pub struct AddedGameObject {
pub addedObject: PPtr,
pub insertIndex: i32,
pub targetCorrespondingSourceObject: PPtr,
}Expand description
AddedGameObject is a sub class of the Unity engine since version 2022.1.0b1. Exert from Unity’s scripting documentation: Class with information about a GameObject that has been added as a child under a Prefab instance.
Fields
addedObject: PPtrPPtr<Transform>: (2022.1.0b1 - 2022.3.2f1)
insertIndex: i32targetCorrespondingSourceObject: PPtrPPtr<Transform>: (2022.1.0b1 - 2022.3.2f1)