AnimationClip

Struct AnimationClip 

pub struct AnimationClip {
Show 21 fields pub m_Bounds: AABB, pub m_Compressed: bool, pub m_CompressedRotationCurves: Vec<CompressedAnimationCurve>, pub m_Events: Vec<AnimationEvent>, pub m_FloatCurves: Vec<FloatCurve>, pub m_Name: String, pub m_PositionCurves: Vec<Vector3Curve>, pub m_RotationCurves: Vec<QuaternionCurve>, pub m_SampleRate: f32, pub m_ScaleCurves: Vec<Vector3Curve>, pub m_WrapMode: i32, pub m_AnimationType: Option<i32>, pub m_ClipBindingConstant: Option<AnimationClipBindingConstant>, pub m_EulerCurves: Option<Vec<Vector3Curve>>, pub m_HasGenericRootTransform: Option<bool>, pub m_HasMotionFloatCurves: Option<bool>, pub m_Legacy: Option<bool>, pub m_MuscleClip: Option<ClipMuscleConstant>, pub m_MuscleClipSize: Option<u32>, pub m_PPtrCurves: Option<Vec<PPtrCurve>>, pub m_UseHighQualityCurve: Option<bool>,
}
AnimationClip is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Stores keyframe based animations. AnimationClip is used by Animation to play back animations.

Fields

m_Bounds: AABBm_Compressed: boolm_CompressedRotationCurves: Vec<CompressedAnimationCurve>m_Events: Vec<AnimationEvent>

Animation Events for this animation clip.

m_FloatCurves: Vec<FloatCurve>m_Name: String

The name of the object.

m_PositionCurves: Vec<Vector3Curve>m_RotationCurves: Vec<QuaternionCurve>m_SampleRate: f32m_ScaleCurves: Vec<Vector3Curve>m_WrapMode: i32

Sets the default wrap mode used in the animation state.

m_AnimationType: Option<i32>

i32: (4.0.0 - 4.7.2)

m_ClipBindingConstant: Option<AnimationClipBindingConstant>

AnimationClipBindingConstant: (4.3.0 - 2022.3.2f1)

m_EulerCurves: Option<Vec<Vector3Curve>>

Vec: (5.3.0f1 - 2022.3.2f1)

m_HasGenericRootTransform: Option<bool>

Returns true if the Animation has animation on the root transform. bool: (2018.3.0f2 - 2022.3.2f1)

m_HasMotionFloatCurves: Option<bool>

Returns true if the AnimationClip has editor curves for its root motion. bool: (2018.3.0f2 - 2022.3.2f1)

m_Legacy: Option<bool>

Set to true if the AnimationClip will be used with the Legacy Animation component ( instead of the Animator ). bool: (5.0.0f4 - 2022.3.2f1)

m_MuscleClip: Option<ClipMuscleConstant>

ClipMuscleConstant: (4.0.0 - 2022.3.2f1)

m_MuscleClipSize: Option<u32>

u32: (4.0.0 - 2022.3.2f1)

m_PPtrCurves: Option<Vec<PPtrCurve>>

Vec: (4.3.0 - 2022.3.2f1)

m_UseHighQualityCurve: Option<bool>

bool: (4.3.0 - 2022.3.2f1)