pub struct AnimationEvent {
pub data: String,
pub floatParameter: f32,
pub functionName: String,
pub intParameter: i32,
pub messageOptions: i32,
pub objectReferenceParameter: PPtr,
pub time: f32,
}Expand description
AnimationEvent is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: AnimationEvent lets you call a script function similar to SendMessage as part of playing back an animation. Animation events support functions that take zero or one parameter. The parameter can be a float, an int, a string, an object reference, or an AnimationEvent. A more detailed example below shows a more complex way of creating an animation. In this script example the Animator component is accessed and a Clip from it obtained. (This clip was set up in the Animation window.) The clip lasts for 2 seconds. An AnimationEvent is created, and has parameters set. The parameters include the function PrintEvent() which will handle the event. The event is then added to the clip. This all happens in Start(). Once the game has launched the event is called after 1.3s and then repeats every 2s.
Fields
data: StringfloatParameter: f32Float parameter that is stored in the event and will be sent to the function.
functionName: StringThe name of the function that will be called.
intParameter: i32Int parameter that is stored in the event and will be sent to the function.
messageOptions: i32Function call options.
objectReferenceParameter: PPtrObject reference parameter that is stored in the event and will be sent to the function.
PPtr<[Object]>: (3.4.0 - 2022.3.2f1)
time: f32The time at which the event will be fired off.