pub struct Animator {Show 15 fields
pub m_ApplyRootMotion: bool,
pub m_Avatar: PPtr,
pub m_Controller: PPtr,
pub m_CullingMode: i32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_AllowConstantClipSamplingOptimization: Option<bool>,
pub m_AnimatePhysics: Option<bool>,
pub m_HasTransformHierarchy: Option<bool>,
pub m_KeepAnimatorControllerStateOnDisable: Option<bool>,
pub m_KeepAnimatorStateOnDisable: Option<bool>,
pub m_LinearVelocityBlending: Option<bool>,
pub m_StabilizeFeet: Option<bool>,
pub m_UpdateMode: Option<i32>,
pub m_WriteDefaultValuesOnDisable: Option<bool>,
}Expand description
Animator is a class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Interface to control the Mecanim animation system.
Fields
m_ApplyRootMotion: boolShould root motion be applied?
m_Avatar: PPtrGets/Sets the current Avatar.
PPtr<Avatar>: (4.0.0 - 2022.3.2f1)
m_Controller: PPtrPPtr<AnimatorController>: (4.0.0 - 4.2.2); PPtr<RuntimeAnimatorController>: (4.3.0 - 2022.3.2f1)
m_CullingMode: i32Controls culling of this Animator component.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.0.0 - 2022.3.2f1)
m_AllowConstantClipSamplingOptimization: Option<bool>bool: (4.5.3 - 2022.3.2f1)
m_AnimatePhysics: Option<bool>bool: (4.0.0 - 4.3.4)
m_HasTransformHierarchy: Option<bool>Returns true if the object has a transform hierarchy. bool: (4.3.0 - 2022.3.2f1)
m_KeepAnimatorControllerStateOnDisable: Option<bool>bool: (2018.1.0b2 - 2022.2.0a18)
m_KeepAnimatorStateOnDisable: Option<bool>Controls the behaviour of the Animator component when a GameObject is disabled. bool: (2020.3.43f1 - 2022.3.2f1)
m_LinearVelocityBlending: Option<bool>bool: (5.0.0f4 - 2022.3.2f1)
m_StabilizeFeet: Option<bool>Automatic stabilization of feet during transition and blending. bool: (2020.3.43f1 - 2022.3.2f1)
m_UpdateMode: Option<i32>Specifies the update mode of the Animator. i32: (4.5.0 - 2022.3.2f1)
m_WriteDefaultValuesOnDisable: Option<bool>Specifies whether playable graph values are reset or preserved when the Animator is disabled. bool: (2020.3.46f1 - 2022.3.2f1)