pub struct AnimatorCondition {
pub m_ConditionEvent: String,
pub m_ConditionMode: i32,
pub m_EventTreshold: f32,
}Expand description
AnimatorCondition is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Condition that is used to determine if a transition must be taken.
Fields
m_ConditionEvent: Stringm_ConditionMode: i32m_EventTreshold: f32Trait Implementations
Sourceimpl Debug for AnimatorCondition
impl Debug for AnimatorCondition
Sourceimpl<'de> Deserialize<'de> for AnimatorCondition
impl<'de> Deserialize<'de> for AnimatorCondition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more