pub struct AnimatorController {
pub m_AnimationClips: Vec<PPtr>,
pub m_Controller: ControllerConstant,
pub m_ControllerSize: u32,
pub m_Name: String,
pub m_TOS: Vec<(u32, String)>,
pub m_MultiThreadedStateMachine: Option<bool>,
pub m_StateMachineBehaviourVectorDescription: Option<StateMachineBehaviourVectorDescription>,
pub m_StateMachineBehaviours: Option<Vec<PPtr>>,
}Expand description
AnimatorController is a class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: The Animator Controller controls animation through layers with state machines, controlled by parameters.
Fields
m_AnimationClips: Vec<PPtr>Retrieves all AnimationClip used by the controller.
Vec<PPtr<AnimationClip>>: (4.0.0 - 2022.3.2f1)
m_Controller: ControllerConstantm_ControllerSize: u32m_Name: StringThe name of the object.
m_TOS: Vec<(u32, String)>m_MultiThreadedStateMachine: Option<bool>bool: (5.0.0f4 - 2022.3.2f1)
m_StateMachineBehaviourVectorDescription: Option<StateMachineBehaviourVectorDescription>StateMachineBehaviourVectorDescription: (5.0.0f4 - 2022.3.2f1)
m_StateMachineBehaviours: Option<Vec<PPtr>>Vec<PPtr<MonoBehaviour>>: (5.0.0f4 - 2022.3.2f1)