AnimatorStateMachine

Struct AnimatorStateMachine 

pub struct AnimatorStateMachine {
    pub m_AnyStatePosition: Vector3f,
    pub m_AnyStateTransitions: Vec<PPtr>,
    pub m_ChildStateMachines: Vec<ChildAnimatorStateMachine>,
    pub m_ChildStates: Vec<ChildAnimatorState>,
    pub m_DefaultState: PPtr,
    pub m_EntryPosition: Vector3f,
    pub m_EntryTransitions: Vec<PPtr>,
    pub m_ExitPosition: Vector3f,
    pub m_Name: String,
    pub m_ParentStateMachinePosition: Vector3f,
    pub m_StateMachineBehaviours: Vec<PPtr>,
    pub m_StateMachineTransitions: Vec<(PPtr, Vec<PPtr>)>,
}
AnimatorStateMachine is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: A graph controlling the interaction of states. Each state references a motion.

Fields

m_AnyStatePosition: Vector3f

The position of the AnyState node.

m_AnyStateTransitions: Vec<PPtr>

The list of AnyState transitions. Vec<PPtr<AnimatorStateTransition>>: (5.0.0f4 - 2022.3.2f1)

m_ChildStateMachines: Vec<ChildAnimatorStateMachine>m_ChildStates: Vec<ChildAnimatorState>m_DefaultState: PPtr

The state that the state machine will be in when it starts. PPtr<AnimatorState>: (5.0.0f4 - 2022.3.2f1)

m_EntryPosition: Vector3f

The position of the entry node.

m_EntryTransitions: Vec<PPtr>

The list of entry transitions in the state machine. Vec<PPtr<AnimatorTransition>>: (5.0.0f4 - 2022.3.2f1)

m_ExitPosition: Vector3f

The position of the exit node.

m_Name: String

The name of the object.

m_ParentStateMachinePosition: Vector3f

The position of the parent state machine node. Only valid when in a hierachic state machine.

m_StateMachineBehaviours: Vec<PPtr>

Vec<PPtr<MonoBehaviour>>: (5.0.0f4 - 2022.3.2f1)

m_StateMachineTransitions: Vec<(PPtr, Vec<PPtr>)>

Vec<(PPtr<AnimatorStateMachine>, Vec<PPtr<AnimatorTransition>>)>: (5.0.0f4 - 2022.3.2f1)