pub struct AnimatorTransitionBase {
pub m_Conditions: Vec<AnimatorCondition>,
pub m_DstState: PPtr,
pub m_DstStateMachine: PPtr,
pub m_IsExit: bool,
pub m_Mute: bool,
pub m_Name: String,
pub m_Solo: bool,
}Expand description
AnimatorTransitionBase is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Base class for animator transitions. Transitions define when and how the state machine switches from one state to another. A transition happens when all its conditions are met.
Fields
m_Conditions: Vec<AnimatorCondition>AnimatorCondition conditions that need to be met for a transition to happen.
m_DstState: PPtrPPtr<AnimatorState>: (5.0.0f4 - 2022.3.2f1)
m_DstStateMachine: PPtrPPtr<AnimatorStateMachine>: (5.0.0f4 - 2022.3.2f1)
m_IsExit: boolIs the transition destination the exit of the current state machine.
m_Mute: boolMutes the transition. The transition will never occur.
m_Name: StringThe name of the object.
m_Solo: boolMutes all other transitions in the source state.