AssetBundle

Struct AssetBundle 

pub struct AssetBundle {
Show 14 fields pub m_Container: Vec<(String, AssetInfo)>, pub m_MainAsset: AssetInfo, pub m_Name: String, pub m_PreloadTable: Vec<PPtr>, pub m_AssetBundleName: Option<String>, pub m_ClassCompatibility: Option<Vec<(i32, u32)>>, pub m_ClassVersionMap: Option<Vec<(i32, i32)>>, pub m_Dependencies: Option<Vec<String>>, pub m_ExplicitDataLayout: Option<i32>, pub m_IsStreamedSceneAssetBundle: Option<bool>, pub m_PathFlags: Option<i32>, pub m_RuntimeCompatibility: Option<u32>, pub m_SceneHashes: Option<Vec<(String, String)>>, pub m_ScriptCompatibility: Option<Vec<AssetBundleScriptInfo>>,
}
AssetBundle is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: AssetBundles let you stream additional assets via the UnityWebRequest class and instantiate them at runtime. Create AssetBundles by calling BuildPipeline.BuildAssetBundles or using the Scriptable Build Pipeline package.A bundle built for any of the standalone platforms can only be loaded on that platform, for example a bundle build on iOS is not compatible with Android. This is because shaders, textures and other types of data are built into platform-specific formats based on the BuildTarget.See Also: UnityWebRequestAssetBundle.GetAssetBundle, Loading Resources at Runtime, BuildPipeline.BuildAssetBundles.

Fields

m_Container: Vec<(String, AssetInfo)>m_MainAsset: AssetInfom_Name: String

The name of the object.

m_PreloadTable: Vec<PPtr>

Vec<PPtr<[Object]>>: (3.4.0 - 2022.3.2f1)

m_AssetBundleName: Option<String>

String: (5.0.0f4 - 2022.3.2f1)

m_ClassCompatibility: Option<Vec<(i32, u32)>>

Vec<(i32, u32)>: (3.5.0 - 4.7.2)

m_ClassVersionMap: Option<Vec<(i32, i32)>>

Vec<(i32, i32)>: (5.4.0f3 - 5.4.6f3)

m_Dependencies: Option<Vec<String>>

Vec: (5.0.0f4 - 2022.3.2f1)

m_ExplicitDataLayout: Option<i32>

i32: (2017.3.0b1 - 2022.3.2f1)

m_IsStreamedSceneAssetBundle: Option<bool>

Return true if the AssetBundle is a streamed Scene AssetBundle. bool: (5.0.0f4 - 2022.3.2f1)

m_PathFlags: Option<i32>

i32: (2017.1.0b2 - 2022.3.2f1)

m_RuntimeCompatibility: Option<u32>

u32: (4.2.0 - 2022.3.2f1)

m_SceneHashes: Option<Vec<(String, String)>>

Vec<(String, String)>: (2017.3.0b1 - 2022.3.2f1)

m_ScriptCompatibility: Option<Vec<AssetBundleScriptInfo>>

Vec: (3.4.0 - 4.7.2)