pub struct AssetBundleInfo {
pub AssetBundleDependencies: Vec<i32>,
pub AssetBundleHash: Hash128,
}Expand description
AssetBundleInfo is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Container for holding asset loading information for an AssetBundle to be built. Note: this class and its members exist to provide low-level support for the Scriptable Build Pipeline package. This is intended for internal use only; use the Scriptable Build Pipeline package to implement a fully featured build pipeline. You can install this via the Unity Package Manager.
Fields
AssetBundleDependencies: Vec<i32>AssetBundleHash: Hash128Trait Implementations
Sourceimpl Debug for AssetBundleInfo
impl Debug for AssetBundleInfo
Sourceimpl<'de> Deserialize<'de> for AssetBundleInfo
impl<'de> Deserialize<'de> for AssetBundleInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more