AudioEchoFilter

Struct AudioEchoFilter 

pub struct AudioEchoFilter {
    pub m_DecayRatio: f32,
    pub m_Delay: Enum_u32__f32,
    pub m_DryMix: f32,
    pub m_Enabled: u8,
    pub m_GameObject: PPtr,
    pub m_WetMix: f32,
}
AudioEchoFilter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The Audio Echo Filter repeats a sound after a given Delay, attenuating the repetitions based on the Decay Ratio. See Also: Audio Echo Filter information.

Fields

m_DecayRatio: f32

Echo decay per delay. 0 to 1. 1.0 = No decay, 0.0 = total decay (i.e. simple 1 line delay). Default = 0.5.

m_Delay: Enum_u32__f32

Echo delay in ms. 10 to 5000. Default = 500.

m_DryMix: f32

Volume of original signal to pass to output. 0.0 to 1.0. Default = 1.0.

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (3.4.0 - 2022.3.2f1)

m_WetMix: f32

Volume of echo signal to pass to output. 0.0 to 1.0. Default = 1.0.