AudioImporter

Struct AudioImporter 

pub struct AudioImporter {
Show 26 fields pub m_3D: bool, pub m_ForceToMono: bool, pub m_Name: String, pub audio_preview_data: Option<Vec<u8>>, pub m_Ambisonic: Option<bool>, pub m_AssetBundleName: Option<String>, pub m_AssetBundleVariant: Option<String>, pub m_DefaultSettings: Option<SampleSettings>, pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>, pub m_FileIDToRecycleName: Option<Vec<(i32, String)>>, pub m_Format: Option<i32>, pub m_LoadInBackground: Option<bool>, pub m_Loopable: Option<bool>, pub m_NewHashIdentity: Option<MdFour>, pub m_Normalize: Option<bool>, pub m_OldHashIdentity: Option<MdFour>, pub m_Output: Option<Enum_Output__AudioImporterOutput>, pub m_PlatformSettingOverrides: Option<Vec<(i32, SampleSettings)>>, pub m_PreloadAudioData: Option<bool>, pub m_PreviewData: Option<PreviewData>, pub m_PreviewDataLength: Option<u32>, pub m_Quality: Option<f32>, pub m_Stream: Option<i32>, pub m_UseHardware: Option<bool>, pub m_UsedFileIDs: Option<Vec<i64>>, pub m_UserData: Option<String>,
}
AudioImporter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Audio importer lets you modify AudioClip import settings from editor scripts. Settings of this class match the ones exposed in Audio Import Settings.

Fields

m_3D: boolm_ForceToMono: bool

Force audioclips to mono?

m_Name: String

The name of the object.

audio_preview_data: Option<Vec<u8>>

Vec: (3.4.0 - 3.5.7)

m_Ambisonic: Option<bool>

When this flag is set, the audio clip will be treated as being ambisonic. bool: (2017.1.0b1 - 2022.3.2f1)

m_AssetBundleName: Option<String>

Get or set the AssetBundle name. String: (5.0.0f4 - 2022.3.2f1)

m_AssetBundleVariant: Option<String>

Get or set the AssetBundle variant. String: (5.0.0f4 - 2022.3.2f1)

m_DefaultSettings: Option<SampleSettings>

SampleSettings: (5.0.0f4 - 2022.3.2f1)

m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>

Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)

m_FileIDToRecycleName: Option<Vec<(i32, String)>>

Vec<(i32, String)>: (3.4.0 - 3.4.2)

m_Format: Option<i32>

i32: (3.4.0 - 4.7.2)

m_LoadInBackground: Option<bool>

Corresponding to the “Load In Background” flag in the AudioClip inspector, when this flag is set, the loading of the clip will happen delayed without blocking the main thread. bool: (5.0.0f4 - 2022.3.2f1)

m_Loopable: Option<bool>

bool: (3.4.0 - 4.7.2)

m_NewHashIdentity: Option<MdFour>

MdFour: (3.4.0 - 3.4.2)

m_Normalize: Option<bool>

bool: (5.1.2f1 - 2022.3.2f1)

m_OldHashIdentity: Option<MdFour>

MdFour: (3.4.0 - 3.4.2)

m_Output: Option<Enum_Output__AudioImporterOutput>

Output: (4.0.0 - 4.7.2); AudioImporterOutput: (5.0.0f4 - 2022.3.2f1)

m_PlatformSettingOverrides: Option<Vec<(i32, SampleSettings)>>

Vec<(i32, SampleSettings)>: (5.0.0f4 - 2022.3.2f1)

m_PreloadAudioData: Option<bool>

bool: (5.0.0f4 - 2022.2.0a16)

m_PreviewData: Option<PreviewData>

PreviewData: (5.0.0f4 - 2022.3.2f1)

m_PreviewDataLength: Option<u32>

u32: (3.4.0 - 3.5.7)

m_Quality: Option<f32>

f32: (3.4.0 - 4.7.2)

m_Stream: Option<i32>

i32: (3.4.0 - 4.7.2)

m_UseHardware: Option<bool>

bool: (3.4.0 - 4.7.2)

m_UsedFileIDs: Option<Vec<i64>>

Vec: (2019.1.0b1 - 2022.3.2f1)

m_UserData: Option<String>

Get or set any user data. String: (4.0.0 - 2022.3.2f1)