pub struct AudioListener {
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_ExtensionPropertyValues: Option<Vec<ExtensionPropertyValue>>,
}Expand description
AudioListener is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Representation of a listener in 3D space. This class implements a microphone-like device. It records the sounds around it and plays that through the player’s speakers.
You can only have one listener in a Scene.See Also: AudioSource, AudioListener component in the Components Reference.
Fields
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_ExtensionPropertyValues: Option<Vec<ExtensionPropertyValue>>Vec