pub struct AudioLowPassFilter {
pub lowpassLevelCustomCurve: AnimationCurve,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_LowpassResonanceQ: f32,
pub m_CutoffFrequency: Option<f32>,
}Expand description
AudioLowPassFilter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The Audio Low Pass Filter passes low frequencies of an AudioSource or all sounds reaching an AudioListener, while removing frequencies higher than the Cutoff Frequency. See Also: Audio Low Pass Filter information.
Fields
lowpassLevelCustomCurve: AnimationCurvem_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_LowpassResonanceQ: f32Determines how much the filter’s self-resonance is dampened.
m_CutoffFrequency: Option<f32>Lowpass cutoff frequency in hz. 10.0 to 22000.0. Default = 5000.0. f32: (3.4.0 - 5.1.5f1)