pub struct AudioMixer {
pub m_EnableSuspend: bool,
pub m_MasterGroup: PPtr,
pub m_MixerConstant: AudioMixerConstant,
pub m_Name: String,
pub m_OutputGroup: PPtr,
pub m_Snapshots: Vec<PPtr>,
pub m_StartSnapshot: PPtr,
pub m_SuspendThreshold: f32,
pub m_UpdateMode: Option<i32>,
}Expand description
AudioMixer is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: AudioMixer asset. This is a singleton representing a specific audio mixer asset in the project.
Fields
m_EnableSuspend: boolm_MasterGroup: PPtrPPtr<AudioMixerGroup>: (5.0.0f4 - 2022.3.2f1)
m_MixerConstant: AudioMixerConstantm_Name: StringThe name of the object.
m_OutputGroup: PPtrPPtr<AudioMixerGroup>: (5.0.0f4 - 2022.3.2f1)
m_Snapshots: Vec<PPtr>Vec<PPtr<AudioMixerSnapshot>>: (5.0.0f4 - 2022.3.2f1)
m_StartSnapshot: PPtrPPtr<AudioMixerSnapshot>: (5.0.0f4 - 2022.3.2f1)
m_SuspendThreshold: f32m_UpdateMode: Option<i32>How time should progress for this AudioMixer. Used during Snapshot transitions. i32: (5.3.6f1 - 2022.3.2f1)