AudioReverbFilter

Struct AudioReverbFilter 

pub struct AudioReverbFilter {
Show 18 fields pub m_DecayHFRatio: f32, pub m_DecayTime: f32, pub m_Density: f32, pub m_Diffusion: f32, pub m_DryLevel: f32, pub m_Enabled: u8, pub m_GameObject: PPtr, pub m_HFReference: f32, pub m_LFReference: f32, pub m_ReflectionsDelay: f32, pub m_ReflectionsLevel: f32, pub m_ReverbDelay: f32, pub m_ReverbLevel: f32, pub m_ReverbPreset: i32, pub m_Room: f32, pub m_RoomHF: f32, pub m_RoomLF: f32, pub m_RoomRolloff: Option<f32>,
}
AudioReverbFilter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The Audio Reverb Filter takes an Audio Clip and distorts it to create a custom reverb effect. See Also: Audio Reverb Filter information.

Fields

m_DecayHFRatio: f32

Decay HF Ratio : High-frequency to low-frequency decay time ratio. Ranges from 0.1 to 2.0. Default is 0.5.

m_DecayTime: f32

Reverberation decay time at low-frequencies in seconds. Ranges from 0.1 to 20.0. Default is 1.0.

m_Density: f32

Reverberation density (modal density) in percent. Ranges from 0.0 to 100.0. Default is 100.0.

m_Diffusion: f32

Reverberation diffusion (echo density) in percent. Ranges from 0.0 to 100.0. Default is 100.0.

m_DryLevel: f32

Mix level of dry signal in output in millibels (mB). Ranges from -10000.0 to 0.0. Default is 0.

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (3.4.0 - 2022.3.2f1)

m_HFReference: f32

Reference high frequency in hertz (Hz). Ranges from 1000.0 to 20000.0. Default is 5000.0.

m_LFReference: f32

Reference low-frequency in hertz (Hz). Ranges from 20.0 to 1000.0. Default is 250.0.

m_ReflectionsDelay: f32

Late reverberation level relative to room effect in millibels (mB). Ranges from -10000.0 to 2000.0. Default is 0.0.

m_ReflectionsLevel: f32

Early reflections level relative to room effect in millibels (mB). Ranges from -10000.0 to 1000.0. Default is -10000.0.

m_ReverbDelay: f32

Late reverberation delay time relative to first reflection in seconds. Ranges from 0.0 to 0.1. Default is 0.04.

m_ReverbLevel: f32

Late reverberation level relative to room effect in millibels (mB). Ranges from -10000.0 to 2000.0. Default is 0.0.

m_ReverbPreset: i32

Set/Get reverb preset properties.

m_Room: f32

Room effect level at low frequencies in millibels (mB). Ranges from -10000.0 to 0.0. Default is 0.0.

m_RoomHF: f32

Room effect high-frequency level re. low frequency level in millibels (mB). Ranges from -10000.0 to 0.0. Default is 0.0.

m_RoomLF: f32

Room effect low-frequency level in millibels (mB). Ranges from -10000.0 to 0.0. Default is 0.0.

m_RoomRolloff: Option<f32>

f32: (3.4.0 - 5.6.0b9)