pub struct Behaviour {
pub m_Enabled: u8,
pub m_GameObject: PPtr,
}Expand description
Behaviour is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Behaviours are Components that can be enabled or disabled. See Also: MonoBehaviour and Component.
Fields
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)