pub struct BoxCollider2D {Show 20 fields
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_IsTrigger: bool,
pub m_Material: PPtr,
pub m_Size: Vector2f,
pub m_AutoTiling: Option<bool>,
pub m_CallbackLayers: Option<BitField>,
pub m_Center: Option<Vector2f>,
pub m_ContactCaptureLayers: Option<BitField>,
pub m_Density: Option<f32>,
pub m_EdgeRadius: Option<f32>,
pub m_ExcludeLayers: Option<BitField>,
pub m_ForceReceiveLayers: Option<BitField>,
pub m_ForceSendLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_LayerOverridePriority: Option<i32>,
pub m_Offset: Option<Vector2f>,
pub m_SpriteTilingProperty: Option<SpriteTilingProperty>,
pub m_UsedByComposite: Option<bool>,
pub m_UsedByEffector: Option<bool>,
}Expand description
BoxCollider2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Collider for 2D physics representing an axis-aligned rectangle. See Also: CircleCollider2D, PolygonCollider2D, EdgeCollider2D.
Fields
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.3.0 - 2022.3.2f1)
m_IsTrigger: boolIs this collider configured as a trigger?
m_Material: PPtrPPtr<PhysicsMaterial2D>: (4.3.0 - 2022.3.2f1)
m_Size: Vector2fThe width and height of the rectangle.
m_AutoTiling: Option<bool>Determines whether the BoxCollider2D’s shape is automatically updated based on a SpriteRenderer’s tiling properties. bool: (5.6.0f1 - 2022.3.2f1)
m_CallbackLayers: Option<BitField>The Layers that this Collider2D will report collision or trigger callbacks for during a contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_Center: Option<Vector2f>Vector2f: (4.3.0 - 4.7.2)
m_ContactCaptureLayers: Option<BitField>The layers of other Collider2D involved in contacts with this Collider2D that will be captured. BitField: (2022.2.0b1 - 2022.3.2f1)
m_Density: Option<f32>The density of the collider used to calculate its mass (when auto mass is enabled). f32: (5.3.0f1 - 2022.3.2f1)
m_EdgeRadius: Option<f32>Controls the radius of all edges created by the collider. f32: (5.6.0f1 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional Layers that this Collider2D should exclude when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceReceiveLayers: Option<BitField>The Layers that this Collider2D can receive forces from during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceSendLayers: Option<BitField>The Layers that this Collider2D is allowed to send forces to during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional Layers that this Collider2D should include when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider2D used when there is a conflicting decision on whether a contact between itself and another Collision2D should happen or not. i32: (2022.2.0b1 - 2022.3.2f1)
m_Offset: Option<Vector2f>The local offset of the collider geometry. Vector2f: (5.0.0f4 - 2022.3.2f1)
m_SpriteTilingProperty: Option<SpriteTilingProperty>SpriteTilingProperty: (5.6.0f1 - 2022.3.2f1)
m_UsedByComposite: Option<bool>Sets whether the Collider will be used or not used by a CompositeCollider2D. bool: (5.6.0b1 - 2022.3.2f1)
m_UsedByEffector: Option<bool>Whether the collider is used by an attached effector or not. bool: (5.0.0f4 - 2022.3.2f1)