pub struct BrokenPrefabAsset {
pub m_BrokenParentPrefab: PPtr,
pub m_IsPrefabFileValid: bool,
pub m_IsVariant: bool,
pub m_IsWarning: bool,
pub m_Message: String,
pub m_Name: String,
}Expand description
BrokenPrefabAsset is a class of the Unity engine since version 2022.2.0b1. Exert from Unity’s scripting documentation: BrokenPrefabAsset is for Prefab files where the file content cannot be loaded without errors. A Prefab Asset can be broken if the content of the file invalid or if it is a Variant Prefab where the parent Prefab is either invalid or missing.Search for t:BrokenPrefabAsset in the project browser to see which assets are of that type.
Fields
m_BrokenParentPrefab: PPtrPPtr<BrokenPrefabAsset>: (2022.2.0b1 - 2022.3.2f1)
m_IsPrefabFileValid: boolReturns true if the content of the file is valid.
m_IsVariant: boolReturns true if the prefab is a variant.
m_IsWarning: boolm_Message: Stringm_Name: StringThe name of the object.