BuildSummary

Struct BuildSummary 

pub struct BuildSummary {
Show 18 fields pub assetBundleOptions: i32, pub crc: u32, pub options: i32, pub outputPath: String, pub platformName: String, pub totalErrors: i32, pub totalSize: u64, pub totalWarnings: i32, pub buildGUID: Option<GUID>, pub buildResult: Option<i32>, pub buildStartTime: Option<DateTime>, pub buildType: Option<i32>, pub name: Option<String>, pub platformGroupName: Option<String>, pub subtarget: Option<i32>, pub success: Option<bool>, pub totalTimeMS: Option<u64>, pub totalTimeTicks: Option<u64>,
}
BuildSummary is a sub class of the Unity engine since version 5.4.0f3. Exert from Unity’s scripting documentation: Contains overall summary information about a build.

Fields

assetBundleOptions: i32crc: u32options: i32

The BuildOptions used for the build, as passed to BuildPipeline.BuildPlayer.

outputPath: String

The output path for the build, as provided to BuildPipeline.BuildPlayer.

platformName: StringtotalErrors: i32

The total number of errors and exceptions recorded during the build process.

totalSize: u64

The total size of the build output, in bytes.

totalWarnings: i32

The total number of warnings recorded during the build process.

buildGUID: Option<GUID>

GUID: (5.6.0f1 - 2022.3.2f1)

buildResult: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

buildStartTime: Option<DateTime>

DateTime: (2018.1.0b2 - 2022.3.2f1)

buildType: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

name: Option<String>

String: (5.4.0f3 - 2017.4.40f1)

platformGroupName: Option<String>

String: (5.6.0b1 - 2022.3.2f1)

subtarget: Option<i32>

i32: (2021.2.0f1 - 2022.3.2f1)

success: Option<bool>

bool: (5.5.0f3 - 2017.1.5f1)

totalTimeMS: Option<u64>

u64: (5.4.0f3 - 2017.4.40f1)

totalTimeTicks: Option<u64>

u64: (2018.1.0b2 - 2022.3.2f1)