BuoyancyEffector2D

Struct BuoyancyEffector2D 

pub struct BuoyancyEffector2D {
    pub m_AngularDrag: f32,
    pub m_ColliderMask: BitField,
    pub m_Density: f32,
    pub m_Enabled: u8,
    pub m_FlowAngle: f32,
    pub m_FlowMagnitude: f32,
    pub m_FlowVariation: f32,
    pub m_GameObject: PPtr,
    pub m_LinearDrag: f32,
    pub m_SurfaceLevel: f32,
    pub m_UseColliderMask: bool,
}
BuoyancyEffector2D is a class of the Unity engine since version 5.3.0f1. Exert from Unity’s scripting documentation: Applies forces to simulate buoyancy, fluid-flow and fluid drag. When any Collider2D overlap the area defined by the effector, calculations are made to determine if they are below the surfaceLevel. If they are not, no forces are applied. If they are then the effector will apply buoyancy forces in an attempt to move the Collider2D to the surfaceLevel i.e. they will float.This effector is designed primarily to work with Collider2D that are set as triggers so that Collider2D can overlap the defined area and have buoyancy forces applied to them.

Fields

m_AngularDrag: f32

A force applied to slow angular movement of any Collider2D in contact with the effector.

m_ColliderMask: BitField

The mask used to select specific layers allowed to interact with the effector.

m_Density: f32

The density of the fluid used to calculate the buoyancy forces.

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_FlowAngle: f32

The angle of the force used to similate fluid flow.

m_FlowMagnitude: f32

The magnitude of the force used to similate fluid flow.

m_FlowVariation: f32

The random variation of the force used to similate fluid flow.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (5.3.0f1 - 2022.3.2f1)

m_LinearDrag: f32

A force applied to slow linear movement of any Collider2D in contact with the effector.

m_SurfaceLevel: f32

Defines an arbitrary horizontal line that represents the fluid surface level.

m_UseColliderMask: bool

Should the collider-mask be used or the global collision matrix?