pub struct CharacterInfo {
pub index: u32,
pub uv: Rectf,
pub vert: Rectf,
pub advance: Option<f32>,
pub flipped: Option<bool>,
pub width: Option<f32>,
}Expand description
CharacterInfo is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Specification for how to render a character from the font texture. See Font.characterInfo. See Also: Example at Font.RequestCharactersInTexture.
Fields
index: u32Unicode value of the character.
uv: Rectfvert: Rectfadvance: Option<f32>The horizontal distance, rounded to the nearest integer, from the origin of this character to the origin of the next character. f32: (5.3.0f1 - 2022.3.2f1)
flipped: Option<bool>bool: (4.0.0 - 2022.3.2f1)
width: Option<f32>f32: (3.4.0 - 5.2.5f1)