pub struct ChildAnimatorState {
pub m_Position: Vector3f,
pub m_State: PPtr,
}Expand description
ChildAnimatorState is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Structure that represents a state in the context of its parent state machine.
Fields
m_Position: Vector3fThe position the the state node in the context of its parent state machine.
m_State: PPtrThe state.
PPtr<AnimatorState>: (5.0.0f4 - 2022.3.2f1)