pub struct ChildAnimatorStateMachine {
pub m_Position: Vector3f,
pub m_StateMachine: PPtr,
}Expand description
ChildAnimatorStateMachine is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Structure that represents a state machine in the context of its parent state machine.
Fields
m_Position: Vector3fThe position of the state machine node in the context of its parent state machine.
m_StateMachine: PPtrThe state machine.
PPtr<AnimatorStateMachine>: (5.0.0f4 - 2022.3.2f1)