pub struct ClipAnimationInfoCurve {
pub curve: AnimationCurve,
pub name: String,
}Expand description
ClipAnimationInfoCurve is a sub class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Stores a curve and its name that will be used to create additional curves during the import process.
Fields
curve: AnimationCurveThe animation curve.
name: StringThe name of the animation curve.