ClothSphereColliderPair

Struct ClothSphereColliderPair 

pub struct ClothSphereColliderPair {
    pub first: PPtr,
    pub second: PPtr,
}
ClothSphereColliderPair is a sub class of the Unity engine since version 2019.1.0b1. Exert from Unity’s scripting documentation: A pair of SphereColliders used to define shapes for Cloth objects to collide against. A ClothSphereColliderPair can contain either a single valid SphereCollider instance (with the second one being null), or a pair of two SphereColliders. In the former cases the ClothSphereColliderPair just represents a single SphereCollider for the cloth to collide against. In the latter case, it represents a conic capsule shape defined by the two spheres, and the cone connecting the two. Conic capsule shapes are useful for modelling limbs of a character.Select the cloth object to see a visualization of Cloth colliders shapes in the Scene view.

Fields

first: PPtr

The first SphereCollider of a ClothSphereColliderPair. PPtr<SphereCollider>: (2019.1.0b1 - 2022.3.2f1)

second: PPtr

The second SphereCollider of a ClothSphereColliderPair. PPtr<SphereCollider>: (2019.1.0b1 - 2022.3.2f1)