CollisionModule

Struct CollisionModule 

pub struct CollisionModule {
Show 31 fields pub enabled: bool, pub minKillSpeed: f32, pub _type: Option<i32>, pub bounce: Option<f32>, pub colliderForce: Option<f32>, pub collidesWith: Option<BitField>, pub collidesWithDynamic: Option<bool>, pub collisionMessages: Option<bool>, pub collisionMode: Option<i32>, pub dampen: Option<f32>, pub energyLossOnCollision: Option<f32>, pub interiorCollisions: Option<bool>, pub m_Bounce: Option<MinMaxCurve>, pub m_Dampen: Option<MinMaxCurve>, pub m_EnergyLossOnCollision: Option<MinMaxCurve>, pub m_Planes: Option<Vec<PPtr>>, pub maxCollisionShapes: Option<i32>, pub maxKillSpeed: Option<f32>, pub multiplyColliderForceByCollisionAngle: Option<bool>, pub multiplyColliderForceByParticleSize: Option<bool>, pub multiplyColliderForceByParticleSpeed: Option<bool>, pub particleRadius: Option<f32>, pub plane0: Option<PPtr>, pub plane1: Option<PPtr>, pub plane2: Option<PPtr>, pub plane3: Option<PPtr>, pub plane4: Option<PPtr>, pub plane5: Option<PPtr>, pub quality: Option<i32>, pub radiusScale: Option<f32>, pub voxelSize: Option<f32>,
}
CollisionModule is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for the CollisionModule of a Particle System. See Also: ParticleSystem, ParticleSystem.collision.

Fields

enabled: bool

Specifies whether the CollisionModule is enabled or disabled.

minKillSpeed: f32

Kill particles whose speed falls below this threshold, after a collision.

_type: Option<i32>

The type of particle collision to perform. i32: (3.5.0 - 2022.3.2f1)

bounce: Option<f32>

How much force is applied to each particle after a collision. f32: (3.5.0 - 5.2.5f1)

colliderForce: Option<f32>

How much force is applied to a Collider when hit by particles from this Particle System. f32: (2017.1.0b1 - 2022.3.2f1)

collidesWith: Option<BitField>

Control which Layers this Particle System collides with. BitField: (4.0.0 - 2022.3.2f1)

collidesWithDynamic: Option<bool>

bool: (5.3.0f1 - 2022.3.2f1)

collisionMessages: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

collisionMode: Option<i32>

i32: (5.3.0f1 - 2022.3.2f1)

dampen: Option<f32>

How much speed does each particle lose after a collision. f32: (3.5.0 - 5.2.5f1)

energyLossOnCollision: Option<f32>

f32: (3.5.0 - 5.2.5f1)

interiorCollisions: Option<bool>

bool: (5.3.0f1 - 2022.3.2f1)

m_Bounce: Option<MinMaxCurve>

How much force is applied to each particle after a collision. MinMaxCurve: (5.3.0f1 - 2022.3.2f1)

m_Dampen: Option<MinMaxCurve>

How much speed does each particle lose after a collision. MinMaxCurve: (5.3.0f1 - 2022.3.2f1)

m_EnergyLossOnCollision: Option<MinMaxCurve>

MinMaxCurve: (5.3.0f1 - 2022.3.2f1)

m_Planes: Option<Vec<PPtr>>

Vec<PPtr<Transform>>: (2020.2.0b1 - 2022.3.2f1)

maxCollisionShapes: Option<i32>

The maximum number of collision shapes Unity considers for particle collisions. It ignores excess shapes. Terrains take priority. i32: (5.3.0f1 - 2022.3.2f1)

maxKillSpeed: Option<f32>

Kill particles whose speed goes above this threshold, after a collision. f32: (5.4.0f3 - 2022.3.2f1)

multiplyColliderForceByCollisionAngle: Option<bool>

Specifies whether the physics system considers the collision angle when it applies forces from particles to Colliders. bool: (2017.1.0b1 - 2022.3.2f1)

multiplyColliderForceByParticleSize: Option<bool>

Specifies whether the physics system considers particle sizes when it applies forces to Colliders. bool: (2017.1.0b1 - 2022.3.2f1)

multiplyColliderForceByParticleSpeed: Option<bool>

Specifies whether the physics system considers particle speeds when it applies forces to Colliders. bool: (2017.1.0b1 - 2022.3.2f1)

particleRadius: Option<f32>

f32: (4.0.0 - 5.2.5f1)

plane0: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

plane1: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

plane2: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

plane3: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

plane4: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

plane5: Option<PPtr>

PPtr<Transform>: (3.5.0 - 2020.2.0a13)

quality: Option<i32>

Specifies the accuracy of particle collisions against colliders in the Scene. i32: (4.0.0 - 2022.3.2f1)

radiusScale: Option<f32>

A multiplier that Unity applies to the size of each particle before collisions are processed. f32: (5.3.0f1 - 2022.3.2f1)

voxelSize: Option<f32>

Size of voxels in the collision cache. f32: (4.0.0 - 2022.3.2f1)