pub struct Component {
pub m_GameObject: PPtr,
}Expand description
Component is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Base class for everything attached to a GameObject. Note that your code will never directly create a Component. Instead, you write script code, and attach the script to a GameObject. See Also: ScriptableObject as a way to create scripts that do not attach to any GameObject.
Fields
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)