pub struct CompositeCollider2D {Show 24 fields
pub m_ColliderPaths: Vec<SubCollider>,
pub m_CompositePaths: Polygon2D,
pub m_Density: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_GenerationType: i32,
pub m_GeometryType: i32,
pub m_IsTrigger: bool,
pub m_Material: PPtr,
pub m_Offset: Vector2f,
pub m_UsedByComposite: bool,
pub m_UsedByEffector: bool,
pub m_VertexDistance: f32,
pub m_CallbackLayers: Option<BitField>,
pub m_CompositeGameObject: Option<PPtr>,
pub m_ContactCaptureLayers: Option<BitField>,
pub m_EdgeRadius: Option<f32>,
pub m_ExcludeLayers: Option<BitField>,
pub m_ForceReceiveLayers: Option<BitField>,
pub m_ForceSendLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_LayerOverridePriority: Option<i32>,
pub m_OffsetDistance: Option<f32>,
pub m_UseDelaunayMesh: Option<bool>,
}Expand description
CompositeCollider2D is a class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: A Collider that can merge other Colliders together. A CompositeCollider2D merges other Colliders together when their Collider2D.usedByComposite is set to true.When a Collider is used by a Composite Collider, the Editor will ignore and not show the Collider2D.sharedMaterial, Collider2D.isTrigger & Collider2D.usedByComposite properties. The same properties on the CompositeCollider2D will be used instead. You should set these properties on the Composite Collider instead to merge all Colliders into the Composite Collider.Composite Colliders can only merge BoxCollider2D and PolygonCollider2D.
Fields
m_ColliderPaths: Vec<SubCollider>m_CompositePaths: Polygon2Dm_Density: f32The density of the collider used to calculate its mass (when auto mass is enabled).
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (5.6.0b1 - 2022.3.2f1)
m_GenerationType: i32Specifies when to generate the Composite Collider geometry.
m_GeometryType: i32Specifies the type of geometry the Composite Collider should generate.
m_IsTrigger: boolIs this collider configured as a trigger?
m_Material: PPtrPPtr<PhysicsMaterial2D>: (5.6.0b1 - 2022.3.2f1)
m_Offset: Vector2fThe local offset of the collider geometry.
m_UsedByComposite: boolSets whether the Collider will be used or not used by a CompositeCollider2D.
m_UsedByEffector: boolWhether the collider is used by an attached effector or not.
m_VertexDistance: f32Controls the minimum distance allowed between generated vertices.
m_CallbackLayers: Option<BitField>The Layers that this Collider2D will report collision or trigger callbacks for during a contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_CompositeGameObject: Option<PPtr>PPtr<GameObject>: (2022.1.18f1 - 2022.3.2f1)
m_ContactCaptureLayers: Option<BitField>The layers of other Collider2D involved in contacts with this Collider2D that will be captured. BitField: (2022.2.0b1 - 2022.3.2f1)
m_EdgeRadius: Option<f32>Controls the radius of all edges created by the Collider. f32: (5.6.0f1 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional Layers that this Collider2D should exclude when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceReceiveLayers: Option<BitField>The Layers that this Collider2D can receive forces from during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceSendLayers: Option<BitField>The Layers that this Collider2D is allowed to send forces to during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional Layers that this Collider2D should include when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider2D used when there is a conflicting decision on whether a contact between itself and another Collision2D should happen or not. i32: (2022.2.0b1 - 2022.3.2f1)
m_OffsetDistance: Option<f32>Vertices are offset by this distance when compositing multiple physic shapes. Any vertices between shapes within this distance are combined. f32: (2019.1.3f1 - 2022.3.2f1)
m_UseDelaunayMesh: Option<bool>When the value is true, the Collider uses an additional Delaunay triangulation step to produce the Collider mesh. When the value is false, this additional step does not occur. bool: (2022.1.0b1 - 2022.3.2f1)