ComputeShader

Struct ComputeShader 

pub struct ComputeShader {
    pub m_Name: String,
    pub constantBuffers: Option<Vec<ComputeShaderCB>>,
    pub kernels: Option<Vec<ComputeShaderKernel>>,
    pub variants: Option<Vec<Enum_ComputeShaderVariant__ComputeShaderPlatformVariant>>,
}
ComputeShader is a class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Compute Shader asset. Compute shaders are programs that run on the GPU outside of the normal rendering pipeline.

They correspond to compute shader assets in the project (.compute files).Compute shader support can be queried runtime using SystemInfo.supportsComputeShaders. See Compute Shaders overview for more info about platforms supporting compute shaders.See Also: ComputeBuffer class, Compute Shaders overview.

Fields

m_Name: String

The name of the object.

constantBuffers: Option<Vec<ComputeShaderCB>>

Vec: (4.0.0 - 4.7.2)

kernels: Option<Vec<ComputeShaderKernel>>

Vec: (4.0.0 - 4.7.2)

variants: Option<Vec<Enum_ComputeShaderVariant__ComputeShaderPlatformVariant>>

Vec: (5.0.0f4 - 2020.1.0a8); Vec: (2020.1.0b1 - 2022.3.2f1)