pub struct CrashReportingSettings {
pub m_Enabled: bool,
pub m_EventUrl: String,
pub m_LogBufferSize: Option<u32>,
pub m_NativeEventUrl: Option<String>,
}Expand description
CrashReportingSettings is a sub class of the Unity engine since version 5.4.0f3. Exert from Unity’s scripting documentation: Editor API for the Unity Services editor feature. Normally CrashReporting is enabled from the Services window, but if writing your own editor extension, this API can be used.
Fields
m_Enabled: boolm_EventUrl: Stringm_LogBufferSize: Option<u32>u32: (2018.3.0f2 - 2022.3.2f1)
m_NativeEventUrl: Option<String>String: (2017.2.0b2 - 2018.2.21f1)