pub struct DefaultPreset {
pub m_Preset: PPtr,
pub m_Disabled: Option<bool>,
pub m_Filter: Option<String>,
}Expand description
DefaultPreset is a sub class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: This structure defines a default Preset. See Preset.GetDefaultListForType and Preset.SetDefaultListForType for usage.
Fields
m_Preset: PPtrThe Preset applied to an object instance when it matches the search filter defined by DefaultPreset.m_Filter.
PPtr<Preset>: (2018.1.0b2 - 2022.3.2f1)
m_Disabled: Option<bool>bool: (2020.1.0b1 - 2022.3.2f1)
m_Filter: Option<String>The search filter that is compared against the object instance. The DefaultPreset.m_Preset is applied to the object instance if it matches the search filter. String: (2019.3.0b1 - 2022.3.2f1)