pub struct EdgeCollider2D {Show 21 fields
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_IsTrigger: bool,
pub m_Material: PPtr,
pub m_Points: Vec<Vector2f>,
pub m_AdjacentEndPoint: Option<Vector2f>,
pub m_AdjacentStartPoint: Option<Vector2f>,
pub m_CallbackLayers: Option<BitField>,
pub m_ContactCaptureLayers: Option<BitField>,
pub m_Density: Option<f32>,
pub m_EdgeRadius: Option<f32>,
pub m_ExcludeLayers: Option<BitField>,
pub m_ForceReceiveLayers: Option<BitField>,
pub m_ForceSendLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_LayerOverridePriority: Option<i32>,
pub m_Offset: Option<Vector2f>,
pub m_UseAdjacentEndPoint: Option<bool>,
pub m_UseAdjacentStartPoint: Option<bool>,
pub m_UsedByComposite: Option<bool>,
pub m_UsedByEffector: Option<bool>,
}Expand description
EdgeCollider2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Collider for 2D physics representing an arbitrary set of connected edges (lines) defined by its vertices. See Also: BoxCollider2D, CircleCollider2D, PolygonCollider2D.
Fields
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.3.0 - 2022.3.2f1)
m_IsTrigger: boolIs this collider configured as a trigger?
m_Material: PPtrPPtr<PhysicsMaterial2D>: (4.3.0 - 2022.3.2f1)
m_Points: Vec<Vector2f>Get or set the points defining multiple continuous edges.
m_AdjacentEndPoint: Option<Vector2f>Defines the position of a virtual point adjacent to the end point of the EdgeCollider2D. Vector2f: (2020.1.0b1 - 2022.3.2f1)
m_AdjacentStartPoint: Option<Vector2f>Defines the position of a virtual point adjacent to the start point of the EdgeCollider2D. Vector2f: (2020.1.0b1 - 2022.3.2f1)
m_CallbackLayers: Option<BitField>The Layers that this Collider2D will report collision or trigger callbacks for during a contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ContactCaptureLayers: Option<BitField>The layers of other Collider2D involved in contacts with this Collider2D that will be captured. BitField: (2022.2.0b1 - 2022.3.2f1)
m_Density: Option<f32>The density of the collider used to calculate its mass (when auto mass is enabled). f32: (5.3.0f1 - 2022.3.2f1)
m_EdgeRadius: Option<f32>Controls the radius of all edges created by the collider. f32: (5.6.0f1 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional Layers that this Collider2D should exclude when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceReceiveLayers: Option<BitField>The Layers that this Collider2D can receive forces from during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceSendLayers: Option<BitField>The Layers that this Collider2D is allowed to send forces to during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional Layers that this Collider2D should include when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider2D used when there is a conflicting decision on whether a contact between itself and another Collision2D should happen or not. i32: (2022.2.0b1 - 2022.3.2f1)
m_Offset: Option<Vector2f>The local offset of the collider geometry. Vector2f: (5.0.0f4 - 2022.3.2f1)
m_UseAdjacentEndPoint: Option<bool>Set this to true to use the adjacentEndPoint to form the collision normal that is used to calculate the collision response when a collision occurs at the Edge Collider’s end point. Set this to false to not use the adjacentEndPoint, and the collision normal becomes the direction of motion of the collision. bool: (2020.1.0b1 - 2022.3.2f1)
m_UseAdjacentStartPoint: Option<bool>Set this to true to use the adjacentStartPoint to form the collision normal that is used to calculate the collision response when a collision occurs at the Edge Collider’s start point. Set this to false to not use the adjacentStartPoint, and the collision normal becomes the direction of motion of the collision. bool: (2020.1.0b1 - 2022.3.2f1)
m_UsedByComposite: Option<bool>Sets whether the Collider will be used or not used by a CompositeCollider2D. bool: (5.6.0b1 - 2022.3.2f1)
m_UsedByEffector: Option<bool>Whether the collider is used by an attached effector or not. bool: (5.0.0f4 - 2022.3.2f1)