EditorSettings

Struct EditorSettings 

pub struct EditorSettings {
Show 49 fields pub m_AssetNamingUsesSpace: Option<bool>, pub m_AssetPipelineMode: Option<i32>, pub m_AsyncShaderCompilation: Option<bool>, pub m_Bc7TextureCompressor: Option<i32>, pub m_CacheServerDownloadBatchSize: Option<i32>, pub m_CacheServerEnableAuth: Option<bool>, pub m_CacheServerEnableDownload: Option<bool>, pub m_CacheServerEnableTls: Option<bool>, pub m_CacheServerEnableUpload: Option<bool>, pub m_CacheServerEndpoint: Option<String>, pub m_CacheServerMode: Option<i32>, pub m_CacheServerNamespacePrefix: Option<String>, pub m_CacheServerValidationMode: Option<i32>, pub m_CachingShaderPreprocessor: Option<bool>, pub m_CollabEditorSettings: Option<CollabEditorSettings>, pub m_DefaultBehaviorMode: Option<i32>, pub m_DisableCookiesInLightmapper: Option<bool>, pub m_EnableEditorAsyncCPUTextureLoading: Option<bool>, pub m_EnableEnlightenBakedGI: Option<bool>, pub m_EnableRoslynAnalyzers: Option<bool>, pub m_EnableTextureStreamingInEditMode: Option<bool>, pub m_EnableTextureStreamingInPlayMode: Option<bool>, pub m_EnterPlayModeOptions: Option<i32>, pub m_EnterPlayModeOptionsEnabled: Option<bool>, pub m_EtcTextureBestCompressor: Option<i32>, pub m_EtcTextureCompressorBehavior: Option<i32>, pub m_EtcTextureFastCompressor: Option<i32>, pub m_EtcTextureNormalCompressor: Option<i32>, pub m_ExternalVersionControlSupport: Option<Enum_i32__String>, pub m_GameObjectNamingDigits: Option<i32>, pub m_GameObjectNamingScheme: Option<i32>, pub m_InspectorUseIMGUIDefaultInspector: Option<bool>, pub m_LineEndingsForNewScripts: Option<i32>, pub m_PrefabModeAllowAutoSave: Option<bool>, pub m_PrefabRegularEnvironment: Option<PPtr>, pub m_PrefabUIEnvironment: Option<PPtr>, pub m_ProjectGenerationIncludedExtensions: Option<String>, pub m_ProjectGenerationRootNamespace: Option<String>, pub m_RefreshImportMode: Option<i32>, pub m_SerializationMode: Option<i32>, pub m_SerializeInlineMappingsOnOneLine: Option<bool>, pub m_ShowLightmapResolutionOverlay: Option<bool>, pub m_SpritePackerCacheSize: Option<i32>, pub m_SpritePackerMode: Option<i32>, pub m_SpritePackerPaddingPower: Option<i32>, pub m_UseLegacyProbeSampleCount: Option<bool>, pub m_UserGeneratedProjectSuffix: Option<String>, pub m_WebSecurityEmulationEnabled: Option<i32>, pub m_WebSecurityEmulationHostUrl: Option<String>,
}
EditorSettings is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: User settings for Unity Editor. Use EditorSettings to apply Editor Project Settings to your Unity Project. You can control settings such as version control, streaming settings, and Asset serialization.See Also: Editor Project Settings

Fields

m_AssetNamingUsesSpace: Option<bool>

bool: (2020.1.0f1 - 2022.3.2f1)

m_AssetPipelineMode: Option<i32>

i32: (2019.3.0f1 - 2022.3.2f1)

m_AsyncShaderCompilation: Option<bool>

bool: (2019.1.0f2 - 2022.3.2f1)

m_Bc7TextureCompressor: Option<i32>

i32: (2021.2.0b1 - 2022.3.2f1)

m_CacheServerDownloadBatchSize: Option<i32>

i32: (2021.3.10f1 - 2022.3.2f1)

m_CacheServerEnableAuth: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

m_CacheServerEnableDownload: Option<bool>

bool: (2019.3.0f1 - 2022.3.2f1)

m_CacheServerEnableTls: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

m_CacheServerEnableUpload: Option<bool>

bool: (2019.3.0f1 - 2022.3.2f1)

m_CacheServerEndpoint: Option<String>

String: (2019.3.0f1 - 2022.3.2f1)

m_CacheServerMode: Option<i32>

i32: (2019.3.0f1 - 2022.3.2f1)

m_CacheServerNamespacePrefix: Option<String>

String: (2019.3.0f1 - 2022.3.2f1)

m_CacheServerValidationMode: Option<i32>

i32: (2019.4.40f1 - 2022.3.2f1)

m_CachingShaderPreprocessor: Option<bool>

bool: (2020.1.0b1 - 2022.1.0a9)

m_CollabEditorSettings: Option<CollabEditorSettings>

CollabEditorSettings: (2017.1.0f2 - 2020.1.0a12)

m_DefaultBehaviorMode: Option<i32>

i32: (4.3.0 - 2022.3.2f1)

m_DisableCookiesInLightmapper: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

m_EnableEditorAsyncCPUTextureLoading: Option<bool>

bool: (2022.1.0b1 - 2022.3.2f1)

m_EnableEnlightenBakedGI: Option<bool>

bool: (2022.2.0b1 - 2022.3.2f1)

m_EnableRoslynAnalyzers: Option<bool>

bool: (2020.2.0a12 - 2020.2.0a16)

m_EnableTextureStreamingInEditMode: Option<bool>

bool: (2019.1.0b1 - 2022.3.2f1)

m_EnableTextureStreamingInPlayMode: Option<bool>

bool: (2018.2.0b1 - 2022.3.2f1)

m_EnterPlayModeOptions: Option<i32>

i32: (2019.3.0b1 - 2022.3.2f1)

m_EnterPlayModeOptionsEnabled: Option<bool>

bool: (2019.3.0b1 - 2022.3.2f1)

m_EtcTextureBestCompressor: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

m_EtcTextureCompressorBehavior: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

m_EtcTextureFastCompressor: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

m_EtcTextureNormalCompressor: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

m_ExternalVersionControlSupport: Option<Enum_i32__String>

i32: (3.4.0 - 3.5.7); String: (4.0.0 - 2020.1.0a12)

m_GameObjectNamingDigits: Option<i32>

i32: (2020.1.0f1 - 2022.3.2f1)

m_GameObjectNamingScheme: Option<i32>

i32: (2020.1.0f1 - 2022.3.2f1)

m_InspectorUseIMGUIDefaultInspector: Option<bool>

bool: (2022.2.0b1 - 2022.3.2f1)

m_LineEndingsForNewScripts: Option<i32>

i32: (2017.3.0b1 - 2022.3.2f1)

m_PrefabModeAllowAutoSave: Option<bool>

bool: (2020.2.0b1 - 2022.3.2f1)

m_PrefabRegularEnvironment: Option<PPtr>

PPtr<[SceneAsset]>: (2018.3.0f2 - 2022.3.2f1)

m_PrefabUIEnvironment: Option<PPtr>

PPtr<[SceneAsset]>: (2018.3.0f2 - 2022.3.2f1)

m_ProjectGenerationIncludedExtensions: Option<String>

String: (5.2.0f2 - 2022.3.2f1)

m_ProjectGenerationRootNamespace: Option<String>

String: (5.2.0f2 - 2022.3.2f1)

m_RefreshImportMode: Option<i32>

i32: (2021.2.0b1 - 2022.3.2f1)

m_SerializationMode: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

m_SerializeInlineMappingsOnOneLine: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

m_ShowLightmapResolutionOverlay: Option<bool>

bool: (2019.2.0b1 - 2020.1.0a12)

m_SpritePackerCacheSize: Option<i32>

i32: (2022.1.0b1 - 2022.3.2f1)

m_SpritePackerMode: Option<i32>

i32: (4.3.0 - 2022.3.2f1)

m_SpritePackerPaddingPower: Option<i32>

i32: (5.1.0f1 - 2022.3.2f1)

m_UseLegacyProbeSampleCount: Option<bool>

bool: (2019.3.0b1 - 2022.3.2f1)

m_UserGeneratedProjectSuffix: Option<String>

String: (5.5.0f3 - 2018.2.21f1)

m_WebSecurityEmulationEnabled: Option<i32>

i32: (3.4.0 - 5.4.6f3)

m_WebSecurityEmulationHostUrl: Option<String>

String: (3.4.0 - 5.4.6f3)