pub struct EmissionModule {Show 19 fields
pub enabled: bool,
pub m_BurstCount: i32,
pub cnt0: Option<i32>,
pub cnt1: Option<i32>,
pub cnt2: Option<i32>,
pub cnt3: Option<i32>,
pub cntmax0: Option<i32>,
pub cntmax1: Option<i32>,
pub cntmax2: Option<i32>,
pub cntmax3: Option<i32>,
pub m_Bursts: Option<Vec<ParticleSystemEmissionBurst>>,
pub m_Type: Option<i32>,
pub rate: Option<MinMaxCurve>,
pub rateOverDistance: Option<MinMaxCurve>,
pub rateOverTime: Option<MinMaxCurve>,
pub time0: Option<f32>,
pub time1: Option<f32>,
pub time2: Option<f32>,
pub time3: Option<f32>,
}Expand description
EmissionModule is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for the EmissionModule of a Particle System. See Also: ParticleSystem, ParticleSystem.emission.
Fields
enabled: boolSpecifies whether the EmissionModule is enabled or disabled.
m_BurstCount: i32The current number of bursts.
cnt0: Option<i32>u16: (3.5.0 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cnt1: Option<i32>u16: (3.5.0 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cnt2: Option<i32>u16: (3.5.0 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cnt3: Option<i32>u16: (3.5.0 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cntmax0: Option<i32>u16: (5.3.0f1 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cntmax1: Option<i32>u16: (5.3.0f1 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cntmax2: Option<i32>u16: (5.3.0f1 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
cntmax3: Option<i32>u16: (5.3.0f1 - 5.3.8f2); i32: (5.4.0f3 - 5.6.0b4)
m_Bursts: Option<Vec<ParticleSystemEmissionBurst>>Vec
m_Type: Option<i32>i32: (3.5.0 - 5.4.6f3)
rate: Option<MinMaxCurve>MinMaxCurve: (3.5.0 - 5.4.6f3)
rateOverDistance: Option<MinMaxCurve>The rate at which the emitter spawns new particles over distance. MinMaxCurve: (5.5.0f3 - 2022.3.2f1)
rateOverTime: Option<MinMaxCurve>The rate at which the emitter spawns new particles over time. MinMaxCurve: (5.5.0f3 - 2022.3.2f1)
time0: Option<f32>f32: (3.5.0 - 5.6.0b4)
time1: Option<f32>f32: (3.5.0 - 5.6.0b4)
time2: Option<f32>f32: (3.5.0 - 5.6.0b4)
time3: Option<f32>f32: (3.5.0 - 5.6.0b4)