pub struct ExternalForcesModule {
pub enabled: bool,
pub influenceFilter: Option<i32>,
pub influenceList: Option<Vec<PPtr>>,
pub influenceMask: Option<BitField>,
pub multiplier: Option<f32>,
pub multiplierCurve: Option<MinMaxCurve>,
}Expand description
ExternalForcesModule is a sub class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Script interface for the ExternalForcesModule of a Particle System. See Also: ParticleSystem, ParticleSystem.externalForces.
Fields
enabled: boolSpecifies whether the ExternalForcesModule is enabled or disabled.
influenceFilter: Option<i32>Apply all Force Fields belonging to a matching Layer to this Particle System. i32: (2018.3.0f2 - 2022.3.2f1)
influenceList: Option<Vec<PPtr>>Vec<PPtr<ParticleSystemForceField>>: (2018.3.0f2 - 2022.3.2f1)
influenceMask: Option<BitField>Particle System Force Field Components with a matching Layer affect this Particle System. BitField: (2018.3.0f2 - 2022.3.2f1)
multiplier: Option<f32>Multiplies the magnitude of external forces affecting the particles. f32: (4.0.0 - 2019.2.0a8)
multiplierCurve: Option<MinMaxCurve>Multiplies the magnitude of applied external forces. MinMaxCurve: (2019.1.0f2 - 2022.3.2f1)