pub struct IHVImageFormatImporter {Show 13 fields
pub m_AssetBundleName: String,
pub m_AssetBundleVariant: String,
pub m_IsReadable: bool,
pub m_Name: String,
pub m_TextureSettings: GLTextureSettings,
pub m_UserData: String,
pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>,
pub m_IgnoreMipmapLimit: Option<bool>,
pub m_MipmapLimitGroupName: Option<String>,
pub m_StreamingMipmaps: Option<bool>,
pub m_StreamingMipmapsPriority: Option<i32>,
pub m_UsedFileIDs: Option<Vec<i64>>,
pub m_sRGBTexture: Option<bool>,
}Expand description
IHVImageFormatImporter is a class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: Use IHVImageFormatImporter to modify Texture2D import settings for Textures in IHV (Independent Hardware Vendor) formats such as .DDS and .PVR from Editor scripts.
Fields
m_AssetBundleName: StringGet or set the AssetBundle name.
m_AssetBundleVariant: StringGet or set the AssetBundle variant.
m_IsReadable: boolIs texture data readable from scripts.
m_Name: StringThe name of the object.
m_TextureSettings: GLTextureSettingsm_UserData: StringGet or set any user data.
m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)
m_IgnoreMipmapLimit: Option<bool>Enable if the texture should ignore any texture mipmap limit settings set in the Project Settings. bool: (2022.2.0f1 - 2022.3.2f1)
m_MipmapLimitGroupName: Option<String>Name of the texture mipmap limit group to which this texture belongs. String: (2022.2.0f1 - 2022.3.2f1)
m_StreamingMipmaps: Option<bool>Enable mipmap streaming for this texture. bool: (2018.2.0b1 - 2022.3.2f1)
m_StreamingMipmapsPriority: Option<i32>Relative priority for this texture when reducing memory size in order to hit the memory budget. i32: (2018.2.0b1 - 2022.3.2f1)
m_UsedFileIDs: Option<Vec<i64>>Vec
m_sRGBTexture: Option<bool>bool: (2017.3.0b1 - 2022.3.2f1)