pub struct JointDrive {
pub maximumForce: f32,
pub positionDamper: f32,
pub positionSpring: f32,
pub mode: Option<i32>,
pub useAcceleration: Option<i32>,
}Expand description
JointDrive is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: How the joint’s movement will behave along its local X axis.
Fields
maximumForce: f32Amount of force applied to push the object toward the defined direction.
positionDamper: f32Resistance strength against the Position Spring. Only used if mode includes Position.
positionSpring: f32Strength of a rubber-band pull toward the defined direction. Only used if mode includes Position.
mode: Option<i32>i32: (3.4.0 - 5.2.5f1)
useAcceleration: Option<i32>Defines whether the drive is an acceleration drive or a force drive. i32: (2022.2.0b1 - 2022.3.2f1)