pub struct JointMotor2D {
pub m_MaximumMotorForce: f32,
pub m_MotorSpeed: f32,
}Expand description
JointMotor2D is a sub class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Parameters for the optional motor force applied to a Joint2D. See Also: HingeJoint2D class, SliderJoint2D class.
Fields
m_MaximumMotorForce: f32m_MotorSpeed: f32The desired speed for the Rigidbody2D to reach as it moves with the joint.