pub struct JointSpring {
pub damper: f32,
pub spring: f32,
pub targetPosition: f32,
}Expand description
JointSpring is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: JointSpring is used add a spring force to HingeJoint and PhysicMaterial.
Fields
damper: f32The damper force uses to dampen the spring.
spring: f32The spring forces used to reach the target position.
targetPosition: f32The target position the joint attempts to reach.