pub struct JointSuspension2D {
pub m_Angle: f32,
pub m_DampingRatio: f32,
pub m_Frequency: f32,
}Expand description
JointSuspension2D is a sub class of the Unity engine since version 4.5.0. Exert from Unity’s scripting documentation: Joint suspension is used to define how suspension works on a WheelJoint2D. See Also: WheelJoint2D class.
Fields
m_Angle: f32The world angle (in degrees) along which the suspension will move.
m_DampingRatio: f32The amount by which the suspension spring force is reduced in proportion to the movement speed.
m_Frequency: f32The frequency at which the suspension spring oscillates.