pub struct LODGroup {
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_LODs: Vec<LOD>,
pub m_LocalReferencePoint: Vector3f,
pub m_Size: f32,
pub m_AnimateCrossFading: Option<bool>,
pub m_FadeMode: Option<i32>,
pub m_LastLODIsBillboard: Option<bool>,
pub m_ScreenRelativeTransitionHeight: Option<f32>,
}Expand description
LODGroup is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: LODGroup lets you group multiple Renderers into LOD levels. This can be used to switch between different LOD levels at runtime based on size on screen.
Fields
m_Enabled: boolAllows you to enable or disable the LODGroup.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.5.0 - 2022.3.2f1)
m_LODs: Vec<LOD>m_LocalReferencePoint: Vector3fThe local reference point against which the LOD distance is calculated.
m_Size: f32The size of the LOD object in local space.
m_AnimateCrossFading: Option<bool>Specify if the cross-fading should be animated by time. The animation duration is specified globally as crossFadeAnimationDuration. bool: (5.1.0f1 - 2022.3.2f1)
m_FadeMode: Option<i32>The LOD fade mode used. i32: (5.1.0f1 - 2022.3.2f1)
m_LastLODIsBillboard: Option<bool>bool: (2018.3.0f2 - 2022.3.2f1)
m_ScreenRelativeTransitionHeight: Option<f32>f32: (3.5.0 - 4.7.2)