pub struct LensFlare {
pub m_Brightness: f32,
pub m_Color: ColorRGBA,
pub m_Directional: bool,
pub m_Enabled: u8,
pub m_Flare: PPtr,
pub m_GameObject: PPtr,
pub m_IgnoreLayers: BitField,
pub m_FadeSpeed: Option<f32>,
}Expand description
LensFlare is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Script interface for a Lens flare component. This allows you to change the brightness and color of lens flares at runtime.
Fields
m_Brightness: f32The strength of the flare.
m_Color: ColorRGBAThe color of the flare.
m_Directional: boolm_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_Flare: PPtrThe flare asset to use.
PPtr<Flare>: (3.4.0 - 2022.3.2f1)
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_IgnoreLayers: BitFieldm_FadeSpeed: Option<f32>The fade speed of the flare. f32: (4.3.0 - 2022.3.2f1)