LifetimeByEmitterSpeedModule

Struct LifetimeByEmitterSpeedModule 

pub struct LifetimeByEmitterSpeedModule {
    pub enabled: bool,
    pub m_Curve: MinMaxCurve,
    pub m_Range: Vector2f,
}
LifetimeByEmitterSpeedModule is a sub class of the Unity engine since version 2020.1.0b1. Exert from Unity’s scripting documentation: The Lifetime By Emitter Speed Module controls the initial lifetime of each particle based on the speed of the emitter when the particle was spawned. This module multiplies the start lifetime of particles with a value that depends on the speed of the object that spawned them. For most Particle Systems, this is the GameObject velocity, but for sub-emitters, the velocity comes from the parent particle that the sub-emitter particle originated from.See Also: ParticleSystem, ParticleSystem.MainModule.startLifetime.

Fields

enabled: bool

Use this property to enable or disable the LifetimeByEmitterSpeed module.

m_Curve: MinMaxCurve

Use this curve to define which value to multiply the start lifetime of a particle with, based on the speed of the emitter when the particle is spawned.

m_Range: Vector2f

Control the start lifetime multiplier between these minimum and maximum speeds of the emitter.