LightBakingOutput

Struct LightBakingOutput 

pub struct LightBakingOutput {
    pub probeOcclusionLightIndex: i32,
    pub isBaked: Option<bool>,
    pub lightmapBakeMode: Option<LightmapBakeMode>,
    pub lightmappingMask: Option<i32>,
    pub occlusionMaskChannel: Option<i32>,
    pub shadowMaskChannel: Option<i32>,
}
LightBakingOutput is a sub class of the Unity engine since version 5.6.0f1. Exert from Unity’s scripting documentation: Struct describing the result of a Global Illumination bake for a given light. The example below demonstrates how you can check the baked status of a light and change its active state.

Fields

probeOcclusionLightIndex: i32

In case of a LightmapBakeType.Mixed light, contains the index of the light as seen from the occlusion probes point of view if any, otherwise -1.

isBaked: Option<bool>

Is the light contribution already stored in lightmaps and/or lightprobes? bool: (2017.3.0b1 - 2022.3.2f1)

lightmapBakeMode: Option<LightmapBakeMode>

LightmapBakeMode: (2017.3.0b1 - 2022.3.2f1)

lightmappingMask: Option<i32>

i32: (5.6.0f1 - 2017.2.5f1)

occlusionMaskChannel: Option<i32>

In case of a LightmapBakeType.Mixed light, contains the index of the occlusion mask channel to use if any, otherwise -1. i32: (5.6.0f1 - 2022.3.2f1)

shadowMaskChannel: Option<i32>

i32: (5.6.0b2 - 5.6.0b4)