LightingDataAsset

Struct LightingDataAsset 

pub struct LightingDataAsset {
Show 21 fields pub m_BakedAmbientProbeInLinear: SphericalHarmonicsL2, pub m_BakedReflectionProbeCubemaps: Vec<PPtr>, pub m_BakedReflectionProbes: Vec<SceneObjectIdentifier>, pub m_EnlightenData: Vec<u8>, pub m_EnlightenSceneMapping: EnlightenSceneMapping, pub m_EnlightenSceneMappingRendererIDs: Vec<SceneObjectIdentifier>, pub m_LightProbes: PPtr, pub m_LightmappedRendererData: Vec<RendererData>, pub m_LightmappedRendererDataIDs: Vec<SceneObjectIdentifier>, pub m_Lightmaps: Vec<LightmapData>, pub m_Lights: Vec<SceneObjectIdentifier>, pub m_Name: String, pub m_AOTextures: Option<Vec<PPtr>>, pub m_BakedLightIndices: Option<Vec<i32>>, pub m_BakedReflectionProbeCubemapCacheFiles: Option<Vec<String>>, pub m_EnlightenDataVersion: Option<i32>, pub m_LightBakingOutputs: Option<Vec<LightBakingOutput>>, pub m_LightmapsCacheFiles: Option<Vec<String>>, pub m_LightmapsMode: Option<i32>, pub m_Scene: Option<PPtr>, pub m_SceneGUID: Option<GUID>,
}
LightingDataAsset is a class of the Unity engine since version 5.3.0f1. Exert from Unity’s scripting documentation: The lighting data asset used by the active Scene. Please note that modifying this value currently does not affect the Scene immediately, the lighting data is only patched into the active Scene when loading the Scene.

Fields

m_BakedAmbientProbeInLinear: SphericalHarmonicsL2m_BakedReflectionProbeCubemaps: Vec<PPtr>

Vec<PPtr<Texture>>: (5.3.0f1 - 2022.3.2f1)

m_BakedReflectionProbes: Vec<SceneObjectIdentifier>m_EnlightenData: Vec<u8>m_EnlightenSceneMapping: EnlightenSceneMappingm_EnlightenSceneMappingRendererIDs: Vec<SceneObjectIdentifier>m_LightProbes: PPtr

PPtr<LightProbes>: (5.3.0f1 - 2022.3.2f1)

m_LightmappedRendererData: Vec<RendererData>m_LightmappedRendererDataIDs: Vec<SceneObjectIdentifier>m_Lightmaps: Vec<LightmapData>m_Lights: Vec<SceneObjectIdentifier>m_Name: String

The name of the object.

m_AOTextures: Option<Vec<PPtr>>

Vec<PPtr<Texture2D>>: (2019.1.0b1 - 2022.3.2f1)

m_BakedLightIndices: Option<Vec<i32>>

Vec: (5.4.0f3 - 5.6.0b1)

m_BakedReflectionProbeCubemapCacheFiles: Option<Vec<String>>

Vec: (2018.2.0b1 - 2022.3.2f1)

m_EnlightenDataVersion: Option<i32>

i32: (5.3.6f1 - 2022.3.2f1)

m_LightBakingOutputs: Option<Vec<LightBakingOutput>>

Vec: (5.6.0f1 - 2022.3.2f1)

m_LightmapsCacheFiles: Option<Vec<String>>

Vec: (2018.2.0b1 - 2022.3.2f1)

m_LightmapsMode: Option<i32>

i32: (5.4.0f3 - 2022.3.2f1)

m_Scene: Option<PPtr>

PPtr<[SceneAsset]>: (2017.1.0f2 - 2022.3.2f1)

m_SceneGUID: Option<GUID>

GUID: (5.3.0f1 - 5.3.0f2)