LightingSettings

Struct LightingSettings 

pub struct LightingSettings {
Show 52 fields pub m_AlbedoBoost: f32, pub m_BounceScale: f32, pub m_EnableBakedLightmaps: bool, pub m_EnableRealtimeLightmaps: bool, pub m_GIWorkflowMode: i32, pub m_Name: String, pub m_RealtimeEnvironmentLighting: bool, pub m_UsingShadowmask: bool, pub m_AO: Option<bool>, pub m_AOMaxDistance: Option<f32>, pub m_BakeBackend: Option<i32>, pub m_BakeResolution: Option<f32>, pub m_CompAOExponent: Option<f32>, pub m_CompAOExponentDirect: Option<f32>, pub m_ExportTrainingData: Option<bool>, pub m_ExtractAO: Option<bool>, pub m_FilterMode: Option<i32>, pub m_FinalGather: Option<bool>, pub m_FinalGatherFiltering: Option<bool>, pub m_FinalGatherRayCount: Option<i32>, pub m_ForceUpdates: Option<bool>, pub m_ForceWhiteAlbedo: Option<bool>, pub m_IndirectOutputScale: Option<f32>, pub m_LightmapMaxSize: Option<i32>, pub m_LightmapParameters: Option<PPtr>, pub m_LightmapsBakeMode: Option<i32>, pub m_MixedBakeMode: Option<i32>, pub m_PVRBounces: Option<i32>, pub m_PVRCulling: Option<bool>, pub m_PVRDenoiserTypeAO: Option<i32>, pub m_PVRDenoiserTypeDirect: Option<i32>, pub m_PVRDenoiserTypeIndirect: Option<i32>, pub m_PVRDirectSampleCount: Option<i32>, pub m_PVREnvironmentMIS: Option<i32>, pub m_PVREnvironmentReferencePointCount: Option<i32>, pub m_PVREnvironmentSampleCount: Option<i32>, pub m_PVRFilterTypeAO: Option<i32>, pub m_PVRFilterTypeDirect: Option<i32>, pub m_PVRFilterTypeIndirect: Option<i32>, pub m_PVRFilteringAtrousPositionSigmaAO: Option<f32>, pub m_PVRFilteringAtrousPositionSigmaDirect: Option<f32>, pub m_PVRFilteringAtrousPositionSigmaIndirect: Option<f32>, pub m_PVRFilteringGaussRadiusAO: Option<i32>, pub m_PVRFilteringGaussRadiusDirect: Option<i32>, pub m_PVRFilteringGaussRadiusIndirect: Option<i32>, pub m_PVRFilteringMode: Option<i32>, pub m_PVRSampleCount: Option<i32>, pub m_PVRSampling: Option<i32>, pub m_Padding: Option<i32>, pub m_RealtimeResolution: Option<f32>, pub m_TextureCompression: Option<bool>, pub m_TrainingDataDestination: Option<String>,
}
LightingSettings is a class of the Unity engine since version 2020.1.0b1. Exert from Unity’s scripting documentation: An object containing settings for precomputing lighting data, that Unity can serialize as a Lighting Settings Asset. When the Unity Editor precomputes lighting data for a Scene that uses the Baked Global Illumination system or the Enlighten Realtime Global Illumination system, it uses settings from a LightingSettings object. The same LightingSettings object can be assigned to more than one Scene, which makes it possible to share settings across multiple Scenes.The following example shows how to create a LightingSettings object and assign it to the active Scene using the Lightmapping.lightingSettings API: The following example shows how to create a LightingSettings object, and save it to disk as a Lighting Settings Asset using the AssetDatabase.CreateAsset API. See Also: Lighting Settings Asset.

Fields

m_AlbedoBoost: f32

The intensity of surface albedo throughout the Scene when considered in lighting calculations. This value influences the energy of light at each bounce. (Editor only).

m_BounceScale: f32m_EnableBakedLightmaps: boolm_EnableRealtimeLightmaps: boolm_GIWorkflowMode: i32m_Name: String

The name of the object.

m_RealtimeEnvironmentLighting: bool

Determines the lightmap that Unity stores environment lighting in.

m_UsingShadowmask: boolm_AO: Option<bool>

Whether to apply ambient occlusion to lightmaps. (Editor only). bool: (2020.1.0a3 - 2020.1.0a12)

m_AOMaxDistance: Option<f32>

The distance that a ray travels before Unity considers it to be unoccluded when calculating ambient occlusion in lightmaps. (Editor only). f32: (2020.1.0a3 - 2020.1.0a12)

m_BakeBackend: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_BakeResolution: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_CompAOExponent: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_CompAOExponentDirect: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_ExportTrainingData: Option<bool>

Whether the Progressive Lightmapper exports machine learning training data to the Project folder when it performs the bake. ( Editor only). bool: (2020.1.0a3 - 2020.1.0a12)

m_ExtractAO: Option<bool>

Whether the Progressive Lightmapper extracts Ambient Occlusion to a separate lightmap. (Editor only). bool: (2020.1.0a3 - 2020.1.0a12)

m_FilterMode: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_FinalGather: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_FinalGatherFiltering: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_FinalGatherRayCount: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_ForceUpdates: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_ForceWhiteAlbedo: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_IndirectOutputScale: Option<f32>

f32: (2020.1.0b1 - 2022.3.2f1)

m_LightmapMaxSize: Option<i32>

The maximum size in pixels of an individual lightmap texture. (Editor only). i32: (2020.1.0a3 - 2020.1.0a12)

m_LightmapParameters: Option<PPtr>

PPtr<LightmapParameters>: (2020.1.0a3 - 2020.1.0a12)

m_LightmapsBakeMode: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_MixedBakeMode: Option<i32>

Sets the MixedLightingMode that Unity uses for all Mixed Lights in the Scene. (Editor only). i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRBounces: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRCulling: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_PVRDenoiserTypeAO: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRDenoiserTypeDirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRDenoiserTypeIndirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRDirectSampleCount: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVREnvironmentMIS: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVREnvironmentReferencePointCount: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVREnvironmentSampleCount: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilterTypeAO: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilterTypeDirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilterTypeIndirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringAtrousPositionSigmaAO: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringAtrousPositionSigmaDirect: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringAtrousPositionSigmaIndirect: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringGaussRadiusAO: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringGaussRadiusDirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringGaussRadiusIndirect: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRFilteringMode: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRSampleCount: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_PVRSampling: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_Padding: Option<i32>

i32: (2020.1.0a3 - 2020.1.0a12)

m_RealtimeResolution: Option<f32>

f32: (2020.1.0a3 - 2020.1.0a12)

m_TextureCompression: Option<bool>

bool: (2020.1.0a3 - 2020.1.0a12)

m_TrainingDataDestination: Option<String>

Determines the name of the destination folder for the exported textures. (Editor only). String: (2020.1.0a3 - 2020.1.0a12)