LightsModule

Struct LightsModule 

pub struct LightsModule {
    pub color: bool,
    pub enabled: bool,
    pub intensity: bool,
    pub intensityCurve: MinMaxCurve,
    pub light: PPtr,
    pub maxLights: i32,
    pub randomDistribution: bool,
    pub range: bool,
    pub rangeCurve: MinMaxCurve,
    pub ratio: f32,
}
LightsModule is a sub class of the Unity engine since version 5.5.0f3. Exert from Unity’s scripting documentation: Access the ParticleSystem Lights Module. This module allows you to attach real-time Lights to a percentage of your particles.The Lights Module is a simple and powerful module that allows particles to cast light onto their environment easily. Lights can inherit properties from the particles they are attached to, such as color and size. Point and Spot Lights are supported, including shadow casting and Light cookies.

Fields

color: boolenabled: bool

Specifies whether the LightsModule is enabled or disabled.

intensity: bool

Define a curve to apply custom intensity scaling to particle Lights.

intensityCurve: MinMaxCurvelight: PPtr

Select what Light Prefab you want to base your particle lights on. PPtr<Light>: (5.5.0f3 - 2022.3.2f1)

maxLights: i32

Set a limit on how many Lights this Module can create.

randomDistribution: boolrange: bool

Define a curve to apply custom range scaling to particle Lights.

rangeCurve: MinMaxCurveratio: f32

Choose what proportion of particles receive a dynamic light.