pub struct MeshCollider {Show 14 fields
pub m_Convex: bool,
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_IsTrigger: bool,
pub m_Material: PPtr,
pub m_Mesh: PPtr,
pub m_CookingOptions: Option<i32>,
pub m_ExcludeLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_InflateMesh: Option<bool>,
pub m_LayerOverridePriority: Option<i32>,
pub m_ProvidesContacts: Option<bool>,
pub m_SkinWidth: Option<f32>,
pub m_SmoothSphereCollisions: Option<bool>,
}Expand description
MeshCollider is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A mesh collider allows you to do collision detection between meshes and primitives. See Also: BoxCollider, CapsuleCollider, PhysicMaterial, Rigidbody.
Fields
m_Convex: boolUse a convex collider from the mesh.
m_Enabled: boolEnabled Colliders will collide with other Colliders, disabled Colliders won’t.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_IsTrigger: boolSpecify if this collider is configured as a trigger.
m_Material: PPtrThe material used by the collider.
PPtr<PhysicMaterial>: (3.4.0 - 2022.3.2f1)
m_Mesh: PPtrPPtr<Mesh>: (3.4.0 - 2022.3.2f1)
m_CookingOptions: Option<i32>Options used to enable or disable certain features in mesh cooking. i32: (2017.3.0b1 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional layers that this Collider should exclude when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional layers that this Collider should include when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_InflateMesh: Option<bool>bool: (5.5.0f3 - 2017.2.5f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider used when there is a conflicting decision on whether a Collider can contact another Collider. i32: (2022.2.0b1 - 2022.3.2f1)
m_ProvidesContacts: Option<bool>Whether or not this Collider generates contacts for Physics.ContactEvent. bool: (2022.2.0b1 - 2022.3.2f1)
m_SkinWidth: Option<f32>f32: (5.5.0f3 - 2018.2.21f1)
m_SmoothSphereCollisions: Option<bool>bool: (3.4.0 - 4.7.2)