pub struct MeshFilter {
pub m_GameObject: PPtr,
pub m_Mesh: PPtr,
}Expand description
MeshFilter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A class to access the Mesh of the mesh filter. Use this with a procedural mesh interface. See Also: Mesh class.
Fields
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_Mesh: PPtrReturns either a new mesh or a duplicate of the existing mesh, and assigns it to the mesh filter.
PPtr<Mesh>: (3.4.0 - 2022.3.2f1)