pub struct MeshRenderer {Show 29 fields
pub m_AdditionalVertexStreams: PPtr,
pub m_CastShadows: u8,
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_LightmapIndex: u16,
pub m_LightmapIndexDynamic: u16,
pub m_LightmapTilingOffset: Vector4f,
pub m_LightmapTilingOffsetDynamic: Vector4f,
pub m_Materials: Vec<PPtr>,
pub m_ProbeAnchor: PPtr,
pub m_ReceiveShadows: Enum_bool__u8,
pub m_ReflectionProbeUsage: i32,
pub m_SortingOrder: i16,
pub m_StaticBatchRoot: PPtr,
pub m_DynamicOccludee: Option<u8>,
pub m_EnlightenVertexStream: Option<PPtr>,
pub m_LightProbeUsage: Option<u8>,
pub m_LightProbeVolumeOverride: Option<PPtr>,
pub m_MotionVectors: Option<u8>,
pub m_RayTraceProcedural: Option<u8>,
pub m_RayTracingMode: Option<u8>,
pub m_RendererPriority: Option<i32>,
pub m_RenderingLayerMask: Option<u32>,
pub m_SortingLayer: Option<i16>,
pub m_SortingLayerID: Option<i32>,
pub m_StaticBatchInfo: Option<StaticBatchInfo>,
pub m_StaticShadowCaster: Option<u8>,
pub m_SubsetIndices: Option<Vec<u32>>,
pub m_UseLightProbes: Option<bool>,
}Expand description
MeshRenderer is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Renders meshes inserted by the MeshFilter or TextMesh.
Fields
m_AdditionalVertexStreams: PPtrVertex attributes in this mesh will override or add attributes of the primary mesh in the MeshRenderer.
PPtr<Mesh>: (5.0.0f4 - 2022.3.2f1)
m_CastShadows: u8m_Enabled: boolMakes the rendered 3D object visible if enabled.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (5.0.0f4 - 2022.3.2f1)
m_LightmapIndex: u16The index of the baked lightmap applied to this renderer.
m_LightmapIndexDynamic: u16m_LightmapTilingOffset: Vector4fm_LightmapTilingOffsetDynamic: Vector4fm_Materials: Vec<PPtr>Returns all the instantiated materials of this object.
Vec<PPtr<Material>>: (5.0.0f4 - 2022.3.2f1)
m_ProbeAnchor: PPtrIf set, Renderer will use this Transform’s position to find the light or reflection probe.
PPtr<Transform>: (5.0.0f4 - 2022.3.2f1)
m_ReceiveShadows: Enum_bool__u8Does this object receive shadows?
m_ReflectionProbeUsage: i32Should reflection probes be used for this Renderer?
m_SortingOrder: i16Renderer’s order within a sorting layer.
m_StaticBatchRoot: PPtrPPtr<Transform>: (5.0.0f4 - 2022.3.2f1)
m_DynamicOccludee: Option<u8>u8: (2017.2.0b2 - 2022.3.2f1)
m_EnlightenVertexStream: Option<PPtr>Vertex attributes that override the primary mesh when the MeshRenderer uses lightmaps in the Realtime Global Illumination system.
PPtr<Mesh>: (2020.1.0b1 - 2022.3.2f1)
m_LightProbeUsage: Option<u8>The light probe interpolation type. u8: (5.4.0f3 - 2022.3.2f1)
m_LightProbeVolumeOverride: Option<PPtr>PPtr<GameObject>: (5.4.0f3 - 2022.3.2f1)
m_MotionVectors: Option<u8>u8: (5.4.0f3 - 2022.3.2f1)
m_RayTraceProcedural: Option<u8>u8: (2020.1.0b1 - 2022.3.2f1)
m_RayTracingMode: Option<u8>Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)
m_RendererPriority: Option<i32>This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)
m_RenderingLayerMask: Option<u32>Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)
m_SortingLayer: Option<i16>i16: (5.6.0b1 - 2022.3.2f1)
m_SortingLayerID: Option<i32>Unique ID of the Renderer’s sorting layer. i32: (5.0.0f4 - 2022.3.2f1)
m_StaticBatchInfo: Option<StaticBatchInfo>StaticBatchInfo: (5.5.0f3 - 2022.3.2f1)
m_StaticShadowCaster: Option<u8>Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)
m_SubsetIndices: Option<Vec<u32>>Vec
m_UseLightProbes: Option<bool>bool: (5.0.0f4 - 5.3.8f2)