MinMaxGradient

Struct MinMaxGradient 

pub struct MinMaxGradient {
    pub maxColor: ColorRGBA,
    pub maxGradient: Enum_GradientNEW__Gradient,
    pub minColor: ColorRGBA,
    pub minGradient: Enum_GradientNEW__Gradient,
    pub minMaxState: i32,
}
MinMaxGradient is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for a Min-Max Gradient. This contains two Gradients, and returns a Color based on ParticleSystem.MinMaxGradient.mode. Depending on the mode, this may return the value randomized.

Gradients are edited via the ParticleSystem Inspector once a ParticleSystemGradientMode requiring them has been selected. Some modes do not require gradients, only colors.

See Also: ParticleSystem.

Fields

maxColor: ColorRGBAmaxGradient: Enum_GradientNEW__GradientminColor: ColorRGBAminGradient: Enum_GradientNEW__GradientminMaxState: i32