pub struct NoiseModule {Show 19 fields
pub damping: bool,
pub enabled: bool,
pub frequency: f32,
pub octaveMultiplier: f32,
pub octaveScale: f32,
pub octaves: i32,
pub quality: i32,
pub remap: MinMaxCurve,
pub remapEnabled: bool,
pub remapY: MinMaxCurve,
pub remapZ: MinMaxCurve,
pub scrollSpeed: MinMaxCurve,
pub separateAxes: bool,
pub strength: MinMaxCurve,
pub strengthY: MinMaxCurve,
pub strengthZ: MinMaxCurve,
pub positionAmount: Option<MinMaxCurve>,
pub rotationAmount: Option<MinMaxCurve>,
pub sizeAmount: Option<MinMaxCurve>,
}Expand description
NoiseModule is a sub class of the Unity engine since version 5.5.0f3. Exert from Unity’s scripting documentation: Script interface for the NoiseModule. The Noise Module allows you to apply turbulence to the movement of your particles. Use the low quality settings to create computationally efficient Noise, or simulate smoother, richer Noise with the higher quality settings. You can also choose to define the behavior of the Noise individually for each axis.See Also: ParticleSystem, ParticleSystem.noise.
Fields
damping: boolHigher frequency noise reduces the strength by a proportional amount, if enabled.
enabled: boolSpecifies whether the the NoiseModule is enabled or disabled.
frequency: f32Low values create soft, smooth noise, and high values create rapidly changing noise.
octaveMultiplier: f32When combining each octave, scale the intensity by this amount.
octaveScale: f32When combining each octave, zoom in by this amount.
octaves: i32quality: i32Generate 1D, 2D or 3D noise.
remap: MinMaxCurveDefine how the noise values are remapped.
remapEnabled: boolEnable remapping of the final noise values, allowing for noise values to be translated into different values.
remapY: MinMaxCurveDefine how the noise values are remapped on the y-axis, when using the ParticleSystem.NoiseModule.separateAxes option.
remapZ: MinMaxCurveDefine how the noise values are remapped on the z-axis, when using the ParticleSystem.NoiseModule.separateAxes option.
scrollSpeed: MinMaxCurveScroll the noise map over the Particle System.
separateAxes: boolControl the noise separately for each axis.
strength: MinMaxCurveHow strong the overall noise effect is.
strengthY: MinMaxCurveDefine the strength of the effect on the y-axis, when using the ParticleSystem.NoiseModule.separateAxes option.
strengthZ: MinMaxCurveDefine the strength of the effect on the z-axis, when using the ParticleSystem.NoiseModule.separateAxes option.
positionAmount: Option<MinMaxCurve>How much the noise affects the particle positions. MinMaxCurve: (2017.1.0b2 - 2022.3.2f1)
rotationAmount: Option<MinMaxCurve>How much the noise affects the particle rotation, in degrees per second. MinMaxCurve: (2017.1.0b2 - 2022.3.2f1)
sizeAmount: Option<MinMaxCurve>How much the noise affects the particle sizes, applied as a multiplier on the size of each particle. MinMaxCurve: (2017.1.0b2 - 2022.3.2f1)