pub struct OcclusionArea {
pub m_Center: Vector3f,
pub m_GameObject: PPtr,
pub m_IsViewVolume: bool,
pub m_Size: Vector3f,
pub m_IsTargetVolume: Option<bool>,
pub m_TargetResolution: Option<i32>,
}Expand description
OcclusionArea is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: OcclusionArea is an area in which occlusion culling is performed.
Fields
m_Center: Vector3fCenter of the occlusion area relative to the transform.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_IsViewVolume: boolm_Size: Vector3fSize that the occlusion area will have.
m_IsTargetVolume: Option<bool>bool: (3.4.0 - 4.2.2)
m_TargetResolution: Option<i32>i32: (3.4.0 - 4.2.2)