pub struct OcclusionPortal {
pub m_Center: Vector3f,
pub m_GameObject: PPtr,
pub m_Open: bool,
pub m_Size: Vector3f,
}Expand description
OcclusionPortal is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: The portal for dynamically changing occlusion at runtime.
Fields
m_Center: Vector3fm_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.5.0 - 2022.3.2f1)
m_Open: boolGets / sets the portal’s open state.
m_Size: Vector3fTrait Implementations
Sourceimpl Debug for OcclusionPortal
impl Debug for OcclusionPortal
Sourceimpl<'de> Deserialize<'de> for OcclusionPortal
impl<'de> Deserialize<'de> for OcclusionPortal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more