pub struct OffMeshLink {
pub m_Activated: bool,
pub m_BiDirectional: bool,
pub m_CostOverride: f32,
pub m_End: PPtr,
pub m_GameObject: PPtr,
pub m_Start: PPtr,
pub m_AgentTypeID: Option<i32>,
pub m_AreaIndex: Option<u32>,
pub m_AutoUpdatePositions: Option<bool>,
pub m_DtPolyRef: Option<u32>,
pub m_Enabled: Option<u8>,
pub m_NavMeshLayer: Option<u32>,
}Expand description
OffMeshLink is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Link allowing movement outside the planar navigation mesh.
Fields
m_Activated: boolIs link active.
m_BiDirectional: boolCan link be traversed in both directions.
m_CostOverride: f32Modify pathfinding cost for the link.
m_End: PPtrPPtr<Transform>: (3.5.0 - 2022.3.2f1)
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.5.0 - 2022.3.2f1)
m_Start: PPtrPPtr<Transform>: (3.5.0 - 2022.3.2f1)
m_AgentTypeID: Option<i32>i32: (5.6.0b1 - 2022.3.2f1)
m_AreaIndex: Option<u32>u32: (5.0.0f4 - 2022.3.2f1)
m_AutoUpdatePositions: Option<bool>Automatically update endpoints. bool: (4.3.0 - 2022.3.2f1)
m_DtPolyRef: Option<u32>u32: (3.5.0 - 4.7.2)
m_Enabled: Option<u8>Enabled Behaviours are Updated, disabled Behaviours are not. u8: (4.3.0 - 2022.3.2f1)
u32: (4.0.0 - 4.7.2)