pub struct PackedAssets {
pub m_Contents: Vec<BuildReportPackedAssetInfo>,
pub m_Overhead: u64,
pub m_ShortPath: String,
pub m_File: Option<u32>,
}Expand description
PackedAssets is a class of the Unity engine since version 5.4.0f3. Exert from Unity’s scripting documentation: An extension to the BuildReport class that tracks how Assets contribute to the size of the build. The build process generates a PackedAssets report for each .sharedAssets or .resource file, or for each AssetBundle.
Fields
m_Contents: Vec<BuildReportPackedAssetInfo>An array of PackedAssetInfo objects that holds information about the Assets that are included in the PackedAssets bundle, such as packed Asset size and type.
m_Overhead: u64The header size of the packed Asset file.
m_ShortPath: StringThe file path to the Asset package, relative to the Data folder of the build.
m_File: Option<u32>u32: (5.4.0f3 - 2021.2.0a11)