pub struct PerformanceReportingSettings {
pub m_Enabled: bool,
}Expand description
PerformanceReportingSettings is a sub class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: Normally performance reporting is enabled from the Services window, but if writing your own editor extension, this API can be used.
Fields
m_Enabled: boolTrait Implementations
Sourceimpl Debug for PerformanceReportingSettings
impl Debug for PerformanceReportingSettings
Sourceimpl<'de> Deserialize<'de> for PerformanceReportingSettings
impl<'de> Deserialize<'de> for PerformanceReportingSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more