pub struct PhysicsMaterial2D {
pub bounciness: f32,
pub friction: f32,
pub m_Name: String,
}Expand description
PhysicsMaterial2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Asset type that defines the surface properties of a Collider2D. Note: the 3D equivalent of this class is spelt as “PhysicMaterial” with no S, but this class is spelt “PhysicsMaterial” with an S.See Also: PhysicMaterial class.
Fields
bounciness: f32The degree of elasticity during collisions.
friction: f32Coefficient of friction.
m_Name: StringThe name of the object.