pub struct PlayableDirector {
pub m_DirectorUpdateMode: i32,
pub m_Enabled: u8,
pub m_ExposedReferences: ExposedReferenceTable,
pub m_GameObject: PPtr,
pub m_InitialState: i32,
pub m_InitialTime: f64,
pub m_PlayableAsset: PPtr,
pub m_SceneBindings: Vec<DirectorGenericBinding>,
pub m_WrapMode: i32,
}Expand description
PlayableDirector is a class of the Unity engine since version 2017.1.0b1. Exert from Unity’s scripting documentation: Instantiates a PlayableAsset and controls playback of Playable objects.
Fields
m_DirectorUpdateMode: i32m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_ExposedReferences: ExposedReferenceTablem_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2017.1.0b1 - 2022.3.2f1)
m_InitialState: i32m_InitialTime: f64The time at which the Playable should start when first played.
m_PlayableAsset: PPtrThe PlayableAsset that is used to instantiate a playable for playback.
PPtr<[Object]>: (2017.1.0b1 - 2022.3.2f1)
m_SceneBindings: Vec<DirectorGenericBinding>m_WrapMode: i32Trait Implementations
Sourceimpl Debug for PlayableDirector
impl Debug for PlayableDirector
Sourceimpl<'de> Deserialize<'de> for PlayableDirector
impl<'de> Deserialize<'de> for PlayableDirector
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more