PlayerSettings

Struct PlayerSettings 

pub struct PlayerSettings {
Show 232 fields pub AndroidProfiler: bool, pub allowedAutorotateToLandscapeLeft: bool, pub allowedAutorotateToLandscapeRight: bool, pub allowedAutorotateToPortrait: bool, pub allowedAutorotateToPortraitUpsideDown: bool, pub captureSingleScreen: bool, pub companyName: String, pub defaultScreenHeight: i32, pub defaultScreenHeightWeb: i32, pub defaultScreenOrientation: i32, pub defaultScreenWidth: i32, pub defaultScreenWidthWeb: i32, pub productName: String, pub runInBackground: bool, pub targetDevice: i32, pub use32BitDisplayBuffer: bool, pub useMacAppStoreValidation: bool, pub useOSAutorotation: bool, pub usePlayerLog: bool, pub AID: Option<Hash128>, pub AndroidEnableSustainedPerformanceMode: Option<bool>, pub AndroidFilterTouchesWhenObscured: Option<bool>, pub AndroidLicensePublicKey: Option<String>, pub D3DHDRBitDepth: Option<i32>, pub Force_IOS_Speakers_When_Recording: Option<bool>, pub Override_IPod_Music: Option<bool>, pub Prepare_IOS_For_Recording: Option<bool>, pub accelerometerFrequency: Option<i32>, pub activeInputHandler: Option<i32>, pub allowFullscreenSwitch: Option<bool>, pub androidBlitType: Option<i32>, pub androidDefaultWindowHeight: Option<i32>, pub androidDefaultWindowWidth: Option<i32>, pub androidFullscreenMode: Option<i32>, pub androidMaxAspectRatio: Option<f32>, pub androidMinimumWindowHeight: Option<i32>, pub androidMinimumWindowWidth: Option<i32>, pub androidRenderOutsideSafeArea: Option<bool>, pub androidResizableWindow: Option<bool>, pub androidShowActivityIndicatorOnLoading: Option<i32>, pub androidStartInFullscreen: Option<bool>, pub androidSupportedAspectRatio: Option<i32>, pub androidUseSwappy: Option<bool>, pub bakeCollisionMeshes: Option<bool>, pub bundleIdentifier: Option<String>, pub bundleVersion: Option<String>, pub cloudEnabled: Option<bool>, pub cloudProjectId: Option<String>, pub cpuConfiguration: Option<Vec<i32>>, pub cursorHotspot: Option<Vector2f>, pub d3d11ForceExclusiveMode: Option<bool>, pub d3d11FullscreenMode: Option<i32>, pub d3d9FullscreenMode: Option<i32>, pub debugUnloadMode: Option<i32>, pub defaultCursor: Option<PPtr>, pub defaultIsFullScreen: Option<bool>, pub defaultIsNativeResolution: Option<bool>, pub deferSystemGesturesMode: Option<i32>, pub disableDepthAndStencilBuffers: Option<bool>, pub disableOldInputManagerSupport: Option<bool>, pub displayResolutionDialog: Option<i32>, pub enableFrameTimingStats: Option<bool>, pub enableGamepadInput: Option<bool>, pub enableHWStatistics: Option<bool>, pub enableNativePlatformBackendsForNewInputSystem: Option<bool>, pub enableNewInputSystem: Option<bool>, pub enableOpenGLProfilerGPURecorders: Option<bool>, pub forceSRGBBlit: Option<bool>, pub forceSingleInstance: Option<bool>, pub framebufferDepthMemorylessMode: Option<i32>, pub fullscreenMode: Option<i32>, pub gpuSkinning: Option<bool>, pub graphicsJobMode: Option<i32>, pub graphicsJobs: Option<bool>, pub hdrBitDepth: Option<i32>, pub hideHomeButton: Option<bool>, pub hmiLoadingImage: Option<PPtr>, pub iPhoneBundleIdentifier: Option<String>, pub ignoreAlphaClear: Option<bool>, pub insecureHttpOption: Option<i32>, pub invalidatedPatternTexture: Option<PPtr>, pub iosAllowHTTPDownload: Option<bool>, pub iosAppInBackgroundBehavior: Option<i32>, pub iosShowActivityIndicatorOnLoading: Option<i32>, pub iosUseCustomAppBackgroundBehavior: Option<bool>, pub isWsaHolographicRemotingEnabled: Option<bool>, pub legacyClampBlendShapeWeights: Option<bool>, pub loadStoreDebugModeEnabled: Option<bool>, pub m_ActiveColorSpace: Option<i32>, pub m_ColorGamuts: Option<Vec<i32>>, pub m_HolographicPauseOnTrackingLoss: Option<bool>, pub m_HolographicTrackingLossScreen: Option<PPtr>, pub m_MTRendering: Option<bool>, pub m_MobileMTRendering: Option<bool>, pub m_MobileRenderingPath: Option<i32>, pub m_RenderingPath: Option<i32>, pub m_ShowUnitySplashLogo: Option<bool>, pub m_ShowUnitySplashScreen: Option<bool>, pub m_SplashScreenAnimation: Option<i32>, pub m_SplashScreenBackgroundAnimationZoom: Option<f32>, pub m_SplashScreenBackgroundColor: Option<ColorRGBA>, pub m_SplashScreenBackgroundLandscape: Option<PPtr>, pub m_SplashScreenBackgroundLandscapeAspect: Option<f32>, pub m_SplashScreenBackgroundLandscapeUvs: Option<Rectf>, pub m_SplashScreenBackgroundPortrait: Option<PPtr>, pub m_SplashScreenBackgroundPortraitAspect: Option<f32>, pub m_SplashScreenBackgroundPortraitUvs: Option<Rectf>, pub m_SplashScreenDrawMode: Option<i32>, pub m_SplashScreenLogoAnimationZoom: Option<f32>, pub m_SplashScreenLogoStyle: Option<i32>, pub m_SplashScreenLogos: Option<Vec<SplashScreenLogo>>, pub m_SplashScreenOverlayOpacity: Option<f32>, pub m_SplashScreenStyle: Option<i32>, pub m_SpriteBatchVertexThreshold: Option<i32>, pub m_StackTraceTypes: Option<Vec<i32>>, pub m_StereoRenderingPath: Option<i32>, pub m_Stereoscopic3D: Option<bool>, pub m_SupportedAspectRatios: Option<AspectRatios>, pub m_UnitySplashLogo: Option<PPtr>, pub m_UseDX11: Option<bool>, pub m_VirtualRealitySplashScreen: Option<PPtr>, pub macAppStoreCategory: Option<String>, pub macFullscreenMode: Option<i32>, pub macRetinaSupport: Option<bool>, pub metalFramebufferOnly: Option<bool>, pub metroEnableIndependentInputSource: Option<bool>, pub metroEnableLowLatencyPresentationAPI: Option<bool>, pub metroInputSource: Option<i32>, pub mipStripping: Option<bool>, pub mobileMTRenderingBaked: Option<bool>, pub muteOtherAudioSources: Option<bool>, pub n3dsDisableStereoscopicView: Option<bool>, pub n3dsEnableSharedListOpt: Option<bool>, pub n3dsEnableVSync: Option<bool>, pub numberOfMipsStripped: Option<i32>, pub numberOfMipsStrippedPerMipmapLimitGroup: Option<Vec<(String, i32)>>, pub organizationId: Option<String>, pub platformRequiresReadableAssets: Option<bool>, pub playerDataPath: Option<String>, pub playerMinOpenGLESVersion: Option<i32>, pub preloadedAssets: Option<Vec<PPtr>>, pub preserveFramebufferAlpha: Option<bool>, pub productGUID: Option<GUID>, pub projectId: Option<String>, pub projectName: Option<String>, pub protectGraphicsMemory: Option<bool>, pub ps3SplashScreen: Option<PPtr>, pub psp2AcquireBGM: Option<bool>, pub psp2PowerMode: Option<i32>, pub qualitySettingsNames: Option<Vec<String>>, pub resetResolutionOnWindowResize: Option<bool>, pub resizableWindow: Option<bool>, pub resolutionScalingMode: Option<i32>, pub singlePassStereoRendering: Option<bool>, pub stadiaPresentMode: Option<i32>, pub stadiaTargetFramerate: Option<i32>, pub stripPhysics: Option<bool>, pub submitAnalytics: Option<bool>, pub switchAllowGpuScratchShrinking: Option<bool>, pub switchGpuScratchPoolGranularity: Option<i32>, pub switchNVNDefaultPoolsGranularity: Option<i32>, pub switchNVNGraphicsFirmwareMemory: Option<i32>, pub switchNVNMaxPublicSamplerIDCount: Option<i32>, pub switchNVNMaxPublicTextureIDCount: Option<i32>, pub switchNVNOtherPoolsGranularity: Option<i32>, pub switchNVNShaderPoolsGranularity: Option<i32>, pub switchQueueCommandMemory: Option<i32>, pub switchQueueComputeMemory: Option<i32>, pub switchQueueControlMemory: Option<i32>, pub targetGlesGraphics: Option<i32>, pub targetIOSGraphics: Option<i32>, pub targetPixelDensity: Option<i32>, pub targetPlatform: Option<i32>, pub targetResolution: Option<i32>, pub tizenShowActivityIndicatorOnLoading: Option<i32>, pub uiUse16BitDepthBuffer: Option<bool>, pub uploadClearedTextureDataAfterCreationFromScript: Option<bool>, pub use24BitDepthBuffer: Option<bool>, pub useAlphaInDashboard: Option<bool>, pub useFlipModelSwapchain: Option<bool>, pub useHDRDisplay: Option<bool>, pub useOnDemandResources: Option<bool>, pub videoMemoryForVertexBuffers: Option<i32>, pub virtualRealitySupported: Option<bool>, pub virtualTexturingSupportEnabled: Option<bool>, pub visibleInBackground: Option<bool>, pub vrSettings: Option<VRSettings>, pub vulkanEnableCommandBufferRecycling: Option<bool>, pub vulkanEnableLateAcquireNextImage: Option<bool>, pub vulkanEnablePreTransform: Option<bool>, pub vulkanEnableSetSRGBWrite: Option<bool>, pub vulkanNumSwapchainBuffers: Option<u32>, pub vulkanUseSWCommandBuffers: Option<bool>, pub wiiHio2Usage: Option<i32>, pub wiiLoadingScreenBackground: Option<ColorRGBA>, pub wiiLoadingScreenFileName: Option<String>, pub wiiLoadingScreenPeriod: Option<i32>, pub wiiLoadingScreenRect: Option<Rectf>, pub wiiLoadingScreenRectPlacement: Option<i32>, pub wiiUAllowScreenCapture: Option<bool>, pub wiiUControllerCount: Option<i32>, pub wiiUGamePadMSAA: Option<i32>, pub wiiUSupportsBalanceBoard: Option<bool>, pub wiiUSupportsClassicController: Option<bool>, pub wiiUSupportsMotionPlus: Option<bool>, pub wiiUSupportsNunchuk: Option<bool>, pub wiiUSupportsProController: Option<bool>, pub wiiUTVResolution: Option<i32>, pub windowsGamepadBackendHint: Option<i32>, pub wsaTransparentSwapchain: Option<bool>, pub xboxEnableAvatar: Option<bool>, pub xboxEnableEnableRenderThreadRunsJobs: Option<bool>, pub xboxEnableFitness: Option<bool>, pub xboxEnableGuest: Option<bool>, pub xboxEnableHeadOrientation: Option<bool>, pub xboxEnableKinect: Option<bool>, pub xboxEnableKinectAutoTracking: Option<bool>, pub xboxEnablePIXSampling: Option<bool>, pub xboxEnableSpeech: Option<bool>, pub xboxOneDisableEsram: Option<bool>, pub xboxOneDisableKinectGpuReservation: Option<bool>, pub xboxOneEnable7thCore: Option<bool>, pub xboxOneEnableTypeOptimization: Option<bool>, pub xboxOneLoggingLevel: Option<i32>, pub xboxOneMonoLoggingLevel: Option<i32>, pub xboxOnePresentImmediateThreshold: Option<u32>, pub xboxOneResolution: Option<i32>, pub xboxOneSResolution: Option<i32>, pub xboxOneXResolution: Option<i32>, pub xboxPIXTextureCapture: Option<bool>, pub xboxSkinOnGPU: Option<bool>, pub xboxSpeechDB: Option<u32>,
}
PlayerSettings is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Player Settings is where you define various parameters for the final game that you will build in Unity. Some of these values are used in the Resolution Dialog that launches when you open a standalone game.

Fields

AndroidProfiler: boolallowedAutorotateToLandscapeLeft: boolallowedAutorotateToLandscapeRight: boolallowedAutorotateToPortrait: boolallowedAutorotateToPortraitUpsideDown: boolcaptureSingleScreen: boolcompanyName: StringdefaultScreenHeight: i32defaultScreenHeightWeb: i32defaultScreenOrientation: i32defaultScreenWidth: i32defaultScreenWidthWeb: i32productName: StringrunInBackground: booltargetDevice: i32use32BitDisplayBuffer: booluseMacAppStoreValidation: booluseOSAutorotation: boolusePlayerLog: boolAID: Option<Hash128>

Hash128: (2020.2.0b1 - 2022.3.2f1)

AndroidEnableSustainedPerformanceMode: Option<bool>

bool: (2018.1.0b2 - 2022.3.2f1)

AndroidFilterTouchesWhenObscured: Option<bool>

bool: (2017.2.0b2 - 2022.3.2f1)

AndroidLicensePublicKey: Option<String>

String: (3.4.0 - 3.5.7)

D3DHDRBitDepth: Option<i32>

i32: (2019.3.0b1 - 2022.2.14f1)

Force_IOS_Speakers_When_Recording: Option<bool>

bool: (2022.3.2f1 - 2022.3.2f1)

Override_IPod_Music: Option<bool>

bool: (3.4.0 - 5.4.6f3)

Prepare_IOS_For_Recording: Option<bool>

bool: (2022.3.2f1 - 2022.3.2f1)

accelerometerFrequency: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

activeInputHandler: Option<i32>

i32: (2020.2.0f1 - 2022.3.2f1)

allowFullscreenSwitch: Option<bool>

bool: (5.3.0f1 - 2022.3.2f1)

androidBlitType: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

androidDefaultWindowHeight: Option<i32>

i32: (2019.4.31f1 - 2022.3.2f1)

androidDefaultWindowWidth: Option<i32>

i32: (2019.4.31f1 - 2022.3.2f1)

androidFullscreenMode: Option<i32>

i32: (2019.4.31f1 - 2022.3.2f1)

androidMaxAspectRatio: Option<f32>

f32: (2017.2.0b2 - 2022.3.2f1)

androidMinimumWindowHeight: Option<i32>

i32: (2019.4.31f1 - 2022.3.2f1)

androidMinimumWindowWidth: Option<i32>

i32: (2019.4.31f1 - 2022.3.2f1)

androidRenderOutsideSafeArea: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

androidResizableWindow: Option<bool>

bool: (2019.4.31f1 - 2022.3.2f1)

androidShowActivityIndicatorOnLoading: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

androidStartInFullscreen: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

androidSupportedAspectRatio: Option<i32>

i32: (2017.2.0b2 - 2022.3.2f1)

androidUseSwappy: Option<bool>

bool: (2019.2.0b1 - 2022.3.2f1)

bakeCollisionMeshes: Option<bool>

bool: (5.0.0f4 - 2022.3.2f1)

bundleIdentifier: Option<String>

String: (5.0.0f4 - 5.6.0b5)

bundleVersion: Option<String>

String: (5.0.0f4 - 2022.3.2f1)

cloudEnabled: Option<bool>

bool: (5.1.0f1 - 2022.3.2f1)

cloudProjectId: Option<String>

String: (5.0.0f4 - 2022.3.2f1)

cpuConfiguration: Option<Vec<i32>>

Vec: (2022.2.0b3 - 2022.2.0b8)

cursorHotspot: Option<Vector2f>

Vector2f: (4.0.0 - 2022.3.2f1)

d3d11ForceExclusiveMode: Option<bool>

bool: (4.5.5 - 4.7.2)

d3d11FullscreenMode: Option<i32>

i32: (5.0.0f4 - 2017.4.40f1)

d3d9FullscreenMode: Option<i32>

i32: (4.5.3 - 2017.2.5f1)

debugUnloadMode: Option<i32>

i32: (3.5.5 - 3.5.7)

defaultCursor: Option<PPtr>

PPtr<Texture2D>: (4.0.0 - 2022.3.2f1)

defaultIsFullScreen: Option<bool>

bool: (3.4.0 - 2017.4.40f1)

defaultIsNativeResolution: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

deferSystemGesturesMode: Option<i32>

i32: (5.6.5f1 - 2022.3.2f1)

disableDepthAndStencilBuffers: Option<bool>

bool: (5.0.0f4 - 2022.3.2f1)

disableOldInputManagerSupport: Option<bool>

bool: (2017.1.0b2 - 2020.2.0a21)

displayResolutionDialog: Option<i32>

i32: (3.4.0 - 2019.3.0a10)

enableFrameTimingStats: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

enableGamepadInput: Option<bool>

bool: (2022.2.0b3 - 2022.2.0b8)

enableHWStatistics: Option<bool>

bool: (4.1.0 - 4.7.2)

enableNativePlatformBackendsForNewInputSystem: Option<bool>

bool: (2017.1.0b2 - 2020.2.0a21)

enableNewInputSystem: Option<bool>

bool: (5.6.0b1 - 2017.1.0b1)

enableOpenGLProfilerGPURecorders: Option<bool>

bool: (2021.3.2f1 - 2022.3.2f1)

forceSRGBBlit: Option<bool>

bool: (2021.2.0b1 - 2022.2.0a18)

forceSingleInstance: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

framebufferDepthMemorylessMode: Option<i32>

i32: (2018.3.0f2 - 2022.3.2f1)

fullscreenMode: Option<i32>

i32: (2018.1.0b2 - 2022.3.2f1)

gpuSkinning: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

graphicsJobMode: Option<i32>

i32: (5.5.2f1 - 2019.3.0a12)

graphicsJobs: Option<bool>

bool: (5.4.0f3 - 2019.3.0a11)

hdrBitDepth: Option<i32>

i32: (2022.2.15f1 - 2022.3.2f1)

hideHomeButton: Option<bool>

bool: (5.6.5f1 - 2022.3.2f1)

hmiLoadingImage: Option<PPtr>

PPtr<Texture2D>: (2022.2.0f1 - 2022.3.2f1)

iPhoneBundleIdentifier: Option<String>

String: (4.1.2 - 4.7.2)

ignoreAlphaClear: Option<bool>

bool: (5.3.1f1 - 2017.2.5f1)

insecureHttpOption: Option<i32>

i32: (2022.1.0b1 - 2022.3.2f1)

invalidatedPatternTexture: Option<PPtr>

PPtr<Texture2D>: (2022.2.3f1 - 2022.3.2f1)

iosAllowHTTPDownload: Option<bool>

bool: (5.2.1f1 - 2021.3.27f1)

iosAppInBackgroundBehavior: Option<i32>

i32: (5.0.0f4 - 2019.3.0a11)

iosShowActivityIndicatorOnLoading: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

iosUseCustomAppBackgroundBehavior: Option<bool>

bool: (2017.4.40f1 - 2022.3.2f1)

isWsaHolographicRemotingEnabled: Option<bool>

bool: (2018.2.9f1 - 2022.3.2f1)

legacyClampBlendShapeWeights: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

loadStoreDebugModeEnabled: Option<bool>

bool: (2022.2.0b1 - 2022.3.2f1)

m_ActiveColorSpace: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

m_ColorGamuts: Option<Vec<i32>>

Vec: (2017.2.0b2 - 2022.3.2f1)

m_HolographicPauseOnTrackingLoss: Option<bool>

bool: (5.5.0f3 - 2022.3.2f1)

m_HolographicTrackingLossScreen: Option<PPtr>

PPtr<Texture2D>: (5.5.0f3 - 2022.3.2f1)

m_MTRendering: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

m_MobileMTRendering: Option<bool>

bool: (4.3.0 - 2017.1.5f1)

m_MobileRenderingPath: Option<i32>

i32: (4.3.0 - 5.4.6f3)

m_RenderingPath: Option<i32>

i32: (3.4.0 - 5.4.6f3)

bool: (5.5.0f3 - 2022.3.2f1)

m_ShowUnitySplashScreen: Option<bool>

bool: (5.0.1f1 - 2022.3.2f1)

m_SplashScreenAnimation: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundAnimationZoom: Option<f32>

f32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundColor: Option<ColorRGBA>

ColorRGBA: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundLandscape: Option<PPtr>

PPtr<Texture2D>: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundLandscapeAspect: Option<f32>

f32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundLandscapeUvs: Option<Rectf>

Rectf: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundPortrait: Option<PPtr>

PPtr<Texture2D>: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundPortraitAspect: Option<f32>

f32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenBackgroundPortraitUvs: Option<Rectf>

Rectf: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenDrawMode: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenLogoAnimationZoom: Option<f32>

f32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenLogoStyle: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenLogos: Option<Vec<SplashScreenLogo>>

Vec: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenOverlayOpacity: Option<f32>

f32: (5.5.0f3 - 2022.3.2f1)

m_SplashScreenStyle: Option<i32>

i32: (5.4.0f3 - 5.4.6f3)

m_SpriteBatchVertexThreshold: Option<i32>

i32: (2022.1.0b1 - 2022.3.2f1)

m_StackTraceTypes: Option<Vec<i32>>

Vec: (5.4.0f3 - 2022.3.2f1)

m_StereoRenderingPath: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

m_Stereoscopic3D: Option<bool>

bool: (4.5.0 - 5.3.8f2)

m_SupportedAspectRatios: Option<AspectRatios>

AspectRatios: (3.4.0 - 2022.1.24f1)

PPtr<Sprite>: (2022.2.0b1 - 2022.3.2f1)

m_UseDX11: Option<bool>

bool: (4.0.0 - 5.0.4f1)

m_VirtualRealitySplashScreen: Option<PPtr>

PPtr<Texture2D>: (5.3.0f1 - 2022.3.2f1)

macAppStoreCategory: Option<String>

String: (5.6.1f1 - 2022.3.2f1)

macFullscreenMode: Option<i32>

i32: (4.0.0 - 2017.4.40f1)

macRetinaSupport: Option<bool>

bool: (2017.2.0b2 - 2022.3.2f1)

metalFramebufferOnly: Option<bool>

bool: (2017.2.0b2 - 2022.3.2f1)

metroEnableIndependentInputSource: Option<bool>

bool: (4.3.3 - 5.4.6f3)

metroEnableLowLatencyPresentationAPI: Option<bool>

bool: (4.3.3 - 5.3.8f2)

metroInputSource: Option<i32>

i32: (5.5.0f3 - 2022.3.2f1)

mipStripping: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

mobileMTRenderingBaked: Option<bool>

bool: (2017.2.0b2 - 2022.3.2f1)

muteOtherAudioSources: Option<bool>

bool: (5.3.8f1 - 2022.3.2f1)

n3dsDisableStereoscopicView: Option<bool>

bool: (5.2.0f2 - 2018.2.21f1)

n3dsEnableSharedListOpt: Option<bool>

bool: (5.2.0f2 - 2018.2.21f1)

n3dsEnableVSync: Option<bool>

bool: (5.2.0f2 - 2018.2.21f1)

numberOfMipsStripped: Option<i32>

i32: (2020.1.0b1 - 2022.3.2f1)

numberOfMipsStrippedPerMipmapLimitGroup: Option<Vec<(String, i32)>>

Vec<(String, i32)>: (2022.2.3f1 - 2022.3.2f1)

organizationId: Option<String>

String: (5.1.0f1 - 2022.3.2f1)

platformRequiresReadableAssets: Option<bool>

bool: (2022.2.19f1 - 2022.3.2f1)

playerDataPath: Option<String>

String: (2021.2.0b1 - 2022.2.0a18)

playerMinOpenGLESVersion: Option<i32>

i32: (2020.2.0f1 - 2022.3.2f1)

preloadedAssets: Option<Vec<PPtr>>

Vec<PPtr<[Object]>>: (5.0.0f4 - 2022.3.2f1)

preserveFramebufferAlpha: Option<bool>

bool: (2017.3.0b2 - 2022.3.2f1)

productGUID: Option<GUID>

GUID: (5.4.0f3 - 2022.3.2f1)

projectId: Option<String>

String: (5.1.0f1 - 5.1.5f1)

projectName: Option<String>

String: (5.1.0f1 - 2022.3.2f1)

protectGraphicsMemory: Option<bool>

bool: (5.4.0f3 - 2019.3.0a12)

ps3SplashScreen: Option<PPtr>

PPtr<Texture2D>: (5.0.0f4 - 5.4.6f3)

psp2AcquireBGM: Option<bool>

bool: (5.0.0f4 - 2018.2.21f1)

psp2PowerMode: Option<i32>

i32: (5.0.0f4 - 2018.2.21f1)

qualitySettingsNames: Option<Vec<String>>

Vec: (2020.2.0b1 - 2022.3.2f1)

resetResolutionOnWindowResize: Option<bool>

bool: (2020.3.35f1 - 2022.3.2f1)

resizableWindow: Option<bool>

bool: (4.0.0 - 2022.3.2f1)

resolutionScalingMode: Option<i32>

i32: (2017.1.0b1 - 2022.3.2f1)

singlePassStereoRendering: Option<bool>

bool: (5.4.0f3 - 5.4.6f3)

stadiaPresentMode: Option<i32>

i32: (2019.3.15f1 - 2022.3.2f1)

stadiaTargetFramerate: Option<i32>

i32: (2019.3.15f1 - 2022.3.2f1)

stripPhysics: Option<bool>

bool: (4.0.0 - 4.7.2)

submitAnalytics: Option<bool>

bool: (5.0.0f4 - 2022.3.2f1)

switchAllowGpuScratchShrinking: Option<bool>

bool: (2022.1.0b1 - 2022.3.2f1)

switchGpuScratchPoolGranularity: Option<i32>

i32: (2022.1.0b1 - 2022.3.2f1)

switchNVNDefaultPoolsGranularity: Option<i32>

i32: (2018.3.5f1 - 2022.3.2f1)

switchNVNGraphicsFirmwareMemory: Option<i32>

i32: (2022.1.0b1 - 2022.3.2f1)

switchNVNMaxPublicSamplerIDCount: Option<i32>

i32: (2018.4.26f1 - 2022.3.2f1)

switchNVNMaxPublicTextureIDCount: Option<i32>

i32: (2018.4.26f1 - 2022.3.2f1)

switchNVNOtherPoolsGranularity: Option<i32>

i32: (2018.3.5f1 - 2022.3.2f1)

switchNVNShaderPoolsGranularity: Option<i32>

i32: (2018.3.5f1 - 2022.3.2f1)

switchQueueCommandMemory: Option<i32>

i32: (2018.1.0f2 - 2022.3.2f1)

switchQueueComputeMemory: Option<i32>

i32: (2018.3.5f1 - 2022.3.2f1)

switchQueueControlMemory: Option<i32>

i32: (2018.3.5f1 - 2022.3.2f1)

targetGlesGraphics: Option<i32>

i32: (4.0.0 - 5.0.4f1)

targetIOSGraphics: Option<i32>

i32: (4.6.3 - 5.0.4f1)

targetPixelDensity: Option<i32>

i32: (2017.1.0b1 - 2022.3.2f1)

targetPlatform: Option<i32>

i32: (3.4.0 - 3.5.7)

targetResolution: Option<i32>

i32: (3.4.0 - 5.2.5f1)

tizenShowActivityIndicatorOnLoading: Option<i32>

i32: (5.4.3f1 - 2018.1.9f2)

uiUse16BitDepthBuffer: Option<bool>

bool: (5.3.0f1 - 5.6.0b2)

uploadClearedTextureDataAfterCreationFromScript: Option<bool>

bool: (2021.2.0b1 - 2022.1.0a15)

use24BitDepthBuffer: Option<bool>

bool: (3.5.0 - 4.7.2)

useAlphaInDashboard: Option<bool>

bool: (3.4.0 - 3.4.2)

useFlipModelSwapchain: Option<bool>

bool: (2019.1.7f1 - 2022.3.2f1)

useHDRDisplay: Option<bool>

bool: (5.5.4f1 - 2022.3.2f1)

useOnDemandResources: Option<bool>

bool: (5.2.1f1 - 2022.3.2f1)

videoMemoryForVertexBuffers: Option<i32>

i32: (4.5.0 - 2018.2.21f1)

virtualRealitySupported: Option<bool>

bool: (5.1.1f1 - 5.3.8f2)

virtualTexturingSupportEnabled: Option<bool>

bool: (2020.1.0b1 - 2022.3.2f1)

visibleInBackground: Option<bool>

bool: (4.5.4 - 2022.3.2f1)

vrSettings: Option<VRSettings>

VRSettings: (5.6.0b1 - 2022.3.2f1)

vulkanEnableCommandBufferRecycling: Option<bool>

bool: (2020.3.18f1 - 2022.3.2f1)

vulkanEnableLateAcquireNextImage: Option<bool>

bool: (2019.4.6f1 - 2022.3.2f1)

vulkanEnablePreTransform: Option<bool>

bool: (2020.2.0b1 - 2022.3.2f1)

vulkanEnableSetSRGBWrite: Option<bool>

bool: (2018.2.0b1 - 2022.3.2f1)

vulkanNumSwapchainBuffers: Option<u32>

u32: (2019.3.0f1 - 2022.3.2f1)

vulkanUseSWCommandBuffers: Option<bool>

bool: (2018.2.0b1 - 2018.2.21f1)

wiiHio2Usage: Option<i32>

i32: (3.5.0 - 4.3.4)

wiiLoadingScreenBackground: Option<ColorRGBA>

ColorRGBA: (3.5.0 - 4.3.4)

wiiLoadingScreenFileName: Option<String>

String: (3.5.0 - 4.3.4)

wiiLoadingScreenPeriod: Option<i32>

i32: (3.5.0 - 4.3.4)

wiiLoadingScreenRect: Option<Rectf>

Rectf: (3.5.0 - 4.3.4)

wiiLoadingScreenRectPlacement: Option<i32>

i32: (3.5.0 - 4.3.4)

wiiUAllowScreenCapture: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUControllerCount: Option<i32>

i32: (5.2.0f2 - 2017.4.40f1)

wiiUGamePadMSAA: Option<i32>

i32: (5.2.0f2 - 2017.4.40f1)

wiiUSupportsBalanceBoard: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUSupportsClassicController: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUSupportsMotionPlus: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUSupportsNunchuk: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUSupportsProController: Option<bool>

bool: (5.2.0f2 - 2017.4.40f1)

wiiUTVResolution: Option<i32>

i32: (5.2.0f2 - 2017.4.40f1)

windowsGamepadBackendHint: Option<i32>

i32: (2020.3.42f1 - 2022.3.2f1)

wsaTransparentSwapchain: Option<bool>

bool: (2017.3.0b1 - 2022.3.2f1)

xboxEnableAvatar: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

xboxEnableEnableRenderThreadRunsJobs: Option<bool>

bool: (5.3.6f1 - 5.3.8f2)

xboxEnableFitness: Option<bool>

bool: (4.0.0 - 2022.3.2f1)

xboxEnableGuest: Option<bool>

bool: (4.3.0 - 2022.3.2f1)

xboxEnableHeadOrientation: Option<bool>

bool: (4.1.0 - 2022.3.2f1)

xboxEnableKinect: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

xboxEnableKinectAutoTracking: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

xboxEnablePIXSampling: Option<bool>

bool: (5.3.0f2 - 2022.3.2f1)

xboxEnableSpeech: Option<bool>

bool: (3.5.0 - 3.5.7)

xboxOneDisableEsram: Option<bool>

bool: (2017.1.0f2 - 2022.3.2f1)

xboxOneDisableKinectGpuReservation: Option<bool>

bool: (5.0.0f4 - 2022.3.2f1)

xboxOneEnable7thCore: Option<bool>

bool: (5.6.0b1 - 2022.3.2f1)

xboxOneEnableTypeOptimization: Option<bool>

bool: (2018.4.17f1 - 2022.3.2f1)

xboxOneLoggingLevel: Option<i32>

i32: (5.3.7f1 - 2022.3.2f1)

xboxOneMonoLoggingLevel: Option<i32>

i32: (5.3.6f1 - 2022.3.2f1)

xboxOnePresentImmediateThreshold: Option<u32>

u32: (2017.2.0b2 - 2022.3.2f1)

xboxOneResolution: Option<i32>

i32: (5.0.0f4 - 2022.3.2f1)

xboxOneSResolution: Option<i32>

i32: (5.5.6f1 - 2022.3.2f1)

xboxOneXResolution: Option<i32>

i32: (5.5.6f1 - 2022.3.2f1)

xboxPIXTextureCapture: Option<bool>

bool: (4.3.0 - 2022.3.2f1)

xboxSkinOnGPU: Option<bool>

bool: (3.4.0 - 4.1.5)

xboxSpeechDB: Option<u32>

u32: (4.0.0 - 2022.3.2f1)