Preset

Struct Preset 

pub struct Preset {
    pub m_Name: String,
    pub m_Properties: Vec<PropertyModification>,
    pub m_TargetType: PresetType,
    pub m_ExcludedProperties: Option<Vec<String>>,
}
Preset is a class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: A Preset contains default values for an Object. The Preset class contains the type of the Object used to create it and a list of each serialized property/value pair of this Object. It can be used to store informations from any serializable Object in the Editor and apply them back to this Object or any other Object of the same type. Presets can also be saved as Assets using the .preset extension in order to.

Fields

m_Name: String

The name of the object.

m_Properties: Vec<PropertyModification>m_TargetType: PresetTypem_ExcludedProperties: Option<Vec<String>>

List of properties to ignore when applying the Preset to an object. Vec: (2020.1.0b1 - 2022.3.2f1)