pub struct PresetType {
pub m_ManagedTypeFallback: String,
pub m_ManagedTypePPtr: PPtr,
pub m_NativeTypeID: i32,
}Expand description
PresetType is a sub class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: Stores a type to which a Preset can be applied. Only classes that inherit from UnityEngine.Object are represented by a PresetType.This structure is used instead of Type because some native C++ types in Unity are not exposed to managed C# for optimization reasons.
Fields
m_ManagedTypeFallback: Stringm_ManagedTypePPtr: PPtrPPtr<MonoScript>: (2018.1.0b2 - 2022.3.2f1)
m_NativeTypeID: i32Trait Implementations
Sourceimpl Debug for PresetType
impl Debug for PresetType
Sourceimpl<'de> Deserialize<'de> for PresetType
impl<'de> Deserialize<'de> for PresetType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more