pub struct Projector {
pub m_AspectRatio: f32,
pub m_Enabled: u8,
pub m_FarClipPlane: f32,
pub m_FieldOfView: f32,
pub m_GameObject: PPtr,
pub m_IgnoreLayers: BitField,
pub m_Material: PPtr,
pub m_NearClipPlane: f32,
pub m_Orthographic: bool,
pub m_OrthographicSize: f32,
}Expand description
Projector is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A script interface for a projector component. The Projector can be used to project any material onto the Scene - just like a real world projector.
The properties exposed by this class are an exact match for the values in the Projector’s inspector.It can be used to implement blob or projected shadows. You could also project an animated texture or
a render texture that films another part of the Scene. The projector will render all objects in
its view frustum with the provided material.There is no shortcut property in GameObject or Component to access the Projector, so you must
use GetComponent to do it: See Also: projector component.
Fields
m_AspectRatio: f32The aspect ratio of the projection.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_FarClipPlane: f32The far clipping plane distance.
m_FieldOfView: f32The field of view of the projection in degrees.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_IgnoreLayers: BitFieldWhich object layers are ignored by the projector.
m_Material: PPtrThe material that will be projected onto every object.
PPtr<Material>: (3.4.0 - 2022.3.2f1)
m_NearClipPlane: f32The near clipping plane distance.
m_Orthographic: boolIs the projection orthographic (true) or perspective (false)?
m_OrthographicSize: f32Projection’s half-size when in orthographic mode.