pub struct PropertyModification {
pub objectReference: PPtr,
pub propertyPath: String,
pub target: PPtr,
pub value: String,
}Expand description
PropertyModification is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Defines a single modified property. Used by the Prefab system to track any changes applied to an instance.
Fields
objectReference: PPtrThe value being applied when it is an object reference (which can not be represented as a string).
PPtr<[Object]>: (3.5.0 - 2022.3.2f1)
propertyPath: StringProperty path of the property being modified (Matches as SerializedProperty.propertyPath).
target: PPtrObject that will be modified.
PPtr<[Object]>: (3.5.0 - 2022.3.2f1)
value: StringThe value being applied.