QualitySettings

Struct QualitySettings 

pub struct QualitySettings {
Show 14 fields pub Beautiful: Option<QualitySetting>, pub Fantastic: Option<QualitySetting>, pub Fast: Option<QualitySetting>, pub Fastest: Option<QualitySetting>, pub Good: Option<QualitySetting>, pub Simple: Option<QualitySetting>, pub m_CurrentQuality: Option<i32>, pub m_DefaultMobileQuality: Option<i32>, pub m_DefaultStandaloneQuality: Option<i32>, pub m_DefaultWebPlayerQuality: Option<i32>, pub m_EditorQuality: Option<i32>, pub m_QualitySettings: Option<Vec<QualitySetting>>, pub m_StrippedMaximumLODLevel: Option<i32>, pub m_TextureMipmapLimitGroupNames: Option<Vec<String>>,
}
QualitySettings is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Script interface for Quality Settings. There can be an arbitrary number of quality settings. The details of each are set up

in the project’s Quality Settings. At run time, the

current quality level can be changed using this class.

Fields

Beautiful: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

Fantastic: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

Fast: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

Fastest: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

Good: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

Simple: Option<QualitySetting>

QualitySetting: (3.4.0 - 3.4.2)

m_CurrentQuality: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

m_DefaultMobileQuality: Option<i32>

i32: (3.4.0 - 3.4.2)

m_DefaultStandaloneQuality: Option<i32>

i32: (3.4.0 - 3.4.2)

m_DefaultWebPlayerQuality: Option<i32>

i32: (3.4.0 - 3.4.2)

m_EditorQuality: Option<i32>

i32: (3.4.0 - 3.4.2)

m_QualitySettings: Option<Vec<QualitySetting>>

Vec: (3.5.0 - 2022.3.2f1)

m_StrippedMaximumLODLevel: Option<i32>

i32: (3.5.0 - 2022.3.2f1)

m_TextureMipmapLimitGroupNames: Option<Vec<String>>

Vec: (2022.2.0f1 - 2022.3.2f1)