pub struct RayTracingShader {
pub m_MaxRecursionDepth: u32,
pub m_Name: String,
pub variants: Vec<RayTracingShaderVariant>,
}Expand description
RayTracingShader is a class of the Unity engine since version 2019.3.0b1. Exert from Unity’s scripting documentation: A shader for GPU ray tracing. This shader should contain at least a raygeneration shader.
Fields
m_MaxRecursionDepth: u32The maximum number of ray bounces this shader can trace (Read Only).
m_Name: StringThe name of the object.
variants: Vec<RayTracingShaderVariant>Trait Implementations
Sourceimpl Debug for RayTracingShader
impl Debug for RayTracingShader
Sourceimpl<'de> Deserialize<'de> for RayTracingShader
impl<'de> Deserialize<'de> for RayTracingShader
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more