RelativeJoint2D

Struct RelativeJoint2D 

pub struct RelativeJoint2D {
Show 13 fields pub m_AngularOffset: f32, pub m_AutoConfigureOffset: bool, pub m_BreakForce: f32, pub m_BreakTorque: f32, pub m_ConnectedRigidBody: PPtr, pub m_CorrectionScale: f32, pub m_EnableCollision: bool, pub m_Enabled: u8, pub m_GameObject: PPtr, pub m_LinearOffset: Vector2f, pub m_MaxForce: f32, pub m_MaxTorque: f32, pub m_BreakAction: Option<i32>,
}
RelativeJoint2D is a class of the Unity engine since version 5.3.0f1. Exert from Unity’s scripting documentation: Keeps two Rigidbody2D at their relative orientations. Two Rigidbody2D connected together with this joint will have forces applied to them to keep them both at their relative linear and angular offsets. If the joint is not connected to another Rigidbody2D then the body with the joint will stay at its current linear and angular offset in world-space i.e. it will be anchored to the implicit static ground-body.You control the maximum linear force applied to maintain the linearOffset by using maxForce.You control the maximum torque applied to maintain the angularOffset by using maxTorqueSee Also: linearOffset, angularOffset, maxForce, maxTorque.

Fields

m_AngularOffset: f32

The current angular offset between the Rigidbody2D that the joint connects.

m_AutoConfigureOffset: bool

Should both the linearOffset and angularOffset be calculated automatically?

m_BreakForce: f32

The force that needs to be applied for this joint to break.

m_BreakTorque: f32

The torque that needs to be applied for this joint to break.

m_ConnectedRigidBody: PPtr

PPtr<Rigidbody2D>: (5.3.0f1 - 2022.3.2f1)

m_CorrectionScale: f32

Scales both the linear and angular forces used to correct the required relative orientation.

m_EnableCollision: bool

Should the two rigid bodies connected with this joint collide with each other?

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (5.3.0f1 - 2022.3.2f1)

m_LinearOffset: Vector2f

The current linear offset between the Rigidbody2D that the joint connects.

m_MaxForce: f32

The maximum force that can be generated when trying to maintain the relative joint constraint.

m_MaxTorque: f32

The maximum torque that can be generated when trying to maintain the relative joint constraint.

m_BreakAction: Option<i32>

The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)