pub struct RotationBySpeedModule {
pub curve: MinMaxCurve,
pub enabled: bool,
pub range: Vector2f,
pub separateAxes: Option<bool>,
pub x: Option<MinMaxCurve>,
pub y: Option<MinMaxCurve>,
}Expand description
RotationBySpeedModule is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for the RotationBySpeedModule. Rotate particles based on their speed.See Also: ParticleSystem, ParticleSystem.rotationBySpeed.
Fields
curve: MinMaxCurveenabled: boolESpecifies whether the RotationBySpeedModule is enabled or disabled.
range: Vector2fSet the minimum and maximum speeds that this module applies the rotation curve between.
separateAxes: Option<bool>Set the rotation by speed on each axis separately. bool: (5.3.0f1 - 2022.3.2f1)
x: Option<MinMaxCurve>Rotation by speed curve for the x-axis. MinMaxCurve: (5.3.0f1 - 2022.3.2f1)
y: Option<MinMaxCurve>Rotation by speed curve for the y-axis. MinMaxCurve: (5.3.0f1 - 2022.3.2f1)