pub struct RuntimeAnimatorController {
pub m_AnimationClips: Vec<PPtr>,
pub m_Controller: ControllerConstant,
pub m_ControllerSize: u32,
pub m_Name: String,
pub m_TOS: Vec<(u32, String)>,
}Expand description
RuntimeAnimatorController is a class of the Unity engine since version 4.1.0. Exert from Unity’s scripting documentation: The runtime representation of the AnimatorController. Use this representation to change the Animator Controller during runtime.
Fields
m_AnimationClips: Vec<PPtr>Retrieves all AnimationClip used by the controller.
Vec<PPtr<AnimationClip>>: (4.1.0 - 4.2.2)
m_Controller: ControllerConstantm_ControllerSize: u32m_Name: StringThe name of the object.
m_TOS: Vec<(u32, String)>Trait Implementations
Sourceimpl Debug for RuntimeAnimatorController
impl Debug for RuntimeAnimatorController
Sourceimpl<'de> Deserialize<'de> for RuntimeAnimatorController
impl<'de> Deserialize<'de> for RuntimeAnimatorController
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more