pub struct ScaleConstraint {
pub m_AffectScalingX: bool,
pub m_AffectScalingY: bool,
pub m_AffectScalingZ: bool,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_ScaleAtRest: Vector3f,
pub m_ScaleOffset: Vector3f,
pub m_Sources: Vec<ConstraintSource>,
pub m_Weight: f32,
pub m_Active: Option<bool>,
pub m_IsContraintActive: Option<bool>,
}Expand description
ScaleConstraint is a class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: Constrains the scale of an object relative to the scale of one or more source objects.
Fields
m_AffectScalingX: boolm_AffectScalingY: boolm_AffectScalingZ: boolm_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2018.1.0b2 - 2022.3.2f1)
m_ScaleAtRest: Vector3fThe scale used when the sources have a total weight of 0.
m_ScaleOffset: Vector3fThe offset from the constrained scale.
m_Sources: Vec<ConstraintSource>m_Weight: f32The weight of the constraint component.
m_Active: Option<bool>bool: (2022.1.0b1 - 2022.3.2f1)
m_IsContraintActive: Option<bool>bool: (2018.1.0b2 - 2022.1.0a9)