pub struct SecondarySpriteTexture {
pub name: String,
pub texture: PPtr,
}Expand description
SecondarySpriteTexture is a sub class of the Unity engine since version 2019.1.0b1. Exert from Unity’s scripting documentation: Encapsulates a Texture2D and its shader property name to give Sprite-based renderers access to a secondary texture, in addition to the main Sprite texture.
Fields
name: StringThe shader property name of the secondary Sprite texture. Use this name to identify and sample the texture in the shader.
texture: PPtrThe texture to be used as a secondary Sprite texture.
PPtr<Texture2D>: (2019.1.0b1 - 2022.3.2f1)