Shader

Struct Shader 

pub struct Shader {
Show 15 fields pub m_Name: String, pub compressedBlob: Option<Vec<u8>>, pub compressedLengths: Option<Vec<Enum_u32__Vec_u32>>, pub decompressedLengths: Option<Vec<Enum_u32__Vec_u32>>, pub decompressedSize: Option<u32>, pub m_Dependencies: Option<Vec<PPtr>>, pub m_NonModifiableTextures: Option<Vec<(String, PPtr)>>, pub m_ParsedForm: Option<SerializedShader>, pub m_PathName: Option<String>, pub m_Script: Option<String>, pub m_ShaderIsBaked: Option<bool>, pub m_SubProgramBlob: Option<Vec<u8>>, pub offsets: Option<Vec<Enum_u32__Vec_u32>>, pub platforms: Option<Vec<u32>>, pub stageCounts: Option<Vec<u32>>,
}
Shader is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Shader scripts used for all rendering. Most of the advanced rendering is controlled via Material class. Shader class is mostly

used just to check whether a shader can run on the user’s hardware (isSupported property), setting up

global shader properties and keywords, and finding shaders by name (Find method).See Also: Material class, Materials, ShaderLab documentation.

Fields

m_Name: String

The name of the object.

compressedBlob: Option<Vec<u8>>

Vec: (5.5.0f3 - 2022.3.2f1)

compressedLengths: Option<Vec<Enum_u32__Vec_u32>>

Vec: (5.5.0f3 - 2019.3.0a12); Vec<Vec>: (2019.3.0b1 - 2022.3.2f1)

decompressedLengths: Option<Vec<Enum_u32__Vec_u32>>

Vec: (5.5.0f3 - 2019.3.0a12); Vec<Vec>: (2019.3.0b1 - 2022.3.2f1)

decompressedSize: Option<u32>

u32: (5.3.0f1 - 5.4.6f3)

m_Dependencies: Option<Vec<PPtr>>

Vec<PPtr<Shader>>: (4.0.0 - 2022.3.2f1)

m_NonModifiableTextures: Option<Vec<(String, PPtr)>>

Vec<(String, PPtr<Texture>)>: (2018.1.0b2 - 2022.3.2f1)

m_ParsedForm: Option<SerializedShader>

SerializedShader: (5.5.0f3 - 2022.3.2f1)

m_PathName: Option<String>

String: (3.4.0 - 5.4.6f3)

m_Script: Option<String>

String: (3.4.0 - 5.4.6f3)

m_ShaderIsBaked: Option<bool>

bool: (4.0.0 - 2022.3.2f1)

m_SubProgramBlob: Option<Vec<u8>>

Vec: (5.3.0f1 - 5.4.6f3)

offsets: Option<Vec<Enum_u32__Vec_u32>>

Vec: (5.5.0f3 - 2019.3.0a12); Vec<Vec>: (2019.3.0b1 - 2022.3.2f1)

platforms: Option<Vec<u32>>

Vec: (5.5.0f3 - 2022.3.2f1)

stageCounts: Option<Vec<u32>>

Vec: (2021.3.12f1 - 2022.3.2f1)