ShaderImporter

Struct ShaderImporter 

pub struct ShaderImporter {
    pub m_Name: String,
    pub m_UserData: String,
    pub m_AssetBundleName: Option<String>,
    pub m_AssetBundleVariant: Option<String>,
    pub m_DefaultTextures: Option<Vec<(String, PPtr)>>,
    pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>,
    pub m_NonModifiableTextures: Option<Vec<(String, PPtr)>>,
    pub m_PreprocessorOverride: Option<i32>,
    pub m_UsedFileIDs: Option<Vec<i64>>,
}
ShaderImporter is a class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Shader importer lets you modify shader import settings from Editor scripts.

Fields

m_Name: String

The name of the object.

m_UserData: String

Get or set any user data.

m_AssetBundleName: Option<String>

Get or set the AssetBundle name. String: (5.0.0f4 - 2022.3.2f1)

m_AssetBundleVariant: Option<String>

Get or set the AssetBundle variant. String: (5.0.0f4 - 2022.3.2f1)

m_DefaultTextures: Option<Vec<(String, PPtr)>>

Vec<(String, PPtr<Texture>)>: (4.2.0 - 2022.3.2f1)

m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>

Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)

m_NonModifiableTextures: Option<Vec<(String, PPtr)>>

Vec<(String, PPtr<Texture>)>: (2018.1.0b2 - 2022.3.2f1)

m_PreprocessorOverride: Option<i32>

This property has no effect. i32: (2020.2.0b1 - 2022.1.0a9)

m_UsedFileIDs: Option<Vec<i64>>

Vec: (2019.1.0b1 - 2022.3.2f1)