pub struct ShaderInfo {
pub variants: Vec<VariantInfo>,
}Expand description
ShaderInfo is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Contains the following information about a shader: -If the shader has compilation errors or warnings. -If the shader is supported on the currently selected platform. -The name of the shader.
Fields
variants: Vec<VariantInfo>Trait Implementations
Sourceimpl Debug for ShaderInfo
impl Debug for ShaderInfo
Sourceimpl<'de> Deserialize<'de> for ShaderInfo
impl<'de> Deserialize<'de> for ShaderInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more