pub struct SizeBySpeedModule {
pub curve: MinMaxCurve,
pub enabled: bool,
pub range: Vector2f,
pub separateAxes: Option<bool>,
pub y: Option<MinMaxCurve>,
pub z: Option<MinMaxCurve>,
}Expand description
SizeBySpeedModule is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for the SizeBySpeedModule. This module controls the size of particles based on their speeds.See Also: ParticleSystem, ParticleSystem.sizeBySpeed.
Fields
curve: MinMaxCurveenabled: boolSpecifies whether the SizeBySpeedModule is enabled or disabled.
range: Vector2fSet the minimum and maximum speed that this modules applies the size curve between.
separateAxes: Option<bool>Set the size by speed on each axis separately. bool: (5.4.0f3 - 2022.3.2f1)
y: Option<MinMaxCurve>Size by speed curve for the y-axis. MinMaxCurve: (5.4.0f3 - 2022.3.2f1)
z: Option<MinMaxCurve>Size by speed curve for the z-axis. MinMaxCurve: (5.4.0f3 - 2022.3.2f1)