pub struct SketchUpImportCamera {
pub aspectRatio: f32,
pub fov: f32,
pub isPerspective: i32,
pub lookAt: Vector3f,
pub orthoSize: f32,
pub position: Vector3f,
pub up: Vector3f,
pub farPlane: Option<f32>,
pub nearPlane: Option<f32>,
}Expand description
SketchUpImportCamera is a sub class of the Unity engine since version 5.1.0f1. Exert from Unity’s scripting documentation: Structure to hold camera data extracted from a SketchUp file. When importing a SketchUp file, Unity retrieves the current camera view the file is saved with and the camera view of all the scenes in the SketchUp file. The camera data of each Scene is stored in SketchUpImportSceneThis can be extracted later from SketchUpImporter.
Fields
aspectRatio: f32Aspect ratio of the camera.
fov: f32isPerspective: i32Indicate if the camera is using a perspective or orthogonal projection.
lookAt: Vector3fThe position the camera is looking at.
orthoSize: f32The orthogonal projection size of the camera. This value only make sense if SketchUpImportCamera.isPerspective is false.
position: Vector3fThe position of the camera.
up: Vector3fUp vector of the camera.
farPlane: Option<f32>The near clipping plane distance. f32: (2019.1.0b1 - 2022.3.2f1)
nearPlane: Option<f32>The far clipping plane distance. f32: (2019.1.0b1 - 2022.3.2f1)