pub struct SketchUpImportScene {
pub camera: SketchUpImportCamera,
pub name: String,
}Expand description
SketchUpImportScene is a sub class of the Unity engine since version 5.1.0f1. Exert from Unity’s scripting documentation: Structure to hold scene data extracted from a SketchUp file. When importing a SketchUp file, Unity retrieves all the scenes in the SketchUp file.This can be extracted later from SketchUpImporter with SketchUpImporter.GetScenes.
Fields
camera: SketchUpImportCameraThe camera data of the SketchUp scene.
name: StringThe name of the SketchUp scene.