pub struct Skybox {
pub m_CustomSkybox: PPtr,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
}Expand description
Skybox is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A script interface for the skybox component. The skybox class has only the material property.See Also: skybox component.
Fields
m_CustomSkybox: PPtrPPtr<Material>: (3.4.0 - 2022.3.2f1)
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)