SliderJoint2D

Struct SliderJoint2D 

pub struct SliderJoint2D {
Show 17 fields pub m_Anchor: Vector2f, pub m_Angle: f32, pub m_ConnectedAnchor: Vector2f, pub m_ConnectedRigidBody: PPtr, pub m_Enabled: u8, pub m_GameObject: PPtr, pub m_Motor: JointMotor2D, pub m_TranslationLimits: JointTranslationLimits2D, pub m_UseLimits: bool, pub m_UseMotor: bool, pub m_AutoConfigureAngle: Option<bool>, pub m_AutoConfigureConnectedAnchor: Option<bool>, pub m_BreakAction: Option<i32>, pub m_BreakForce: Option<f32>, pub m_BreakTorque: Option<f32>, pub m_CollideConnected: Option<bool>, pub m_EnableCollision: Option<bool>,
}
SliderJoint2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Joint that restricts the motion of a Rigidbody2D object to a single line. See Also: Rigidbody2D, DistanceJoint2D, HingeJoint2D, SpringJoint2D, JointTranslationLimits2D.

Fields

m_Anchor: Vector2f

The joint’s anchor point on the object that has the joint component.

m_Angle: f32

The angle of the line in space (in degrees).

m_ConnectedAnchor: Vector2f

The joint’s anchor point on the second object (ie, the one which doesn’t have the joint component).

m_ConnectedRigidBody: PPtr

PPtr<Rigidbody2D>: (4.3.0 - 2022.3.2f1)

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (4.3.0 - 2022.3.2f1)

m_Motor: JointMotor2D

Parameters for a motor force that is applied automatically to the Rigibody2D along the line.

m_TranslationLimits: JointTranslationLimits2Dm_UseLimits: bool

Should motion limits be used?

m_UseMotor: bool

Should a motor force be applied automatically to the Rigidbody2D?

m_AutoConfigureAngle: Option<bool>

Should the angle be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)

m_AutoConfigureConnectedAnchor: Option<bool>

Should the connectedAnchor be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)

m_BreakAction: Option<i32>

The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)

m_BreakForce: Option<f32>

The force that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)

m_BreakTorque: Option<f32>

The torque that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)

m_CollideConnected: Option<bool>

bool: (4.3.0 - 5.0.0f4)

m_EnableCollision: Option<bool>

Should the two rigid bodies connected with this joint collide with each other? bool: (5.0.1f1 - 2022.3.2f1)