pub struct SoftJointLimit {
pub bounciness: f32,
pub limit: f32,
pub contactDistance: Option<f32>,
pub damper: Option<f32>,
pub spring: Option<f32>,
}Expand description
SoftJointLimit is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The limits defined by the CharacterJoint.
Fields
bounciness: f32When the joint hits the limit, it can be made to bounce off it.
limit: f32The limit position/angle of the joint (in degrees).
contactDistance: Option<f32>Determines how far ahead in space the solver can “see” the joint limit. f32: (5.0.0f4 - 2022.3.2f1)
damper: Option<f32>f32: (3.4.0 - 4.7.2)
spring: Option<f32>f32: (3.4.0 - 4.7.2)