pub struct SoftJointLimitSpring {
pub damper: f32,
pub spring: f32,
}Expand description
SoftJointLimitSpring is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: The configuration of the spring attached to the joint’s limits: linear and angular. Used by CharacterJoint and ConfigurableJoint.
Fields
damper: f32The damping of the spring limit. In effect when the stiffness of the sprint limit is not zero.
spring: f32The stiffness of the spring limit. When stiffness is zero the limit is hard, otherwise soft.