SortingGroup

Struct SortingGroup 

pub struct SortingGroup {
    pub m_Enabled: u8,
    pub m_GameObject: PPtr,
    pub m_SortingLayer: i16,
    pub m_SortingOrder: i16,
    pub m_SortAtRoot: Option<bool>,
    pub m_SortingLayerID: Option<i32>,
}
SortingGroup is a class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: Adding a SortingGroup component to a GameObject will ensure that all Renderers within the GameObject’s descendants will be sorted and rendered together. A common use case for having a SortingGroup is to create complex 2D characters that are made up of multiple SpriteRenderers. When several clones of such a character overlap, their individual body parts might not be sorted properly resulting in a visual glitch where the the body parts interleave. For example, the hands of two characters might be sorted in front of their bodies, where you would expect one entire character to be drawn in front of the other character. The SortingGroup component solves this by ensuring the entire branch of the character are sorted and rendered together.The descendants of the SortingGroup are sorted using the same SortingLayer and Renderer.sortingOrder. However, they are only sorted against other descendants of the SortingGroup and not with any renderers outside of it. This allows you to reuse the same SortingLayers (for example, “Hands”, “Torso”…) to sort body parts while ensuring they never interleave with other clones of the character.The SortingGroups, together with other renderers, are sorted using the SortingLayer and Renderer.sortingOrder. Additionally, they can be nested within other SortingGroups. This is useful if you have branches of descendants that should not be mixed up i.e. the “Left Hand” vs the “Right Hand” hierarchy branches. .

Fields

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (5.6.0b1 - 2022.3.2f1)

m_SortingLayer: i16m_SortingOrder: i16

Renderer’s order within a sorting layer.

m_SortAtRoot: Option<bool>

Ignores any parent SortingGroup and sorts this and its descendant Renderers against other Renderers at the root level. bool: (2022.1.0b1 - 2022.3.2f1)

m_SortingLayerID: Option<i32>

Unique ID of the Renderer’s sorting layer. i32: (5.6.0f3 - 2022.3.2f1)