SpeedTreeImporter

Struct SpeedTreeImporter 

pub struct SpeedTreeImporter {
Show 24 fields pub m_AlphaTestRef: f32, pub m_AssetBundleName: String, pub m_AssetBundleVariant: String, pub m_BestWindQuality: i32, pub m_BillboardTransitionCrossFadeWidth: f32, pub m_EnableSmoothLODTransition: bool, pub m_FadeOutWidth: f32, pub m_HasBillboard: bool, pub m_HueVariation: ColorRGBA, pub m_LODSettings: Vec<PerLODSettings>, pub m_MainColor: ColorRGBA, pub m_Name: String, pub m_ScaleFactor: f32, pub m_UserData: String, pub m_AnimateCrossFading: Option<bool>, pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>, pub m_FileIDType: Option<i32>, pub m_MaterialLocation: Option<i32>, pub m_MaterialVersion: Option<i32>, pub m_Materials: Option<Vec<SourceAssetIdentifier>>, pub m_Shininess: Option<f32>, pub m_SpecColor: Option<ColorRGBA>, pub m_SupportsEmbeddedMaterials: Option<bool>, pub m_UsedFileIDs: Option<Vec<i64>>,
}
SpeedTreeImporter is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: AssetImportor for importing SpeedTree model assets.

Fields

m_AlphaTestRef: f32

Gets and sets a default alpha test reference values.

m_AssetBundleName: String

Get or set the AssetBundle name.

m_AssetBundleVariant: String

Get or set the AssetBundle variant.

m_BestWindQuality: i32

Returns the best-possible wind quality on this asset (configured in SpeedTree modeler).

m_BillboardTransitionCrossFadeWidth: f32

Proportion of the last 3D mesh LOD region width which is used for cross-fading to billboard tree.

m_EnableSmoothLODTransition: bool

Enables smooth LOD transitions.

m_FadeOutWidth: f32

Proportion of the billboard LOD region width which is used for fading out the billboard.

m_HasBillboard: bool

Tells if there is a billboard LOD.

m_HueVariation: ColorRGBA

Gets and sets a default Hue variation color and amount (in alpha).

m_LODSettings: Vec<PerLODSettings>m_MainColor: ColorRGBA

Gets and sets a default main color.

m_Name: String

The name of the object.

m_ScaleFactor: f32

How much to scale the tree model compared to what is in the .spm file.

m_UserData: String

Get or set any user data.

m_AnimateCrossFading: Option<bool>

Indicates if the cross-fade LOD transition, applied to the last mesh LOD and the billboard, should be animated. bool: (5.1.0f1 - 2022.3.2f1)

m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>

Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)

m_FileIDType: Option<i32>

i32: (2019.1.0b1 - 2022.3.2f1)

m_MaterialLocation: Option<i32>

Material import location options. i32: (2018.3.0f2 - 2022.3.2f1)

m_MaterialVersion: Option<i32>

i32: (5.2.0f2 - 2022.3.2f1)

m_Materials: Option<Vec<SourceAssetIdentifier>>

Vec: (2018.3.0f2 - 2022.3.2f1)

m_Shininess: Option<f32>

f32: (5.0.0f4 - 5.4.0b25)

m_SpecColor: Option<ColorRGBA>

ColorRGBA: (5.0.0f4 - 5.4.0b25)

m_SupportsEmbeddedMaterials: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

m_UsedFileIDs: Option<Vec<i64>>

Vec: (2019.1.0b1 - 2022.3.2f1)