SphericalHarmonicsL2

Struct SphericalHarmonicsL2 

pub struct SphericalHarmonicsL2 {
Show 27 fields pub sh_10_: Option<f32>, pub sh_11_: Option<f32>, pub sh_12_: Option<f32>, pub sh_13_: Option<f32>, pub sh_14_: Option<f32>, pub sh_15_: Option<f32>, pub sh_16_: Option<f32>, pub sh_17_: Option<f32>, pub sh_18_: Option<f32>, pub sh_19_: Option<f32>, pub sh_20_: Option<f32>, pub sh_21_: Option<f32>, pub sh_22_: Option<f32>, pub sh_23_: Option<f32>, pub sh_24_: Option<f32>, pub sh_25_: Option<f32>, pub sh_26_: Option<f32>, pub sh__0_: Option<f32>, pub sh__1_: Option<f32>, pub sh__2_: Option<f32>, pub sh__3_: Option<f32>, pub sh__4_: Option<f32>, pub sh__5_: Option<f32>, pub sh__6_: Option<f32>, pub sh__7_: Option<f32>, pub sh__8_: Option<f32>, pub sh__9_: Option<f32>,
}
SphericalHarmonicsL2 is a sub class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Spherical harmonics up to the second order (3 bands, 9 coefficients). Spherical harmonics (SH) represent a function or signal over directions, and are commonly used in computer graphics to efficiently evaluate smooth lighting. Unity uses them for LightProbes and environment lighting.L2 spherical harmonics is composed of 9 coefficients for each color channel.See Also: RenderSettings.ambientMode, RenderSettings.ambientProbe, LightProbes.

Fields

sh_10_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_11_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_12_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_13_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_14_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_15_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_16_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_17_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_18_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_19_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_20_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_21_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_22_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_23_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_24_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_25_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh_26_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__0_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__1_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__2_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__3_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__4_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__5_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__6_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__7_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__8_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)

sh__9_: Option<f32>

f32: (5.0.0f4 - 2022.3.2f1)