SplashScreenLogo

Struct SplashScreenLogo 

pub struct SplashScreenLogo {
    pub duration: f32,
    pub logo: PPtr,
}
SplashScreenLogo is a sub class of the Unity engine since version 5.5.0f3. Exert from Unity’s scripting documentation: A single logo that is shown during the Splash Screen. Controls the Sprite that is displayed and its duration.

Fields

duration: f32

The total time in seconds for which the logo is shown. The minimum duration is 2 seconds.

The Sprite that is shown during this logo. If this is null, then no logo will be displayed for the duration. PPtr<Sprite>: (5.5.0f3 - 2022.3.2f1)