SplatPrototype

Struct SplatPrototype 

pub struct SplatPrototype {
    pub texture: PPtr,
    pub tileOffset: Vector2f,
    pub tileSize: Vector2f,
    pub normalMap: Option<PPtr>,
    pub smoothness: Option<f32>,
    pub specularMetallic: Option<Vector4f>,
}
SplatPrototype is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A Splat prototype is just a texture that is used by the TerrainData. A class on a Terrain GameObject.

Fields

texture: PPtr

Texture of the splat applied to the Terrain. PPtr<Texture2D>: (3.4.0 - 2018.2.21f1)

tileOffset: Vector2f

Offset of the tile texture of the SplatPrototype.

tileSize: Vector2f

Size of the tile used in the texture of the SplatPrototype.

normalMap: Option<PPtr>

Normal map of the splat applied to the Terrain. PPtr<Texture2D>: (4.0.0 - 2018.2.21f1)

smoothness: Option<f32>

The smoothness value of the splat layer when the main texture has no alpha channel. f32: (5.0.1f1 - 2018.2.21f1)

specularMetallic: Option<Vector4f>

Vector4f: (5.0.0f4 - 2018.2.21f1)