pub struct SpringJoint2D {Show 15 fields
pub m_Anchor: Vector2f,
pub m_ConnectedAnchor: Vector2f,
pub m_ConnectedRigidBody: PPtr,
pub m_DampingRatio: f32,
pub m_Distance: f32,
pub m_Enabled: u8,
pub m_Frequency: f32,
pub m_GameObject: PPtr,
pub m_AutoConfigureConnectedAnchor: Option<bool>,
pub m_AutoConfigureDistance: Option<bool>,
pub m_BreakAction: Option<i32>,
pub m_BreakForce: Option<f32>,
pub m_BreakTorque: Option<f32>,
pub m_CollideConnected: Option<bool>,
pub m_EnableCollision: Option<bool>,
}Expand description
SpringJoint2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Joint that attempts to keep two Rigidbody2D objects a set distance apart by applying a force between them. Note that unlike DistanceJoint2D, the length of the joint can stretch and oscillate.See Also: DistanceJoint2D, HingeJoint2D, SliderJoint2D.
Fields
m_Anchor: Vector2fThe joint’s anchor point on the object that has the joint component.
m_ConnectedAnchor: Vector2fThe joint’s anchor point on the second object (ie, the one which doesn’t have the joint component).
m_ConnectedRigidBody: PPtrPPtr<Rigidbody2D>: (4.3.0 - 2022.3.2f1)
m_DampingRatio: f32The amount by which the spring force is reduced in proportion to the movement speed.
m_Distance: f32The distance the spring will try to keep between the two objects.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_Frequency: f32The frequency at which the spring oscillates around the distance distance between the objects.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.3.0 - 2022.3.2f1)
m_AutoConfigureConnectedAnchor: Option<bool>Should the connectedAnchor be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)
m_AutoConfigureDistance: Option<bool>Should the distance be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)
m_BreakAction: Option<i32>The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)
m_BreakForce: Option<f32>The force that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_BreakTorque: Option<f32>The torque that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_CollideConnected: Option<bool>bool: (4.3.0 - 5.0.0f4)
m_EnableCollision: Option<bool>Should the two rigid bodies connected with this joint collide with each other? bool: (5.0.1f1 - 2022.3.2f1)