SpriteAtlasImporter

Struct SpriteAtlasImporter 

pub struct SpriteAtlasImporter {
    pub m_AssetBundleName: String,
    pub m_AssetBundleVariant: String,
    pub m_ExternalObjects: Vec<(SourceAssetIdentifier, PPtr)>,
    pub m_Name: String,
    pub m_UsedFileIDs: Vec<i64>,
    pub m_UserData: String,
    pub m_BindAsDefault: Option<bool>,
    pub m_PackingSettings: Option<PackingSettings>,
    pub m_PlatformSettings: Option<Vec<TextureImporterPlatformSettings>>,
    pub m_SecondaryTextureSettings: Option<Vec<(String, SecondaryTextureSettings)>>,
    pub m_TextureSettings: Option<TextureSettings>,
    pub m_VariantMultiplier: Option<f32>,
}
SpriteAtlasImporter is a class of the Unity engine since version 2020.1.0b1. Exert from Unity’s scripting documentation: SpriteAtlasImporter imports SpriteAtlasAsset and generates SpriteAtlas.

Fields

m_AssetBundleName: String

Get or set the AssetBundle name.

m_AssetBundleVariant: String

Get or set the AssetBundle variant.

m_ExternalObjects: Vec<(SourceAssetIdentifier, PPtr)>

Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2020.1.0b1 - 2022.3.2f1)

m_Name: String

The name of the object.

m_UsedFileIDs: Vec<i64>m_UserData: String

Get or set any user data.

m_BindAsDefault: Option<bool>

bool: (2022.1.0b1 - 2022.3.2f1)

m_PackingSettings: Option<PackingSettings>

SpriteAtlasPackingSettings to use when packing this SpriteAtlas. PackingSettings: (2022.1.0b1 - 2022.3.2f1)

m_PlatformSettings: Option<Vec<TextureImporterPlatformSettings>>

Vec: (2022.1.0b1 - 2022.3.2f1)

m_SecondaryTextureSettings: Option<Vec<(String, SecondaryTextureSettings)>>

Vec<(String, SecondaryTextureSettings)>: (2022.1.0b1 - 2022.3.2f1)

m_TextureSettings: Option<TextureSettings>

SpriteAtlasTextureSettings of the packed Texture generated by this SpriteAtlas. TextureSettings: (2022.1.0b1 - 2022.3.2f1)

m_VariantMultiplier: Option<f32>

f32: (2022.1.0b1 - 2022.3.2f1)