SpriteMask

Struct SpriteMask 

pub struct SpriteMask {
Show 35 fields pub m_BackSortingLayer: i16, pub m_BackSortingOrder: i16, pub m_CastShadows: u8, pub m_Enabled: bool, pub m_FrontSortingLayer: i16, pub m_FrontSortingOrder: i16, pub m_GameObject: PPtr, pub m_IsCustomRangeActive: bool, pub m_LightProbeUsage: u8, pub m_LightProbeVolumeOverride: PPtr, pub m_LightmapIndex: u16, pub m_LightmapIndexDynamic: u16, pub m_LightmapTilingOffset: Vector4f, pub m_LightmapTilingOffsetDynamic: Vector4f, pub m_MaskAlphaCutoff: f32, pub m_Materials: Vec<PPtr>, pub m_MotionVectors: u8, pub m_ProbeAnchor: PPtr, pub m_ReceiveShadows: u8, pub m_ReflectionProbeUsage: u8, pub m_SortingLayer: i16, pub m_SortingLayerID: i32, pub m_SortingOrder: i16, pub m_Sprite: PPtr, pub m_StaticBatchInfo: StaticBatchInfo, pub m_StaticBatchRoot: PPtr, pub m_BackSortingLayerID: Option<i32>, pub m_DynamicOccludee: Option<u8>, pub m_FrontSortingLayerID: Option<i32>, pub m_RayTraceProcedural: Option<u8>, pub m_RayTracingMode: Option<u8>, pub m_RendererPriority: Option<i32>, pub m_RenderingLayerMask: Option<u32>, pub m_SpriteSortPoint: Option<i32>, pub m_StaticShadowCaster: Option<u8>,
}
SpriteMask is a class of the Unity engine since version 2017.1.0b1. Exert from Unity’s scripting documentation: A component for masking Sprites and Particles. By default it will mask all Sorting Layers. A custom range of Sorting Layers can be set. If a SortingGroup is present, it will act local to the SortingGroup.

Fields

m_BackSortingLayer: i16m_BackSortingOrder: i16

Order within the back sorting layer defining the end of the custom range.

m_CastShadows: u8m_Enabled: bool

Makes the rendered 3D object visible if enabled.

m_FrontSortingLayer: i16m_FrontSortingOrder: i16

Order within the front sorting layer defining the start of the custom range.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (2017.1.0b1 - 2022.3.2f1)

m_IsCustomRangeActive: bool

Mask sprites from front to back sorting values only.

m_LightProbeUsage: u8

The light probe interpolation type.

m_LightProbeVolumeOverride: PPtr

PPtr<GameObject>: (2017.1.0b1 - 2022.3.2f1)

m_LightmapIndex: u16

The index of the baked lightmap applied to this renderer.

m_LightmapIndexDynamic: u16m_LightmapTilingOffset: Vector4fm_LightmapTilingOffsetDynamic: Vector4fm_MaskAlphaCutoff: f32m_Materials: Vec<PPtr>

Returns all the instantiated materials of this object. Vec<PPtr<Material>>: (2017.1.0b1 - 2022.3.2f1)

m_MotionVectors: u8m_ProbeAnchor: PPtr

If set, Renderer will use this Transform’s position to find the light or reflection probe. PPtr<Transform>: (2017.1.0b1 - 2022.3.2f1)

m_ReceiveShadows: u8

Does this object receive shadows?

m_ReflectionProbeUsage: u8

Should reflection probes be used for this Renderer?

m_SortingLayer: i16m_SortingLayerID: i32

Unique ID of the Renderer’s sorting layer.

m_SortingOrder: i16

Renderer’s order within a sorting layer.

m_Sprite: PPtr

The Sprite used to define the mask. PPtr<Sprite>: (2017.1.0b1 - 2022.3.2f1)

m_StaticBatchInfo: StaticBatchInfom_StaticBatchRoot: PPtr

PPtr<Transform>: (2017.1.0b1 - 2022.3.2f1)

m_BackSortingLayerID: Option<i32>

Unique ID of the sorting layer defining the end of the custom range. i32: (2018.4.5f1 - 2022.3.2f1)

m_DynamicOccludee: Option<u8>

u8: (2017.2.0b2 - 2022.3.2f1)

m_FrontSortingLayerID: Option<i32>

Unique ID of the sorting layer defining the start of the custom range. i32: (2018.4.5f1 - 2022.3.2f1)

m_RayTraceProcedural: Option<u8>

u8: (2020.1.0b1 - 2022.3.2f1)

m_RayTracingMode: Option<u8>

Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)

m_RendererPriority: Option<i32>

This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)

m_RenderingLayerMask: Option<u32>

Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)

m_SpriteSortPoint: Option<i32>

Determines the position of the Sprite used for sorting the SpriteMask. i32: (2018.2.0b1 - 2022.3.2f1)

m_StaticShadowCaster: Option<u8>

Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)