pub struct SpriteMetaData {Show 15 fields
pub m_Alignment: i32,
pub m_Name: String,
pub m_Pivot: Vector2f,
pub m_Rect: Rectf,
pub m_Bones: Option<Vec<SpriteBone>>,
pub m_Border: Option<Vector4f>,
pub m_Edges: Option<Vec<int2_storage>>,
pub m_Indices: Option<Vec<i32>>,
pub m_InternalID: Option<i64>,
pub m_Outline: Option<Vec<Vec<Vector2f>>>,
pub m_PhysicsShape: Option<Vec<Vec<Vector2f>>>,
pub m_SpriteID: Option<String>,
pub m_TessellationDetail: Option<f32>,
pub m_Vertices: Option<Vec<Vector2f>>,
pub m_Weights: Option<Vec<BoneWeights4>>,
}Expand description
SpriteMetaData is a sub class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Editor data used in producing a Sprite. See Also: TextureImporter.spritesheet.
Fields
m_Alignment: i32Edge-relative alignment of the sprite graphic.
m_Name: StringName of the Sprite.
m_Pivot: Vector2fThe pivot point of the Sprite, relative to its bounding rectangle.
m_Rect: RectfBounding rectangle of the sprite’s graphic within the atlas image.
m_Bones: Option<Vec<SpriteBone>>Vec
m_Border: Option<Vector4f>Edge border size for a sprite (in pixels). Vector4f: (4.5.0 - 2022.3.2f1)
m_Edges: Option<Vec<int2_storage>>Vec<int2_storage>: (2018.1.0b2 - 2022.3.2f1)
m_Indices: Option<Vec<i32>>Vec
m_InternalID: Option<i64>i64: (2019.1.0b1 - 2022.3.2f1)
m_Outline: Option<Vec<Vec<Vector2f>>>Vec<Vec
m_PhysicsShape: Option<Vec<Vec<Vector2f>>>Vec<Vec
m_SpriteID: Option<String>String: (2018.1.0b2 - 2022.3.2f1)
m_TessellationDetail: Option<f32>f32: (5.4.0f3 - 2022.3.2f1)
m_Vertices: Option<Vec<Vector2f>>Vec
m_Weights: Option<Vec<BoneWeights4>>Vec