pub struct SpriteRenderer {Show 39 fields
pub m_CastShadows: Enum_bool__u8,
pub m_Color: ColorRGBA,
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_LightmapIndex: u16,
pub m_LightmapTilingOffset: Vector4f,
pub m_Materials: Vec<PPtr>,
pub m_ReceiveShadows: Enum_bool__u8,
pub m_SortingOrder: i16,
pub m_Sprite: PPtr,
pub m_StaticBatchRoot: PPtr,
pub m_AdaptiveModeThreshold: Option<f32>,
pub m_DrawMode: Option<i32>,
pub m_DynamicOccludee: Option<u8>,
pub m_FlipX: Option<bool>,
pub m_FlipY: Option<bool>,
pub m_LightProbeAnchor: Option<PPtr>,
pub m_LightProbeUsage: Option<u8>,
pub m_LightProbeVolumeOverride: Option<PPtr>,
pub m_LightmapIndexDynamic: Option<u16>,
pub m_LightmapTilingOffsetDynamic: Option<Vector4f>,
pub m_MaskInteraction: Option<i32>,
pub m_MotionVectors: Option<u8>,
pub m_ProbeAnchor: Option<PPtr>,
pub m_RayTraceProcedural: Option<u8>,
pub m_RayTracingMode: Option<u8>,
pub m_ReflectionProbeUsage: Option<i32>,
pub m_RendererPriority: Option<i32>,
pub m_RenderingLayerMask: Option<u32>,
pub m_Size: Option<Vector2f>,
pub m_SortingLayer: Option<i16>,
pub m_SortingLayerID: Option<i64>,
pub m_SpriteSortPoint: Option<i32>,
pub m_SpriteTileMode: Option<i32>,
pub m_StaticBatchInfo: Option<StaticBatchInfo>,
pub m_StaticShadowCaster: Option<u8>,
pub m_SubsetIndices: Option<Vec<u32>>,
pub m_UseLightProbes: Option<bool>,
pub m_WasSpriteAssigned: Option<bool>,
}Expand description
SpriteRenderer is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Renders a Sprite for 2D graphics.
Fields
m_CastShadows: Enum_bool__u8m_Color: ColorRGBARendering color for the Sprite graphic.
m_Enabled: boolMakes the rendered 3D object visible if enabled.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.3.0 - 2022.3.2f1)
m_LightmapIndex: u16The index of the baked lightmap applied to this renderer.
m_LightmapTilingOffset: Vector4fm_Materials: Vec<PPtr>Returns all the instantiated materials of this object.
Vec<PPtr<Material>>: (4.3.0 - 2022.3.2f1)
m_ReceiveShadows: Enum_bool__u8Does this object receive shadows?
m_SortingOrder: i16Renderer’s order within a sorting layer.
m_Sprite: PPtrThe Sprite to render.
PPtr<Sprite>: (4.3.0 - 2022.3.2f1)
m_StaticBatchRoot: PPtrPPtr<Transform>: (4.3.0 - 2022.3.2f1)
m_AdaptiveModeThreshold: Option<f32>The current threshold for Sprite Renderer tiling. f32: (5.6.0f1 - 2022.3.2f1)
m_DrawMode: Option<i32>The current draw mode of the Sprite Renderer. i32: (5.6.0f1 - 2022.3.2f1)
m_DynamicOccludee: Option<u8>u8: (2017.2.0b2 - 2022.3.2f1)
m_FlipX: Option<bool>Flips the sprite on the X axis. bool: (5.3.0f1 - 2022.3.2f1)
m_FlipY: Option<bool>Flips the sprite on the Y axis. bool: (5.3.0f1 - 2022.3.2f1)
m_LightProbeAnchor: Option<PPtr>PPtr<Transform>: (4.3.0 - 4.7.2)
m_LightProbeUsage: Option<u8>The light probe interpolation type. u8: (5.4.0f3 - 2022.3.2f1)
m_LightProbeVolumeOverride: Option<PPtr>PPtr<GameObject>: (5.4.0f3 - 2022.3.2f1)
m_LightmapIndexDynamic: Option<u16>u16: (5.0.0f4 - 2022.3.2f1)
m_LightmapTilingOffsetDynamic: Option<Vector4f>Vector4f: (5.0.0f4 - 2022.3.2f1)
m_MaskInteraction: Option<i32>Specifies how the sprite interacts with the masks. i32: (2017.1.0b1 - 2022.3.2f1)
m_MotionVectors: Option<u8>u8: (5.4.0f3 - 2022.3.2f1)
m_ProbeAnchor: Option<PPtr>If set, Renderer will use this Transform’s position to find the light or reflection probe.
PPtr<Transform>: (5.0.0f4 - 2022.3.2f1)
m_RayTraceProcedural: Option<u8>u8: (2020.1.0b1 - 2022.3.2f1)
m_RayTracingMode: Option<u8>Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)
m_ReflectionProbeUsage: Option<i32>Should reflection probes be used for this Renderer? i32: (5.0.0f4 - 5.3.8f2); u8: (5.4.0f3 - 2022.3.2f1)
m_RendererPriority: Option<i32>This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)
m_RenderingLayerMask: Option<u32>Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)
m_Size: Option<Vector2f>Property to set or get the size to render when the SpriteRenderer.drawMode is set to SpriteDrawMode.Sliced or SpriteDrawMode.Tiled. Vector2f: (5.6.0f1 - 2022.3.2f1)
m_SortingLayer: Option<i16>i16: (4.3.0 - 2022.3.2f1)
m_SortingLayerID: Option<i64>Unique ID of the Renderer’s sorting layer. u32: (4.5.0 - 4.7.2); i32: (5.0.0f4 - 2022.3.2f1)
m_SpriteSortPoint: Option<i32>Determines the position of the Sprite used for sorting the SpriteRenderer. i32: (2018.2.0b1 - 2022.3.2f1)
m_SpriteTileMode: Option<i32>i32: (5.6.0f1 - 2022.3.2f1)
m_StaticBatchInfo: Option<StaticBatchInfo>StaticBatchInfo: (5.5.0f3 - 2022.3.2f1)
m_StaticShadowCaster: Option<u8>Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)
m_SubsetIndices: Option<Vec<u32>>Vec
m_UseLightProbes: Option<bool>bool: (4.3.0 - 5.3.8f2)
m_WasSpriteAssigned: Option<bool>bool: (5.6.2f1 - 2022.3.2f1)