pub struct SpriteShapeRenderer {Show 31 fields
pub m_CastShadows: u8,
pub m_Color: ColorRGBA,
pub m_DynamicOccludee: u8,
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_LightProbeUsage: u8,
pub m_LightProbeVolumeOverride: PPtr,
pub m_LightmapIndex: u16,
pub m_LightmapIndexDynamic: u16,
pub m_LightmapTilingOffset: Vector4f,
pub m_LightmapTilingOffsetDynamic: Vector4f,
pub m_LocalAABB: AABB,
pub m_MaskInteraction: i32,
pub m_Materials: Vec<PPtr>,
pub m_MotionVectors: u8,
pub m_ProbeAnchor: PPtr,
pub m_ReceiveShadows: u8,
pub m_ReflectionProbeUsage: u8,
pub m_RenderingLayerMask: u32,
pub m_ShapeTexture: PPtr,
pub m_SortingLayer: i16,
pub m_SortingLayerID: i32,
pub m_SortingOrder: i16,
pub m_Sprites: Vec<PPtr>,
pub m_StaticBatchInfo: StaticBatchInfo,
pub m_StaticBatchRoot: PPtr,
pub m_RayTraceProcedural: Option<u8>,
pub m_RayTracingMode: Option<u8>,
pub m_RendererPriority: Option<i32>,
pub m_SpriteSortPoint: Option<i32>,
pub m_StaticShadowCaster: Option<u8>,
}Expand description
SpriteShapeRenderer is a class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: Renders SpriteShapes defined through the SpriteShapeUtility.GenerateSpriteShape API.
Fields
m_CastShadows: u8m_Color: ColorRGBARendering color for the SpriteShape.
m_DynamicOccludee: u8m_Enabled: boolMakes the rendered 3D object visible if enabled.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2018.1.0b2 - 2022.3.2f1)
m_LightProbeUsage: u8The light probe interpolation type.
m_LightProbeVolumeOverride: PPtrPPtr<GameObject>: (2018.1.0b2 - 2022.3.2f1)
m_LightmapIndex: u16The index of the baked lightmap applied to this renderer.
m_LightmapIndexDynamic: u16m_LightmapTilingOffset: Vector4fm_LightmapTilingOffsetDynamic: Vector4fm_LocalAABB: AABBm_MaskInteraction: i32Specifies how the SpriteShape interacts with the masks.
m_Materials: Vec<PPtr>Returns all the instantiated materials of this object.
Vec<PPtr<Material>>: (2018.1.0b2 - 2022.3.2f1)
m_MotionVectors: u8m_ProbeAnchor: PPtrIf set, Renderer will use this Transform’s position to find the light or reflection probe.
PPtr<Transform>: (2018.1.0b2 - 2022.3.2f1)
m_ReceiveShadows: u8Does this object receive shadows?
m_ReflectionProbeUsage: u8Should reflection probes be used for this Renderer?
m_RenderingLayerMask: u32Determines which rendering layer this renderer lives on.
m_ShapeTexture: PPtrPPtr<Texture2D>: (2018.1.0b2 - 2022.3.2f1)
m_SortingLayer: i16m_SortingLayerID: i32Unique ID of the Renderer’s sorting layer.
m_SortingOrder: i16Renderer’s order within a sorting layer.
m_Sprites: Vec<PPtr>Vec<PPtr<Sprite>>: (2018.1.0b2 - 2022.3.2f1)
m_StaticBatchInfo: StaticBatchInfom_StaticBatchRoot: PPtrPPtr<Transform>: (2018.1.0b2 - 2022.3.2f1)
m_RayTraceProcedural: Option<u8>u8: (2020.1.0b1 - 2022.3.2f1)
m_RayTracingMode: Option<u8>Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)
m_RendererPriority: Option<i32>This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)
m_SpriteSortPoint: Option<i32>i32: (2022.1.0b1 - 2022.3.2f1)
m_StaticShadowCaster: Option<u8>Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)