pub struct State {
pub m_IKOnFeet: bool,
pub m_Motions: Vec<PPtr>,
pub m_Name: String,
pub m_ParentStateMachine: PPtr,
pub m_Position: Vector3f,
pub m_Speed: f32,
pub m_Tag: String,
pub m_CycleOffset: Option<f32>,
pub m_Mirror: Option<bool>,
}Expand description
State is a class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Serializable structure used to hold the full internal state of the random number generator. See Also: Random.state.
Fields
m_IKOnFeet: boolm_Motions: Vec<PPtr>Vec<PPtr<[Motion]>>: (4.0.0 - 4.7.2)
m_Name: Stringm_ParentStateMachine: PPtrPPtr<StateMachine>: (4.0.0 - 4.7.2)
m_Position: Vector3fm_Speed: f32m_Tag: Stringm_CycleOffset: Option<f32>f32: (4.1.0 - 4.7.2)
m_Mirror: Option<bool>bool: (4.1.0 - 4.7.2)