SurfaceEffector2D

Struct SurfaceEffector2D 

pub struct SurfaceEffector2D {
    pub m_ColliderMask: BitField,
    pub m_Enabled: u8,
    pub m_GameObject: PPtr,
    pub m_Speed: f32,
    pub m_SpeedVariation: f32,
    pub m_ForceScale: Option<f32>,
    pub m_UseBounce: Option<bool>,
    pub m_UseColliderMask: Option<bool>,
    pub m_UseContactForce: Option<bool>,
    pub m_UseFriction: Option<bool>,
}
SurfaceEffector2D is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Applies tangent forces along the surfaces of colliders. When the source Collider2D is a trigger, the effector will apply forces whenever the target Collider2D overlaps the source. When the source Collider isn’t a trigger, the effector will apply forces whenever the target Collider2D is in contact with the source only.This effector can be used to create constant speed elevators and moving surfaces.

Fields

m_ColliderMask: BitField

The mask used to select specific layers allowed to interact with the effector.

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (5.0.0f4 - 2022.3.2f1)

m_Speed: f32

The speed to be maintained along the surface.

m_SpeedVariation: f32

The speed variation (from zero to the variation) added to base speed to be applied.

m_ForceScale: Option<f32>

The scale of the impulse force applied while attempting to reach the surface speed. f32: (5.0.1f1 - 2022.3.2f1)

m_UseBounce: Option<bool>

Should bounce be used for any contact with the surface? bool: (5.0.1f1 - 2022.3.2f1)

m_UseColliderMask: Option<bool>

Should the collider-mask be used or the global collision matrix? bool: (5.0.2f1 - 2022.3.2f1)

m_UseContactForce: Option<bool>

Should the impulse force but applied to the contact point? bool: (5.0.1f1 - 2022.3.2f1)

m_UseFriction: Option<bool>

Should friction be used for any contact with the surface? bool: (5.0.1f1 - 2022.3.2f1)