TakeInfo

Struct TakeInfo 

pub struct TakeInfo {
    pub bakeStartTime: f32,
    pub bakeStopTime: f32,
    pub clip: PPtr,
    pub defaultClipName: String,
    pub name: String,
    pub sampleRate: f32,
    pub startTime: f32,
    pub stopTime: f32,
    pub internalID: Option<i64>,
}
TakeInfo is a sub class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: A Takeinfo object contains all the information needed to describe a take. See Also: ModelImporter.importedTakeInfos.

Fields

bakeStartTime: f32

Start time in second.

bakeStopTime: f32

Stop time in second.

clip: PPtr

PPtr<AnimationClip>: (4.0.0 - 2022.3.2f1)

defaultClipName: String

This is the default clip name for the clip generated for this take.

name: String

Take name as define from imported file.

sampleRate: f32

Sample rate of the take.

startTime: f32

Start time in second.

stopTime: f32

Stop time in second.

internalID: Option<i64>

i64: (2019.1.0b1 - 2022.3.2f1)