pub struct TerrainCollider {
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_TerrainData: PPtr,
pub m_CreateTreeColliders: Option<bool>,
pub m_EnableTreeColliders: Option<bool>,
pub m_ExcludeLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_IsTrigger: Option<bool>,
pub m_LayerOverridePriority: Option<i32>,
pub m_Material: Option<PPtr>,
pub m_ProvidesContacts: Option<bool>,
}Expand description
TerrainCollider is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A heightmap based collider. See Also: SphereCollider, CapsuleCollider, PhysicMaterial, Rigidbody.
Fields
m_Enabled: boolEnabled Colliders will collide with other Colliders, disabled Colliders won’t.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_TerrainData: PPtrThe terrain that stores the heightmap.
PPtr<TerrainData>: (3.4.0 - 2022.3.2f1)
m_CreateTreeColliders: Option<bool>bool: (3.4.0 - 4.7.2)
m_EnableTreeColliders: Option<bool>bool: (5.0.0f4 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional layers that this Collider should exclude when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional layers that this Collider should include when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IsTrigger: Option<bool>Specify if this collider is configured as a trigger. bool: (3.4.0 - 4.7.2)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider used when there is a conflicting decision on whether a Collider can contact another Collider. i32: (2022.2.0b1 - 2022.3.2f1)
m_Material: Option<PPtr>The material used by the collider.
PPtr<PhysicMaterial>: (3.4.0 - 2022.3.2f1)
m_ProvidesContacts: Option<bool>Whether or not this Collider generates contacts for Physics.ContactEvent. bool: (2022.2.0b1 - 2022.3.2f1)