pub struct TerrainData {
pub m_DetailDatabase: DetailDatabase,
pub m_Heightmap: Heightmap,
pub m_Name: String,
pub m_SplatDatabase: SplatDatabase,
pub m_PreloadShaders: Option<Vec<PPtr>>,
}Expand description
TerrainData is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The TerrainData class stores heightmaps, detail mesh positions, tree instances, and terrain texture alpha maps. The Terrain component links to the terrain data and renders it.
Fields
m_DetailDatabase: DetailDatabasem_Heightmap: Heightmapm_Name: StringThe name of the object.
m_SplatDatabase: SplatDatabasem_PreloadShaders: Option<Vec<PPtr>>Vec<PPtr<Shader>>: (2018.4.14f1 - 2022.3.2f1)