TerrainLayer

Struct TerrainLayer 

pub struct TerrainLayer {
Show 14 fields pub m_DiffuseRemapMax: Vector4f, pub m_DiffuseRemapMin: Vector4f, pub m_DiffuseTexture: PPtr, pub m_MaskMapRemapMax: Vector4f, pub m_MaskMapRemapMin: Vector4f, pub m_MaskMapTexture: PPtr, pub m_Metallic: f32, pub m_Name: String, pub m_NormalMapTexture: PPtr, pub m_NormalScale: f32, pub m_Smoothness: f32, pub m_Specular: ColorRGBA, pub m_TileOffset: Vector2f, pub m_TileSize: Vector2f,
}
TerrainLayer is a class of the Unity engine since version 2018.3.0f2. Exert from Unity’s scripting documentation: Description of a terrain layer.

Fields

m_DiffuseRemapMax: Vector4f

A Vector4 value specifying the maximum RGBA value that the diffuse texture maps to when the value of the channel is 1.

m_DiffuseRemapMin: Vector4f

A Vector4 value specifying the minimum RGBA value that the diffuse texture maps to when the value of the channel is 0.

m_DiffuseTexture: PPtr

The diffuse texture used by the terrain layer. PPtr<Texture2D>: (2018.3.0f2 - 2022.3.2f1)

m_MaskMapRemapMax: Vector4f

A Vector4 value specifying the maximum RGBA value that the mask map texture maps to when the value of the channel is 1.

m_MaskMapRemapMin: Vector4f

A Vector4 value specifying the minimum RGBA value that the mask map texture maps to when the value of the channel is 0.

m_MaskMapTexture: PPtr

The mask map texture used by the terrain layer. PPtr<Texture2D>: (2018.3.0f2 - 2022.3.2f1)

m_Metallic: f32

Metallic factor used by the terrain layer.

m_Name: String

The name of the object.

m_NormalMapTexture: PPtr

Normal map texture used by the terrain layer. PPtr<Texture2D>: (2018.3.0f2 - 2022.3.2f1)

m_NormalScale: f32

A float value that scales the normal vector. The minimum value is 0, the maximum value is 1.

m_Smoothness: f32

Smoothness of the specular reflection.

m_Specular: ColorRGBA

Specular color.

m_TileOffset: Vector2f

UV tiling offset.

m_TileSize: Vector2f

UV Tiling size.