TrailRenderer

Struct TrailRenderer 

pub struct TrailRenderer {
Show 38 fields pub m_Autodestruct: bool, pub m_CastShadows: Enum_bool__u8, pub m_Enabled: bool, pub m_GameObject: PPtr, pub m_LightmapIndex: u16, pub m_LightmapTilingOffset: Vector4f, pub m_Materials: Vec<PPtr>, pub m_MinVertexDistance: f32, pub m_ReceiveShadows: Enum_bool__u8, pub m_StaticBatchRoot: PPtr, pub m_Time: f32, pub m_ApplyActiveColorSpace: Option<bool>, pub m_Colors: Option<Gradient>, pub m_DynamicOccludee: Option<u8>, pub m_Emitting: Option<bool>, pub m_EndWidth: Option<f32>, pub m_LightProbeAnchor: Option<PPtr>, pub m_LightProbeUsage: Option<u8>, pub m_LightProbeVolumeOverride: Option<PPtr>, pub m_LightmapIndexDynamic: Option<u16>, pub m_LightmapTilingOffsetDynamic: Option<Vector4f>, pub m_MaskInteraction: Option<i32>, pub m_MotionVectors: Option<u8>, pub m_Parameters: Option<LineParameters>, pub m_ProbeAnchor: Option<PPtr>, pub m_RayTraceProcedural: Option<u8>, pub m_RayTracingMode: Option<u8>, pub m_ReflectionProbeUsage: Option<i32>, pub m_RendererPriority: Option<i32>, pub m_RenderingLayerMask: Option<u32>, pub m_SortingLayer: Option<i16>, pub m_SortingLayerID: Option<i64>, pub m_SortingOrder: Option<i16>, pub m_StartWidth: Option<f32>, pub m_StaticBatchInfo: Option<StaticBatchInfo>, pub m_StaticShadowCaster: Option<u8>, pub m_SubsetIndices: Option<Vec<u32>>, pub m_UseLightProbes: Option<bool>,
}
TrailRenderer is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The trail renderer is used to make trails behind objects in the Scene as they move about. This class is a script interface for a trail renderer component.

Fields

m_Autodestruct: bool

Does the GameObject of this Trail Renderer auto destruct?

m_CastShadows: Enum_bool__u8m_Enabled: bool

Makes the rendered 3D object visible if enabled.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (3.4.0 - 2022.3.2f1)

m_LightmapIndex: u16

The index of the baked lightmap applied to this renderer.

m_LightmapTilingOffset: Vector4fm_Materials: Vec<PPtr>

Returns all the instantiated materials of this object. Vec<PPtr<Material>>: (3.4.0 - 2022.3.2f1)

m_MinVertexDistance: f32

Set the minimum distance the trail can travel before a new vertex is added to it.

m_ReceiveShadows: Enum_bool__u8

Does this object receive shadows?

m_StaticBatchRoot: PPtr

PPtr<Transform>: (3.4.0 - 2022.3.2f1)

m_Time: f32

How long does the trail take to fade out.

m_ApplyActiveColorSpace: Option<bool>

bool: (2022.1.0b1 - 2022.3.2f1)

m_Colors: Option<Gradient>

Gradient: (3.4.0 - 5.4.6f3)

m_DynamicOccludee: Option<u8>

u8: (2017.2.0b2 - 2022.3.2f1)

m_Emitting: Option<bool>

Creates trails when the GameObject moves. bool: (2018.2.0b1 - 2022.3.2f1)

m_EndWidth: Option<f32>

The width of the trail at the end of the trail. f32: (3.4.0 - 5.4.6f3)

m_LightProbeAnchor: Option<PPtr>

PPtr<Transform>: (3.5.0 - 4.7.2)

m_LightProbeUsage: Option<u8>

The light probe interpolation type. u8: (5.4.0f3 - 2022.3.2f1)

m_LightProbeVolumeOverride: Option<PPtr>

PPtr<GameObject>: (5.4.0f3 - 2022.3.2f1)

m_LightmapIndexDynamic: Option<u16>

u16: (5.0.0f4 - 2022.3.2f1)

m_LightmapTilingOffsetDynamic: Option<Vector4f>

Vector4f: (5.0.0f4 - 2022.3.2f1)

m_MaskInteraction: Option<i32>

Specifies how the TrailRenderer interacts with SpriteMask. i32: (2022.1.0b1 - 2022.3.2f1)

m_MotionVectors: Option<u8>

u8: (5.4.0f3 - 2022.3.2f1)

m_Parameters: Option<LineParameters>

LineParameters: (5.5.0f3 - 2022.3.2f1)

m_ProbeAnchor: Option<PPtr>

If set, Renderer will use this Transform’s position to find the light or reflection probe. PPtr<Transform>: (5.0.0f4 - 2022.3.2f1)

m_RayTraceProcedural: Option<u8>

u8: (2020.1.0b1 - 2022.3.2f1)

m_RayTracingMode: Option<u8>

Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)

m_ReflectionProbeUsage: Option<i32>

Should reflection probes be used for this Renderer? i32: (5.0.0f4 - 5.3.8f2); u8: (5.4.0f3 - 2022.3.2f1)

m_RendererPriority: Option<i32>

This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)

m_RenderingLayerMask: Option<u32>

Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)

m_SortingLayer: Option<i16>

i16: (4.3.0 - 2022.3.2f1)

m_SortingLayerID: Option<i64>

Unique ID of the Renderer’s sorting layer. u32: (4.5.0 - 4.7.2); i32: (5.0.0f4 - 2022.3.2f1)

m_SortingOrder: Option<i16>

Renderer’s order within a sorting layer. i16: (4.3.0 - 2022.3.2f1)

m_StartWidth: Option<f32>

The width of the trail at the spawning point. f32: (3.4.0 - 5.4.6f3)

m_StaticBatchInfo: Option<StaticBatchInfo>

StaticBatchInfo: (5.5.0f3 - 2022.3.2f1)

m_StaticShadowCaster: Option<u8>

Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)

m_SubsetIndices: Option<Vec<u32>>

Vec: (3.4.0 - 5.4.6f3)

m_UseLightProbes: Option<bool>

bool: (3.5.0 - 5.3.8f2)