pub struct Tree {
pub m_GameObject: PPtr,
pub m_SpeedTreeWindAsset: Option<PPtr>,
}Expand description
Tree is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Tree Component for the tree creator.
Fields
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_SpeedTreeWindAsset: Option<PPtr>PPtr<SpeedTreeWindAsset>: (5.0.0f4 - 2022.3.2f1)