pub struct TreePrototype {
pub bendFactor: f32,
pub prefab: PPtr,
pub navMeshLod: Option<i32>,
}Expand description
TreePrototype is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Simple class that contains a pointer to a tree prototype. This class is used by the TerrainData gameObject.
Fields
bendFactor: f32Bend factor of the tree prototype.
prefab: PPtrRetrieves the actual GameObject used by the tree.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
The LOD index of a Tree LODGroup that Unity uses to generate a NavMesh. It uses this value only for Trees with a LODGroup, and ignores this value for regular Trees. i32: (2020.2.0b1 - 2022.3.2f1)