pub struct VFXManager {
pub m_CopyBufferShader: PPtr,
pub m_FixedTimeStep: f32,
pub m_IndirectShader: PPtr,
pub m_MaxDeltaTime: f32,
pub m_RenderPipeSettingsPath: String,
pub m_SortShader: PPtr,
pub m_BatchEmptyLifetime: Option<u32>,
pub m_CompiledVersion: Option<u32>,
pub m_MaxScrubTime: Option<f32>,
pub m_RuntimeResources: Option<PPtr>,
pub m_RuntimeVersion: Option<u32>,
pub m_StripUpdateShader: Option<PPtr>,
}Expand description
VFXManager is a class of the Unity engine since version 2018.3.0f2. Exert from Unity’s scripting documentation: Use this class to set a number of properties that control VisualEffect behavior within your Unity Project.
Fields
m_CopyBufferShader: PPtrPPtr<ComputeShader>: (2018.3.0f2 - 2022.3.2f1)
m_FixedTimeStep: f32m_IndirectShader: PPtrPPtr<ComputeShader>: (2018.3.0f2 - 2022.3.2f1)
m_MaxDeltaTime: f32m_RenderPipeSettingsPath: Stringm_SortShader: PPtrPPtr<ComputeShader>: (2018.3.0f2 - 2022.3.2f1)
m_BatchEmptyLifetime: Option<u32>u32: (2022.2.0f1 - 2022.3.2f1)
m_CompiledVersion: Option<u32>u32: (2020.1.0b1 - 2022.3.2f1)
m_MaxScrubTime: Option<f32>f32: (2022.1.0b1 - 2022.3.2f1)
m_RuntimeResources: Option<PPtr>PPtr<MonoBehaviour>: (2021.2.0b1 - 2022.3.2f1)
m_RuntimeVersion: Option<u32>u32: (2020.1.0b1 - 2022.3.2f1)
m_StripUpdateShader: Option<PPtr>PPtr<ComputeShader>: (2019.3.0b1 - 2022.3.2f1)