pub struct VideoClip {Show 18 fields
pub Height: u32,
pub Width: u32,
pub m_AudioChannelCount: Vec<u16>,
pub m_AudioLanguage: Vec<String>,
pub m_AudioSampleRate: Vec<u32>,
pub m_ExternalResources: StreamedResource,
pub m_Format: i32,
pub m_FrameCount: u64,
pub m_FrameRate: f64,
pub m_HasSplitAlpha: bool,
pub m_Name: String,
pub m_OriginalPath: String,
pub m_ProxyHeight: u32,
pub m_ProxyWidth: u32,
pub m_PixelAspecRatioDen: Option<u32>,
pub m_PixelAspecRatioNum: Option<u32>,
pub m_VideoShaders: Option<Vec<PPtr>>,
pub m_sRGB: Option<bool>,
}Expand description
VideoClip is a class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: A container for video data. A VideoClip stores the video portion of a movie file using a codec that is appropriate for the target platform. VideoClips are referenced by VideoPlayers to play videos.
Fields
Height: u32The height of the images in the video clip in pixels. (Read Only).
Width: u32The width of the images in the video clip in pixels. (Read Only).
m_AudioChannelCount: Vec<u16>m_AudioLanguage: Vec<String>m_AudioSampleRate: Vec<u32>m_ExternalResources: StreamedResourcem_Format: i32m_FrameCount: u64The length of the VideoClip in frames. (Read Only).
m_FrameRate: f64The frame rate of the clip in frames/second. (Read Only).
m_HasSplitAlpha: boolm_Name: StringThe name of the object.
m_OriginalPath: StringThe video clip path in the project’s assets. (Read Only).
m_ProxyHeight: u32m_ProxyWidth: u32m_PixelAspecRatioDen: Option<u32>u32: (2017.2.0b2 - 2022.3.2f1)
m_PixelAspecRatioNum: Option<u32>u32: (2017.2.0b2 - 2022.3.2f1)
m_VideoShaders: Option<Vec<PPtr>>Vec<PPtr<Shader>>: (2020.1.0b1 - 2022.3.2f1)
m_sRGB: Option<bool>Whether the imported clip contains sRGB color data (Read Only). bool: (2019.2.0b1 - 2022.3.2f1)