VideoClipImporter

Struct VideoClipImporter 

pub struct VideoClipImporter {
Show 31 fields pub m_AssetBundleName: String, pub m_AssetBundleVariant: String, pub m_ColorSpace: i32, pub m_Deinterlace: i32, pub m_EncodeAlpha: bool, pub m_EndFrame: i32, pub m_FlipHorizontal: bool, pub m_FlipVertical: bool, pub m_FrameRange: i32, pub m_Name: String, pub m_Output: VideoClipImporterOutput, pub m_StartFrame: i32, pub m_TargetSettings: Vec<(i32, VideoClipImporterTargetSettings)>, pub m_UserData: String, pub m_AudioImportMode: Option<i32>, pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>, pub m_FrameCount: Option<i32>, pub m_FrameRate: Option<f64>, pub m_ImportAudio: Option<bool>, pub m_IsColorLinear: Option<bool>, pub m_OriginalHeight: Option<i32>, pub m_OriginalWidth: Option<i32>, pub m_PixelAspectRatioDenominator: Option<u32>, pub m_PixelAspectRatioNumerator: Option<u32>, pub m_Quality: Option<f32>, pub m_SourceAudioChannelCount: Option<Vec<u16>>, pub m_SourceAudioSampleRate: Option<Vec<u32>>, pub m_SourceFileSize: Option<u64>, pub m_SourceHasAlpha: Option<bool>, pub m_UseLegacyImporter: Option<bool>, pub m_UsedFileIDs: Option<Vec<i64>>,
}
VideoClipImporter is a class of the Unity engine since version 5.6.0b1. Exert from Unity’s scripting documentation: VideoClipImporter lets you modify VideoClip import settings from Editor scripts. See the Movie File Format Support Notes section in the VideoPlayer class documentation for supported movie file formats and encoding guidelines.

Fields

m_AssetBundleName: String

Get or set the AssetBundle name.

m_AssetBundleVariant: String

Get or set the AssetBundle variant.

m_ColorSpace: i32m_Deinterlace: i32m_EncodeAlpha: boolm_EndFrame: i32m_FlipHorizontal: bool

Apply a horizontal flip during import.

m_FlipVertical: bool

Apply a vertical flip during import.

m_FrameRange: i32m_Name: String

The name of the object.

m_Output: VideoClipImporterOutputm_StartFrame: i32m_TargetSettings: Vec<(i32, VideoClipImporterTargetSettings)>m_UserData: String

Get or set any user data.

m_AudioImportMode: Option<i32>

i32: (5.6.0b1 - 5.6.0b2)

m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>

Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)

m_FrameCount: Option<i32>

Number of frames in the clip. i32: (5.6.0b1 - 2017.2.1f1)

m_FrameRate: Option<f64>

Frame rate of the clip. f64: (5.6.0b1 - 2017.2.1f1)

m_ImportAudio: Option<bool>

Import audio tracks from source file. bool: (5.6.0f1 - 2022.3.2f1)

m_IsColorLinear: Option<bool>

bool: (5.6.0b1 - 2019.2.21f1)

m_OriginalHeight: Option<i32>

i32: (5.6.0b1 - 2017.2.1f1)

m_OriginalWidth: Option<i32>

i32: (5.6.0b1 - 2017.2.1f1)

m_PixelAspectRatioDenominator: Option<u32>

Denominator of the pixel aspect ratio (num:den). u32: (2017.2.0b2 - 2017.2.1f1)

m_PixelAspectRatioNumerator: Option<u32>

Numerator of the pixel aspect ratio (num:den). u32: (2017.2.0b2 - 2017.2.1f1)

m_Quality: Option<f32>

f32: (5.6.0b1 - 2019.2.21f1)

m_SourceAudioChannelCount: Option<Vec<u16>>

Vec: (5.6.0b1 - 2017.2.1f1)

m_SourceAudioSampleRate: Option<Vec<u32>>

Vec: (5.6.0b1 - 2017.2.1f1)

m_SourceFileSize: Option<u64>

Size in bytes of the file before importing. u64: (5.6.0b1 - 2017.2.1f1)

m_SourceHasAlpha: Option<bool>

True if the source file has a channel for per-pixel transparency. bool: (5.6.0b1 - 2017.2.1f1)

m_UseLegacyImporter: Option<bool>

bool: (5.6.0b1 - 2019.2.21f1)

m_UsedFileIDs: Option<Vec<i64>>

Vec: (2019.1.0b1 - 2022.3.2f1)