pub struct VisualEffect {
pub m_Asset: PPtr,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_PropertySheet: VFXPropertySheetSerializedBase,
pub m_ResetSeedOnPlay: Enum_bool__u8,
pub m_StartSeed: u32,
pub m_AllowInstancing: Option<u8>,
pub m_InitialEventName: Option<String>,
pub m_InitialEventNameOverriden: Option<u8>,
}Expand description
VisualEffect is a class of the Unity engine since version 2018.3.0f2. Exert from Unity’s scripting documentation: The visual effect class that references an VisualEffectAsset instance within the Scene.
Fields
m_Asset: PPtrPPtr<VisualEffectAsset>: (2018.3.0f2 - 2022.3.2f1)
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2018.3.0f2 - 2022.3.2f1)
m_PropertySheet: VFXPropertySheetSerializedBasem_ResetSeedOnPlay: Enum_bool__u8This property controls whether the visual effect generates a new seed for the random number generator with each call to VisualEffect.Play function.
m_StartSeed: u32The initial seed used for internal random number generator.
m_AllowInstancing: Option<u8>u8: (2022.2.0b1 - 2022.3.2f1)
m_InitialEventName: Option<String>The default event name. Unity calls this event when the VisualEffect awakes, or when you call VisualEffect.Reinit. String: (2019.3.0b1 - 2022.3.2f1)
m_InitialEventNameOverriden: Option<u8>u8: (2019.3.0b1 - 2022.3.2f1)