pub struct WheelJoint2D {Show 14 fields
pub m_Anchor: Vector2f,
pub m_ConnectedAnchor: Vector2f,
pub m_ConnectedRigidBody: PPtr,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_Motor: JointMotor2D,
pub m_Suspension: JointSuspension2D,
pub m_UseMotor: bool,
pub m_AutoConfigureConnectedAnchor: Option<bool>,
pub m_BreakAction: Option<i32>,
pub m_BreakForce: Option<f32>,
pub m_BreakTorque: Option<f32>,
pub m_CollideConnected: Option<bool>,
pub m_EnableCollision: Option<bool>,
}Expand description
WheelJoint2D is a class of the Unity engine since version 4.5.0. Exert from Unity’s scripting documentation: The wheel joint allows the simulation of wheels by providing a constraining suspension motion with an optional motor. See Also: JointSuspension2D.
Fields
m_Anchor: Vector2fThe joint’s anchor point on the object that has the joint component.
m_ConnectedAnchor: Vector2fThe joint’s anchor point on the second object (ie, the one which doesn’t have the joint component).
m_ConnectedRigidBody: PPtrPPtr<Rigidbody2D>: (4.5.0 - 2022.3.2f1)
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.5.0 - 2022.3.2f1)
m_Motor: JointMotor2DParameters for a motor force that is applied automatically to the Rigibody2D along the line.
m_Suspension: JointSuspension2DSet the joint suspension configuration.
m_UseMotor: boolShould a motor force be applied automatically to the Rigidbody2D?
m_AutoConfigureConnectedAnchor: Option<bool>Should the connectedAnchor be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)
m_BreakAction: Option<i32>The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)
m_BreakForce: Option<f32>The force that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_BreakTorque: Option<f32>The torque that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_CollideConnected: Option<bool>bool: (4.5.0 - 5.0.0f4)
m_EnableCollision: Option<bool>Should the two rigid bodies connected with this joint collide with each other? bool: (5.0.1f1 - 2022.3.2f1)