pub struct WindZone {
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_Mode: i32,
pub m_Radius: f32,
pub m_WindMain: f32,
pub m_WindPulseFrequency: f32,
pub m_WindPulseMagnitude: f32,
pub m_WindTurbulence: f32,
}Expand description
WindZone is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Wind Zones add realism to the trees you create by making them wave their branches and leaves as if blown by the wind. Note: This only works with trees created by the tree creator or imported from SpeedTree Modeler.
Fields
m_Enabled: u8m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_Mode: i32Defines the type of wind zone to be used (Spherical or Directional).
m_Radius: f32Radius of the Spherical Wind Zone (only active if the WindZoneMode is set to Spherical).
m_WindMain: f32The primary wind force.
m_WindPulseFrequency: f32Defines the frequency of the wind changes.
m_WindPulseMagnitude: f32Defines how much the wind changes over time.
m_WindTurbulence: f32The turbulence wind force.