pub struct AnimatorState {Show 19 fields
pub m_CycleOffset: f32,
pub m_IKOnFeet: bool,
pub m_Mirror: bool,
pub m_Motion: PPtr,
pub m_Name: String,
pub m_Position: Vector3f,
pub m_Speed: f32,
pub m_StateMachineBehaviours: Vec<PPtr>,
pub m_Tag: String,
pub m_Transitions: Vec<PPtr>,
pub m_WriteDefaultValues: bool,
pub m_CycleOffsetParameter: Option<String>,
pub m_CycleOffsetParameterActive: Option<bool>,
pub m_MirrorParameter: Option<String>,
pub m_MirrorParameterActive: Option<bool>,
pub m_SpeedParameter: Option<String>,
pub m_SpeedParameterActive: Option<bool>,
pub m_TimeParameter: Option<String>,
pub m_TimeParameterActive: Option<bool>,
}Expand description
AnimatorState is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: States are the basic building blocks of a state machine. Each state contains a Motion ( AnimationClip or BlendTree) which will play while the character is in that state. When an event in the game triggers a state transition, the character will be left in a new state whose animation sequence will then take over.
Fields
m_CycleOffset: f32Offset at which the animation loop starts. Useful for synchronizing looped animations.Units is normalized time.
m_IKOnFeet: boolShould Foot IK be respected for this state.
m_Mirror: boolShould the state be mirrored.
m_Motion: PPtrThe motion assigned to this state.
PPtr<[Motion]>: (5.0.0f4 - 2022.3.2f1)
m_Name: StringThe name of the object.
m_Position: Vector3fm_Speed: f32The default speed of the motion.
m_StateMachineBehaviours: Vec<PPtr>Vec<PPtr<MonoBehaviour>>: (5.0.0f4 - 2022.3.2f1)
m_Tag: StringA tag can be used to identify a state.
m_Transitions: Vec<PPtr>The transitions that are going out of the state.
Vec<PPtr<AnimatorStateTransition>>: (5.0.0f4 - 2022.3.2f1)
m_WriteDefaultValues: boolWhether or not the AnimatorStates writes back the default values for properties that are not animated by its Motion.
m_CycleOffsetParameter: Option<String>The animator controller parameter that drives the cycle offset value. String: (5.1.0f1 - 2022.3.2f1)
m_CycleOffsetParameterActive: Option<bool>Define if the cycle offset value is driven by an Animator controller parameter or by the value set in the editor. bool: (5.1.0f1 - 2022.3.2f1)
m_MirrorParameter: Option<String>The animator controller parameter that drives the mirror value. String: (5.1.0f1 - 2022.3.2f1)
m_MirrorParameterActive: Option<bool>Define if the mirror value is driven by an Animator controller parameter or by the value set in the editor. bool: (5.1.0f1 - 2022.3.2f1)
m_SpeedParameter: Option<String>The animator controller parameter that drives the speed value. String: (5.1.0f1 - 2022.3.2f1)
m_SpeedParameterActive: Option<bool>Define if the speed value is driven by an Animator controller parameter or by the value set in the editor. bool: (5.1.0f1 - 2022.3.2f1)
m_TimeParameter: Option<String>If timeParameterActive is true, the value of this Parameter will be used instead of normalized time. String: (2017.2.0b2 - 2022.3.2f1)
m_TimeParameterActive: Option<bool>If true, use value of given Parameter as normalized time. bool: (2017.2.0b2 - 2022.3.2f1)