pub struct AudioChorusFilter {
pub m_Delay: f32,
pub m_Depth: f32,
pub m_DryMix: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_Rate: f32,
pub m_WetMix1: f32,
pub m_WetMix2: f32,
pub m_WetMix3: f32,
pub m_FeedBack: Option<f32>,
}Expand description
AudioChorusFilter is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The Audio Chorus Filter takes an Audio Clip and processes it creating a chorus effect. The chorus effect modulates the original sound by a sinusoid low frequency oscillator (LFO). The output sounds like there are multiple sources emitting the same sound with slight variations (resembling a choir).See Also: Audio Chorus Filter information.
Fields
m_Delay: f32Chorus delay in ms. 0.1 to 100.0. Default = 40.0 ms.
m_Depth: f32Chorus modulation depth. 0.0 to 1.0. Default = 0.03.
m_DryMix: f32Volume of original signal to pass to output. 0.0 to 1.0. Default = 0.5.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_Rate: f32Chorus modulation rate in hz. 0.0 to 20.0. Default = 0.8 hz.
m_WetMix1: f32Volume of 1st chorus tap. 0.0 to 1.0. Default = 0.5.
m_WetMix2: f32Volume of 2nd chorus tap. This tap is 90 degrees out of phase of the first tap. 0.0 to 1.0. Default = 0.5.
m_WetMix3: f32Volume of 3rd chorus tap. This tap is 90 degrees out of phase of the second tap. 0.0 to 1.0. Default = 0.5.
m_FeedBack: Option<f32>f32: (3.4.0 - 4.1.5)