pub struct AudioReverbZone {Show 19 fields
pub m_DecayHFRatio: f32,
pub m_DecayTime: f32,
pub m_Density: f32,
pub m_Diffusion: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_HFReference: f32,
pub m_LFReference: f32,
pub m_MaxDistance: f32,
pub m_MinDistance: f32,
pub m_Reflections: i32,
pub m_ReflectionsDelay: f32,
pub m_Reverb: i32,
pub m_ReverbDelay: f32,
pub m_ReverbPreset: i32,
pub m_Room: i32,
pub m_RoomHF: i32,
pub m_RoomLF: i32,
pub m_RoomRolloffFactor: Option<f32>,
}Expand description
AudioReverbZone is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Reverb Zones are used when you want to create location based ambient effects in the Scene. As the Audio Listener moves into a Reverb Zone, the ambient effect associated with the zone is gradually applied.
At the max distance there is no effect and at the min distance the effect is fully applied.
For example you can gradually change your character’s footsteps sounds and create the
feeling like you where entering into a cavern, going trough a room,
swimming underwater, etc.You can always mix reverb zones to have combined effects.
For more info check Reverb Zones in the manual.
Fields
m_DecayHFRatio: f32High-frequency to mid-frequency decay time ratio.
m_DecayTime: f32Reverberation decay time at mid frequencies.
m_Density: f32Value that controls the modal density in the late reverberation decay.
m_Diffusion: f32Value that controls the echo density in the late reverberation decay.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_HFReference: f32Reference high frequency (hz).
m_LFReference: f32Reference low frequency (hz).
m_MaxDistance: f32The distance from the centerpoint that the reverb will not have any effect. Default = 15.0.
m_MinDistance: f32The distance from the centerpoint that the reverb will have full effect at. Default = 10.0.
m_Reflections: i32Early reflections level relative to room effect.
m_ReflectionsDelay: f32Initial reflection delay time.
m_Reverb: i32Late reverberation level relative to room effect.
m_ReverbDelay: f32Late reverberation delay time relative to initial reflection.
m_ReverbPreset: i32Set/Get reverb preset properties.
m_Room: i32Room effect level (at mid frequencies).
m_RoomHF: i32Relative room effect level at high frequencies.
m_RoomLF: i32Relative room effect level at low frequencies.
m_RoomRolloffFactor: Option<f32>f32: (3.4.0 - 5.6.0b9)