BuildSettings

Struct BuildSettings 

pub struct BuildSettings {
Show 30 fields pub enableDynamicBatching: bool, pub hasAdvancedVersion: bool, pub hasPROVersion: bool, pub hasPublishingRights: bool, pub hasShadows: bool, pub isEducationalBuild: bool, pub m_Version: String, pub buildGUID: Option<Enum_GUID__String>, pub buildTags: Option<Vec<String>>, pub enableMultipleDisplays: Option<bool>, pub enabledVRDevices: Option<Vec<String>>, pub hasClusterRendering: Option<bool>, pub hasLocalLightShadows: Option<bool>, pub hasOculusPlugin: Option<bool>, pub hasRenderTexture: Option<bool>, pub hasSoftShadows: Option<bool>, pub isDebugBuild: Option<bool>, pub isEmbedded: Option<bool>, pub isNoWatermarkBuild: Option<bool>, pub isPrototypingBuild: Option<bool>, pub isTrial: Option<bool>, pub isWsaHolographicRemotingEnabled: Option<bool>, pub levels: Option<Vec<String>>, pub m_AuthToken: Option<String>, pub m_GraphicsAPIs: Option<Vec<i32>>, pub preloadedPlugins: Option<Vec<String>>, pub runtimeClassHashes: Option<Vec<(i32, Enum_u32__Hash128)>>, pub scenes: Option<Vec<String>>, pub scriptHashes: Option<Vec<(Hash128, Hash128)>>, pub usesOnMouseEvents: Option<bool>,
}
BuildSettings is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Struct containing information on how to build content. Note: this struct and its members exist to provide low-level support for the Scriptable Build Pipeline package. This is intended for internal use only; use the Scriptable Build Pipeline package to implement a fully featured build pipeline. You can install this via the Unity Package Manager.

Fields

enableDynamicBatching: boolhasAdvancedVersion: boolhasPROVersion: boolhasPublishingRights: boolhasShadows: boolisEducationalBuild: boolm_Version: StringbuildGUID: Option<Enum_GUID__String>

GUID: (5.6.0f1 - 2022.2.1f1); String: (5.6.0b3 - 5.6.0b3)

buildTags: Option<Vec<String>>

Vec: (5.6.0b1 - 2022.3.2f1)

enableMultipleDisplays: Option<bool>

bool: (5.0.0f4 - 5.2.5f1)

enabledVRDevices: Option<Vec<String>>

Vec: (5.4.0f3 - 2022.3.2f1)

hasClusterRendering: Option<bool>

bool: (5.0.0f4 - 2022.3.2f1)

hasLocalLightShadows: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

hasOculusPlugin: Option<bool>

bool: (4.6.2 - 4.7.2)

hasRenderTexture: Option<bool>

bool: (3.4.0 - 5.2.5f1)

hasSoftShadows: Option<bool>

bool: (4.2.0 - 2022.3.2f1)

isDebugBuild: Option<bool>

bool: (3.4.0 - 2022.2.1f1)

isEmbedded: Option<bool>

bool: (4.0.0 - 2022.3.2f1)

isNoWatermarkBuild: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

isPrototypingBuild: Option<bool>

bool: (3.5.0 - 2022.3.2f1)

isTrial: Option<bool>

bool: (2018.3.0f2 - 2022.3.2f1)

isWsaHolographicRemotingEnabled: Option<bool>

bool: (2018.2.0b1 - 2018.2.8f1)

levels: Option<Vec<String>>

Vec: (3.4.0 - 5.0.4f1)

m_AuthToken: Option<String>

String: (3.4.0 - 2022.2.0a18)

m_GraphicsAPIs: Option<Vec<i32>>

Vec: (5.1.0f1 - 2022.3.2f1)

preloadedPlugins: Option<Vec<String>>

Vec: (5.0.0f4 - 2022.3.2f1)

runtimeClassHashes: Option<Vec<(i32, Enum_u32__Hash128)>>

Vec<(i32, u32)>: (3.5.0 - 4.7.2); Vec<(i32, Hash128)>: (5.0.0f4 - 2020.2.0a19)

scenes: Option<Vec<String>>

Vec: (5.1.0f1 - 2022.3.2f1)

scriptHashes: Option<Vec<(Hash128, Hash128)>>

Vec<(Hash128, Hash128)>: (5.0.0f4 - 2020.2.0a19)

usesOnMouseEvents: Option<bool>

bool: (4.0.0 - 2022.3.2f1)