pub struct CharacterController {Show 15 fields
pub m_Center: Vector3f,
pub m_GameObject: PPtr,
pub m_Height: f32,
pub m_MinMoveDistance: f32,
pub m_Radius: f32,
pub m_SkinWidth: f32,
pub m_SlopeLimit: f32,
pub m_StepOffset: f32,
pub m_Enabled: Option<bool>,
pub m_ExcludeLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_IsTrigger: Option<bool>,
pub m_LayerOverridePriority: Option<i32>,
pub m_Material: Option<PPtr>,
pub m_ProvidesContacts: Option<bool>,
}Expand description
CharacterController is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A CharacterController allows you to easily do movement constrained by collisions without having to deal with a rigidbody. A CharacterController is not affected by forces and will only move when you call the Move function.
It will then carry out the movement but be constrained by collisions.See Also: Character Controller component and Character animation examples
Fields
m_Center: Vector3fThe center of the character’s capsule relative to the transform’s position.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_Height: f32The height of the character’s capsule.
m_MinMoveDistance: f32Gets or sets the minimum move distance of the character controller.
m_Radius: f32The radius of the character’s capsule.
m_SkinWidth: f32The character’s collision skin width.
m_SlopeLimit: f32The character controllers slope limit in degrees.
m_StepOffset: f32The character controllers step offset in meters.
m_Enabled: Option<bool>Enabled Colliders will collide with other Colliders, disabled Colliders won’t. bool: (5.0.0f4 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional layers that this Collider should exclude when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional layers that this Collider should include when deciding if the Collider can contact another Collider. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IsTrigger: Option<bool>Specify if this collider is configured as a trigger. bool: (5.0.0f4 - 2022.3.2f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider used when there is a conflicting decision on whether a Collider can contact another Collider. i32: (2022.2.0b1 - 2022.3.2f1)
m_Material: Option<PPtr>The material used by the collider.
PPtr<PhysicMaterial>: (5.0.0f4 - 2022.3.2f1)
m_ProvidesContacts: Option<bool>Whether or not this Collider generates contacts for Physics.ContactEvent. bool: (2022.2.0b1 - 2022.3.2f1)