pub struct DistanceJoint2D {Show 14 fields
pub m_Anchor: Vector2f,
pub m_ConnectedAnchor: Vector2f,
pub m_ConnectedRigidBody: PPtr,
pub m_Distance: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_AutoConfigureConnectedAnchor: Option<bool>,
pub m_AutoConfigureDistance: Option<bool>,
pub m_BreakAction: Option<i32>,
pub m_BreakForce: Option<f32>,
pub m_BreakTorque: Option<f32>,
pub m_CollideConnected: Option<bool>,
pub m_EnableCollision: Option<bool>,
pub m_MaxDistanceOnly: Option<bool>,
}Expand description
DistanceJoint2D is a class of the Unity engine since version 4.3.0. Exert from Unity’s scripting documentation: Joint that keeps two Rigidbody2D objects a fixed distance apart. Note that unlike the SpringJoint2D component, the distance separating the objects is truly fixed and does not allow for any stretching.See Also: HingeJoint2D class, SliderJoint2D class, SpringJoint2D class.
Fields
m_Anchor: Vector2fThe joint’s anchor point on the object that has the joint component.
m_ConnectedAnchor: Vector2fThe joint’s anchor point on the second object (ie, the one which doesn’t have the joint component).
m_ConnectedRigidBody: PPtrPPtr<Rigidbody2D>: (4.3.0 - 2022.3.2f1)
m_Distance: f32The distance separating the two ends of the joint.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.3.0 - 2022.3.2f1)
m_AutoConfigureConnectedAnchor: Option<bool>Should the connectedAnchor be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)
m_AutoConfigureDistance: Option<bool>Should the distance be calculated automatically? bool: (5.3.0f1 - 2022.3.2f1)
m_BreakAction: Option<i32>The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)
m_BreakForce: Option<f32>The force that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_BreakTorque: Option<f32>The torque that needs to be applied for this joint to break. f32: (5.3.0f1 - 2022.3.2f1)
m_CollideConnected: Option<bool>bool: (4.3.0 - 5.0.0f4)
m_EnableCollision: Option<bool>Should the two rigid bodies connected with this joint collide with each other? bool: (5.0.1f1 - 2022.3.2f1)
m_MaxDistanceOnly: Option<bool>Whether to maintain a maximum distance only or not. If not then the absolute distance will be maintained instead. bool: (4.5.0 - 2022.3.2f1)