pub struct FixedJoint2D {
pub m_Anchor: Vector2f,
pub m_AutoConfigureConnectedAnchor: bool,
pub m_BreakForce: f32,
pub m_BreakTorque: f32,
pub m_ConnectedAnchor: Vector2f,
pub m_ConnectedRigidBody: PPtr,
pub m_DampingRatio: f32,
pub m_EnableCollision: bool,
pub m_Enabled: u8,
pub m_Frequency: f32,
pub m_GameObject: PPtr,
pub m_BreakAction: Option<i32>,
}Expand description
FixedJoint2D is a class of the Unity engine since version 5.3.0f1. Exert from Unity’s scripting documentation: Connects two Rigidbody2D together at their anchor points using a configurable spring.
Fields
m_Anchor: Vector2fThe joint’s anchor point on the object that has the joint component.
m_AutoConfigureConnectedAnchor: boolShould the connectedAnchor be calculated automatically?
m_BreakForce: f32The force that needs to be applied for this joint to break.
m_BreakTorque: f32The torque that needs to be applied for this joint to break.
m_ConnectedAnchor: Vector2fThe joint’s anchor point on the second object (ie, the one which doesn’t have the joint component).
m_ConnectedRigidBody: PPtrPPtr<Rigidbody2D>: (5.3.0f1 - 2022.3.2f1)
m_DampingRatio: f32The amount by which the spring force is reduced in proportion to the movement speed.
m_EnableCollision: boolShould the two rigid bodies connected with this joint collide with each other?
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_Frequency: f32The frequency at which the spring oscillates around the distance between the objects.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (5.3.0f1 - 2022.3.2f1)
m_BreakAction: Option<i32>The action to take when the joint breaks the breakForce or breakTorque. i32: (2022.2.0b1 - 2022.3.2f1)