pub struct Grid {
pub m_CellGap: Vector3f,
pub m_CellLayout: i32,
pub m_CellSize: Vector3f,
pub m_CellSwizzle: i32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
}Expand description
Grid is a class of the Unity engine since version 2017.2.0b2. Exert from Unity’s scripting documentation: Grid is the base class for plotting a layout of uniformly spaced points and lines. The Grid component stores dimensional data of the layout of the grid and provides helper functions to retrieve information about the grid, such as the conversion between the cell location and local space location of items within the grid.The layout of the Grid component is in the XY plane with the origin of the grid always beginning at (0, 0) and the X and Y coordinates of the grid only as positive values.Implements the interface GridLayout.
Fields
m_CellGap: Vector3fThe size of the gap between each cell in the layout.
m_CellLayout: i32The layout of the cells.
m_CellSize: Vector3fThe size of each cell in the layout.
m_CellSwizzle: i32The cell swizzle for the layout.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2017.2.0b2 - 2022.3.2f1)