pub struct Hash128 {Show 16 fields
pub bytes_0_: Option<u8>,
pub bytes_10_: Option<u8>,
pub bytes_11_: Option<u8>,
pub bytes_12_: Option<u8>,
pub bytes_13_: Option<u8>,
pub bytes_14_: Option<u8>,
pub bytes_15_: Option<u8>,
pub bytes_1_: Option<u8>,
pub bytes_2_: Option<u8>,
pub bytes_3_: Option<u8>,
pub bytes_4_: Option<u8>,
pub bytes_5_: Option<u8>,
pub bytes_6_: Option<u8>,
pub bytes_7_: Option<u8>,
pub bytes_8_: Option<u8>,
pub bytes_9_: Option<u8>,
}Expand description
Hash128 is a sub class of the Unity engine since version 4.1.0. Exert from Unity’s scripting documentation: Represents a 128-bit hash value. Use Hash128 to uniquely identify a piece of data. A 128-bit hash value has an extremely low probability of hash collisions, so you can assume that if the hash values of two pieces of data are identical, then the data is identical too. For example, to quickly determine whether texture pixel contents have changed, or if they are identical between several textures, you can use Texture.imageContentsHash.To compute the hash values for some data, use the Hash128.Compute function. To compute the hash values incrementally for several pieces of data, use Hash128.Append. The hash algorithm used to compute Hash128 values is SpookyHash V2. Note that while this hash algorithm is quite fast to compute and has good hash distribution qualities, it is not a cryptographic hash function.
Fields
bytes_0_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_10_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_11_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_12_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_13_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_14_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_15_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_1_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_2_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_3_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_4_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_5_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_6_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_7_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_8_: Option<u8>u8: (4.1.0 - 2022.3.2f1)
bytes_9_: Option<u8>u8: (4.1.0 - 2022.3.2f1)