pub struct HingeJoint {Show 22 fields
pub m_Anchor: Vector3f,
pub m_Axis: Vector3f,
pub m_BreakForce: f32,
pub m_BreakTorque: f32,
pub m_ConnectedBody: PPtr,
pub m_GameObject: PPtr,
pub m_Limits: JointLimits,
pub m_Motor: JointMotor,
pub m_Spring: JointSpring,
pub m_UseLimits: bool,
pub m_UseMotor: bool,
pub m_UseSpring: bool,
pub m_AutoConfigureConnectedAnchor: Option<bool>,
pub m_ConnectedAnchor: Option<Vector3f>,
pub m_ConnectedArticulationBody: Option<PPtr>,
pub m_ConnectedMassScale: Option<f32>,
pub m_EnableCollision: Option<bool>,
pub m_EnablePreprocessing: Option<bool>,
pub m_Enabled: Option<bool>,
pub m_ExtendedLimits: Option<bool>,
pub m_MassScale: Option<f32>,
pub m_UseAcceleration: Option<bool>,
}Expand description
HingeJoint is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The HingeJoint groups together 2 rigid bodies, constraining them to move like connected by a hinge. This joint is great for, well, doors, but can also be used to model chains, etc…The HingeJoint has a motor which can be used to make the hinge spin around the joints axis.
A spring which attempts to reach for a target angle by spinning around the joints axis.
And a limit which constrains the joint angle.
Fields
m_Anchor: Vector3fThe Position of the anchor around which the joints motion is constrained.
m_Axis: Vector3fThe Direction of the axis around which the body is constrained.
m_BreakForce: f32The force that needs to be applied for this joint to break.
m_BreakTorque: f32The torque that needs to be applied for this joint to break. To be able to break, a joint must be Locked or Limited on the axis of rotation where the torque is being applied. This means that some joints cannot break, such as an unconstrained Configurable Joint.
m_ConnectedBody: PPtrA reference to another rigidbody this joint connects to.
PPtr<Rigidbody>: (3.4.0 - 2022.3.2f1)
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_Limits: JointLimitsLimit of angular rotation (in degrees) on the hinge joint.
m_Motor: JointMotorThe motor will apply a force up to a maximum force to achieve the target velocity in degrees per second.
m_Spring: JointSpringThe spring attempts to reach a target angle by adding spring and damping forces.
m_UseLimits: boolEnables the joint’s limits. Disabled by default.
m_UseMotor: boolEnables the joint’s motor. Disabled by default.
m_UseSpring: boolEnables the joint’s spring. Disabled by default.
m_AutoConfigureConnectedAnchor: Option<bool>Should the connectedAnchor be calculated automatically? bool: (4.3.0 - 2022.3.2f1)
m_ConnectedAnchor: Option<Vector3f>Position of the anchor relative to the connected Rigidbody. Vector3f: (4.3.0 - 2022.3.2f1)
m_ConnectedArticulationBody: Option<PPtr>A reference to an articulation body this joint connects to.
PPtr<ArticulationBody>: (2020.2.0b1 - 2022.3.2f1)
m_ConnectedMassScale: Option<f32>The scale to apply to the inverse mass and inertia tensor of the connected body prior to solving the constraints. f32: (2017.1.0b2 - 2022.3.2f1)
m_EnableCollision: Option<bool>Enable collision between bodies connected with the joint. bool: (4.5.0 - 2022.3.2f1)
m_EnablePreprocessing: Option<bool>Toggle preprocessing for this joint. bool: (5.0.0f4 - 2022.3.2f1)
m_Enabled: Option<bool>bool: (2017.1.0b2 - 2017.1.0b5)
m_ExtendedLimits: Option<bool>If enabled, the angle of the hinge is extended to [-360, 360] degrees. bool: (2022.2.0b1 - 2022.3.2f1)
m_MassScale: Option<f32>The scale to apply to the inverse mass and inertia tensor of the body prior to solving the constraints. f32: (2017.1.0b2 - 2022.3.2f1)
m_UseAcceleration: Option<bool>Defines whether the HingeJoint.spring outputs accelerations instead of forces. bool: (2022.2.0b1 - 2022.3.2f1)