pub struct HumanBone {
pub m_BoneName: String,
pub m_HumanName: String,
pub m_Limit: SkeletonBoneLimit,
}Expand description
HumanBone is a sub class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: The mapping between a bone in the model and the conceptual bone in the Mecanim human anatomy. The names of the Mecanim human bone and the bone in the model are stored along with the limiting muscle values that constrain the bone’s rotation during animation. See Also: HumanDescription, AvatarBuilder.
Fields
m_BoneName: StringThe name of the bone to which the Mecanim human bone is mapped.
m_HumanName: StringThe name of the Mecanim human bone to which the bone from the model is mapped.
m_Limit: SkeletonBoneLimitThe rotation limits that define the muscle for this bone.