HumanPose

Struct HumanPose 

pub struct HumanPose {
    pub m_DoFArray: Vec<f32>,
    pub m_GoalArray: Vec<HumanGoal>,
    pub m_LeftHandPose: HandPose,
    pub m_LookAtPosition: Enum_float4__float3,
    pub m_LookAtWeight: float4,
    pub m_RightHandPose: HandPose,
    pub m_RootX: xform,
    pub m_TDoFArray: Option<Vec<Enum_float3__float4>>,
}
HumanPose is a sub class of the Unity engine since version 4.0.0. Exert from Unity’s scripting documentation: Retargetable humanoid pose. Represents a humanoid pose that is completely abstracted from any skeleton rig. See Also: HumanPoseHandler.

Fields

m_DoFArray: Vec<f32>m_GoalArray: Vec<HumanGoal>m_LeftHandPose: HandPosem_LookAtPosition: Enum_float4__float3m_LookAtWeight: float4m_RightHandPose: HandPosem_RootX: xformm_TDoFArray: Option<Vec<Enum_float3__float4>>

Vec: (5.2.0f2 - 5.3.8f2); Vec: (5.4.0f3 - 2022.3.2f1)