pub struct InheritVelocityModule {
pub enabled: bool,
pub m_Curve: MinMaxCurve,
pub m_Mode: i32,
}Expand description
InheritVelocityModule is a sub class of the Unity engine since version 5.3.0f1. Exert from Unity’s scripting documentation: The Inherit Velocity Module controls how the velocity of the emitter is transferred to the particles as they are emitted. NOTE: The inherit velocity module only has an effect if the Particle System is set to simulate in world space. If the system is simulating in local space, this module is ignored.
See Also: ParticleSystem, ParticleSystem.inheritVelocity.
Fields
enabled: boolSpecifies whether the InheritVelocityModule is enabled or disabled.
m_Curve: MinMaxCurveCurve to define how much of the emitter velocity the system applies during the lifetime of a particle.
m_Mode: i32Specifies how to apply emitter velocity to particles.