pub struct Keyframe {
pub inSlope: Quaternionf,
pub outSlope: Quaternionf,
pub time: f32,
pub value: Quaternionf,
pub inWeight: Option<Quaternionf>,
pub outWeight: Option<Quaternionf>,
pub weightedMode: Option<i32>,
}Expand description
Keyframe is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A single keyframe that can be injected into an animation curve.
Fields
inSlope: QuaternionfoutSlope: Quaternionftime: f32The time of the keyframe.
value: QuaternionfThe value of the curve at keyframe.
inWeight: Option<Quaternionf>Sets the incoming weight for this key. The incoming weight affects the slope of the curve from the previous key to this key. Quaternionf: (2018.1.0b2 - 2022.3.2f1)
outWeight: Option<Quaternionf>Sets the outgoing weight for this key. The outgoing weight affects the slope of the curve from this key to the next key. Quaternionf: (2018.1.0b2 - 2022.3.2f1)
weightedMode: Option<i32>Weighted mode for the keyframe. i32: (2018.1.0b2 - 2022.3.2f1)