pub struct LightProbeGroup {
pub m_GameObject: PPtr,
pub m_Enabled: Option<u8>,
}Expand description
LightProbeGroup is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Light Probe Group.
Fields
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.5.0 - 2022.3.2f1)
m_Enabled: Option<u8>Enabled Behaviours are Updated, disabled Behaviours are not. u8: (4.0.0 - 2022.3.2f1)