pub struct LightProbeProxyVolume {Show 14 fields
pub m_BoundingBoxMode: i32,
pub m_BoundingBoxOrigin: Vector3f,
pub m_BoundingBoxSize: Vector3f,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_ProbePositionMode: i32,
pub m_RefreshMode: i32,
pub m_ResolutionMode: i32,
pub m_ResolutionProbesPerUnit: f32,
pub m_ResolutionX: u32,
pub m_ResolutionY: u32,
pub m_ResolutionZ: u32,
pub m_DataFormat: Option<i32>,
pub m_QualityMode: Option<i32>,
}Expand description
LightProbeProxyVolume is a class of the Unity engine since version 5.4.0f3. Exert from Unity’s scripting documentation: The Light Probe Proxy Volume component offers the possibility to use higher resolution lighting for large non-static GameObjects. By default, a probe-lit Renderer receives lighting from a single Light Probe that is interpolated from the surrounding Light Probes in the Scene. Because of this, GameObjects have constant ambient lighting regardless of their position on the surface. The light has have a rotational gradient because it’s using spherical harmonics, but it lacks a spatial gradient. This is more noticeable on larger GameObjects and Particle Systems. The lighting across the GameObject matches the lighting at the anchor point, and if the GameObject straddles a lighting gradient, parts of the GameObject will look incorrect.This component will generate a 3D grid of interpolated Light Probes inside a bounding volume. The resolution of the grid can be user-specified. The spherical harmonics coefficients of the interpolated Light Probes are updated into 3D textures, which are sampled at render time to compute the contribution to the diffuse ambient lighting. This adds a spatial gradient to probe-lit GameObjects.See Also: Light Probes.
Fields
m_BoundingBoxMode: i32The bounding box mode for generating the 3D grid of interpolated Light Probes.
m_BoundingBoxOrigin: Vector3fm_BoundingBoxSize: Vector3fm_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (5.4.0f3 - 2022.3.2f1)
m_ProbePositionMode: i32The mode in which the interpolated Light Probe positions are generated.
m_RefreshMode: i32Sets the way the Light Probe Proxy Volume refreshes.
m_ResolutionMode: i32The resolution mode for generating the grid of interpolated Light Probes.
m_ResolutionProbesPerUnit: f32m_ResolutionX: u32m_ResolutionY: u32m_ResolutionZ: u32m_DataFormat: Option<i32>The texture data format used by the Light Probe Proxy Volume 3D texture. i32: (2020.2.0b1 - 2022.3.2f1)
m_QualityMode: Option<i32>Determines how many Spherical Harmonics bands will be evaluated to compute the ambient color. i32: (2018.2.0b2 - 2022.3.2f1)