pub struct LightmapData {
pub m_Lightmap: PPtr,
pub m_DirLightmap: Option<PPtr>,
pub m_IndirectLightmap: Option<PPtr>,
pub m_ShadowMask: Option<PPtr>,
}Expand description
LightmapData is a sub class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: Data of a lightmap. A Scene can have several lightmaps stored in it, and Renderer components can use those lightmaps. This makes it possible to use the same material on multiple objects, while each object can refer to a different lightmap or different portion of the same lightmap.You must set the following properties or Unity might render objects incorrectly:
Fields
m_Lightmap: PPtrPPtr<Texture2D>: (3.4.0 - 2022.3.2f1)
m_DirLightmap: Option<PPtr>PPtr<Texture2D>: (5.6.0f1 - 2022.3.2f1)
m_IndirectLightmap: Option<PPtr>PPtr<Texture2D>: (3.4.0 - 5.6.0b1)
m_ShadowMask: Option<PPtr>Texture storing occlusion mask per light (ShadowMask, up to four lights).
PPtr<Texture2D>: (5.6.0f1 - 2022.3.2f1)