pub struct MinMaxGradient {
pub maxColor: ColorRGBA,
pub maxGradient: Enum_GradientNEW__Gradient,
pub minColor: ColorRGBA,
pub minGradient: Enum_GradientNEW__Gradient,
pub minMaxState: i32,
}Expand description
MinMaxGradient is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for a Min-Max Gradient. This contains two Gradients, and returns a Color based on ParticleSystem.MinMaxGradient.mode. Depending on the mode, this may return the value randomized.
Gradients are edited via the ParticleSystem Inspector once a ParticleSystemGradientMode requiring them has been selected. Some modes do not require gradients, only colors.
See Also: ParticleSystem.
Fields
maxColor: ColorRGBAmaxGradient: Enum_GradientNEW__GradientminColor: ColorRGBAminGradient: Enum_GradientNEW__GradientminMaxState: i32Trait Implementations
Sourceimpl Debug for MinMaxGradient
impl Debug for MinMaxGradient
Sourceimpl<'de> Deserialize<'de> for MinMaxGradient
impl<'de> Deserialize<'de> for MinMaxGradient
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more