pub struct NavMesh {
pub m_Heightmaps: Vec<HeightmapData>,
pub m_MeshData: Vec<u8>,
pub m_Name: String,
}Expand description
NavMesh is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Singleton class to access the baked NavMesh. Use the NavMesh class to perform spatial queries such as pathfinding and walkability tests. This class also lets you set the pathfinding cost for specific area types, and tweak the global behavior of pathfinding and avoidance.Before you can use spatial queries, you must first bake the NavMesh to your scene.See also: • Building a NavMesh – for more information on how to setup and bake NavMesh • Areas and Costs – to learn how to use different Area types. • NavMeshAgent – to learn how to control and move NavMesh Agents. • NavMeshObstacle – to learn how to control NavMesh Obstacles using scripting. • OffMeshLink – to learn how to control Off-Mesh Links using scripting.
Fields
m_Heightmaps: Vec<HeightmapData>m_MeshData: Vec<u8>m_Name: String