pub struct NavMeshAgent {Show 16 fields
pub m_Acceleration: f32,
pub m_AngularSpeed: f32,
pub m_AutoRepath: bool,
pub m_AutoTraverseOffMeshLink: bool,
pub m_BaseOffset: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_Height: f32,
pub m_ObstacleAvoidanceType: i32,
pub m_Radius: f32,
pub m_Speed: f32,
pub m_StoppingDistance: f32,
pub m_WalkableMask: u32,
pub avoidancePriority: Option<i32>,
pub m_AgentTypeID: Option<i32>,
pub m_AutoBraking: Option<bool>,
}Expand description
NavMeshAgent is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Navigation mesh agent. This component is attached to a mobile character in the game to allow it to navigate the Scene using the NavMesh. See the Navigation section of the manual for further details.
Fields
m_Acceleration: f32The maximum acceleration of an agent as it follows a path, given in units / sec^2.
m_AngularSpeed: f32Maximum turning speed in (deg/s) while following a path.
m_AutoRepath: boolShould the agent attempt to acquire a new path if the existing path becomes invalid?
m_AutoTraverseOffMeshLink: boolShould the agent move across OffMeshLinks automatically?
m_BaseOffset: f32The relative vertical displacement of the owning GameObject.
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.5.0 - 2022.3.2f1)
m_Height: f32The height of the agent for purposes of passing under obstacles, etc.
m_ObstacleAvoidanceType: i32The level of quality of avoidance.
m_Radius: f32The avoidance radius for the agent.
m_Speed: f32Maximum movement speed when following a path.
m_StoppingDistance: f32Stop within this distance from the target position.
m_WalkableMask: u32avoidancePriority: Option<i32>The avoidance priority level. i32: (4.0.0 - 2022.3.2f1)
m_AgentTypeID: Option<i32>The type ID for the agent. i32: (5.6.0b1 - 2022.3.2f1)
m_AutoBraking: Option<bool>Should the agent brake automatically to avoid overshooting the destination point? bool: (4.1.0 - 2022.3.2f1)