NavMeshData

Struct NavMeshData 

pub struct NavMeshData {
    pub m_HeightMeshes: Vec<HeightMeshData>,
    pub m_Heightmaps: Vec<HeightmapData>,
    pub m_Name: String,
    pub m_NavMeshTiles: Vec<NavMeshTileData>,
    pub m_OffMeshLinks: Vec<AutoOffMeshLinkData>,
    pub m_AgentTypeID: Option<i32>,
    pub m_NavMeshBuildSettings: Option<NavMeshBuildSettings>,
    pub m_NavMeshParams: Option<NavMeshParams>,
    pub m_Position: Option<Vector3f>,
    pub m_Rotation: Option<Quaternionf>,
    pub m_SourceBounds: Option<AABB>,
}
NavMeshData is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Contains and represents NavMesh data. An object of this class can be used for creating instances of NavMeshes. See NavMesh.AddNavMeshData. The contained NavMesh can be built and updated using the build API. See NavMeshBuilder and methods therein.

Fields

m_HeightMeshes: Vec<HeightMeshData>m_Heightmaps: Vec<HeightmapData>m_Name: String

The name of the object.

m_NavMeshTiles: Vec<NavMeshTileData>m_OffMeshLinks: Vec<AutoOffMeshLinkData>m_AgentTypeID: Option<i32>

i32: (5.6.1f1 - 2022.3.2f1)

m_NavMeshBuildSettings: Option<NavMeshBuildSettings>

NavMeshBuildSettings: (5.6.0b1 - 2022.3.2f1)

m_NavMeshParams: Option<NavMeshParams>

NavMeshParams: (5.0.0f4 - 5.5.6f1)

m_Position: Option<Vector3f>

Gets or sets the world space position of the NavMesh data. Vector3f: (5.6.1f1 - 2022.3.2f1)

m_Rotation: Option<Quaternionf>

Gets or sets the orientation of the NavMesh data. Quaternionf: (5.6.1f1 - 2022.3.2f1)

m_SourceBounds: Option<AABB>

Returns the bounding volume of the input geometry used to build this NavMesh (Read Only). AABB: (5.6.1f1 - 2022.3.2f1)