NetworkView

Struct NetworkView 

pub struct NetworkView {
    pub m_Enabled: u8,
    pub m_GameObject: PPtr,
    pub m_Observed: PPtr,
    pub m_StateSynchronization: i32,
    pub m_ViewID: NetworkViewID,
}
NetworkView is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The network view is the binding material of multiplayer games. With this you can define exactly what is to be synchronized over the network and how it should be done. Game objects can have NetworkView components which can be configured to watch other components for the object. For more information see the Network View manual page and the component reference page.

Fields

m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (3.4.0 - 2018.1.9f2)

m_Observed: PPtr

PPtr<Component>: (3.4.0 - 2018.1.9f2)

m_StateSynchronization: i32m_ViewID: NetworkViewID