pub struct ParticleSystemForceField {
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_Parameters: ParticleSystemForceFieldParameters,
}Expand description
ParticleSystemForceField is a class of the Unity engine since version 2018.3.0f2. Exert from Unity’s scripting documentation: Script interface for Particle System Force Fields. Particle System Force Fields can be used to influence groups of particles that enter each field’s zone of influence.The shape of the Force Field can be set to a variety of shapes, and how the particles are affected is controlled by various properties in the Force Field.As part of choosing the shape, you may define a start and end range. The end range describes the maximum extent of the shape, and the start range can be used to create a hollow shape.A number of forces can be applied to particles that are within this volume: directional, gravitational, rotational, drag, and a vector field.The settings for each type of force make use of the MinMaxCurve type, which is also used in the Particle System. This type allows you to set simple uniform values, or more complicated values that vary per-particle, and vary over the lifetime of each particle.
Fields
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2018.3.0f2 - 2022.3.2f1)
m_Parameters: ParticleSystemForceFieldParameters