ParticleSystemRenderer

Struct ParticleSystemRenderer 

pub struct ParticleSystemRenderer {
Show 59 fields pub m_CameraVelocityScale: f32, pub m_CastShadows: Enum_bool__u8, pub m_Enabled: bool, pub m_GameObject: PPtr, pub m_LengthScale: f32, pub m_LightmapIndex: u16, pub m_LightmapTilingOffset: Vector4f, pub m_Materials: Vec<PPtr>, pub m_MaxParticleSize: f32, pub m_Mesh: PPtr, pub m_ReceiveShadows: Enum_bool__u8, pub m_RenderMode: i32, pub m_SortMode: i32, pub m_SortingFudge: f32, pub m_StaticBatchRoot: PPtr, pub m_VelocityScale: f32, pub m_AllowRoll: Option<bool>, pub m_ApplyActiveColorSpace: Option<bool>, pub m_DynamicOccludee: Option<u8>, pub m_EnableGPUInstancing: Option<bool>, pub m_Flip: Option<Vector3f>, pub m_FreeformStretching: Option<bool>, pub m_LightProbeAnchor: Option<PPtr>, pub m_LightProbeUsage: Option<u8>, pub m_LightProbeVolumeOverride: Option<PPtr>, pub m_LightmapIndexDynamic: Option<u16>, pub m_LightmapTilingOffsetDynamic: Option<Vector4f>, pub m_MaskInteraction: Option<i32>, pub m_Mesh1: Option<PPtr>, pub m_Mesh2: Option<PPtr>, pub m_Mesh3: Option<PPtr>, pub m_MeshDistribution: Option<u8>, pub m_MeshWeighting: Option<f32>, pub m_MeshWeighting1: Option<f32>, pub m_MeshWeighting2: Option<f32>, pub m_MeshWeighting3: Option<f32>, pub m_MinParticleSize: Option<f32>, pub m_MotionVectors: Option<u8>, pub m_NormalDirection: Option<f32>, pub m_Pivot: Option<Vector3f>, pub m_ProbeAnchor: Option<PPtr>, pub m_RayTraceProcedural: Option<u8>, pub m_RayTracingMode: Option<u8>, pub m_ReflectionProbeUsage: Option<i32>, pub m_RenderAlignment: Option<i32>, pub m_RendererPriority: Option<i32>, pub m_RenderingLayerMask: Option<u32>, pub m_RotateWithStretchDirection: Option<bool>, pub m_ShadowBias: Option<f32>, pub m_SortingLayer: Option<i16>, pub m_SortingLayerID: Option<i64>, pub m_SortingOrder: Option<i16>, pub m_StaticBatchInfo: Option<StaticBatchInfo>, pub m_StaticShadowCaster: Option<u8>, pub m_SubsetIndices: Option<Vec<u32>>, pub m_UseCustomVertexStreams: Option<bool>, pub m_UseLightProbes: Option<bool>, pub m_VertexStreamMask: Option<i32>, pub m_VertexStreams: Option<Vec<u8>>,
}
ParticleSystemRenderer is a class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Use this class to render particles on to the screen.

Fields

m_CameraVelocityScale: f32

How much do the particles stretch depending on the Camera’s speed.

m_CastShadows: Enum_bool__u8m_Enabled: bool

Makes the rendered 3D object visible if enabled.

m_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (3.5.0 - 2022.3.2f1)

m_LengthScale: f32

How much are the particles stretched in their direction of motion, defined as the length of the particle compared to its width.

m_LightmapIndex: u16

The index of the baked lightmap applied to this renderer.

m_LightmapTilingOffset: Vector4fm_Materials: Vec<PPtr>

Returns all the instantiated materials of this object. Vec<PPtr<Material>>: (3.5.0 - 2022.3.2f1)

m_MaxParticleSize: f32

Clamp the maximum particle size.

m_Mesh: PPtr

The Mesh that the particle uses instead of a billboarded Texture. PPtr<Mesh>: (3.5.0 - 2022.3.2f1)

m_ReceiveShadows: Enum_bool__u8

Does this object receive shadows?

m_RenderMode: i32

Specifies how the system draws particles.

m_SortMode: i32

Specifies how to sort particles within a system.

m_SortingFudge: f32

Biases Particle System sorting amongst other transparencies.

m_StaticBatchRoot: PPtr

PPtr<Transform>: (3.5.0 - 2022.3.2f1)

m_VelocityScale: f32

Specifies how much particles stretch depending on their velocity.

m_AllowRoll: Option<bool>

Allow billboard particles to roll around their z-axis. bool: (2018.3.0f2 - 2022.3.2f1)

m_ApplyActiveColorSpace: Option<bool>

bool: (2018.2.0b1 - 2022.3.2f1)

m_DynamicOccludee: Option<u8>

u8: (2017.2.0b2 - 2022.3.2f1)

m_EnableGPUInstancing: Option<bool>

Enables GPU Instancing on platforms that support it. bool: (2018.1.0b2 - 2022.3.2f1)

m_Flip: Option<Vector3f>

Flip a percentage of the particles, along each axis. Vector3f: (2018.3.0f2 - 2022.3.2f1)

m_FreeformStretching: Option<bool>

Enables freeform stretching behavior. bool: (2020.1.0b1 - 2022.3.2f1)

m_LightProbeAnchor: Option<PPtr>

PPtr<Transform>: (3.5.0 - 4.7.2)

m_LightProbeUsage: Option<u8>

The light probe interpolation type. u8: (5.4.0f3 - 2022.3.2f1)

m_LightProbeVolumeOverride: Option<PPtr>

PPtr<GameObject>: (5.4.0f3 - 2022.3.2f1)

m_LightmapIndexDynamic: Option<u16>

u16: (5.0.0f4 - 2022.3.2f1)

m_LightmapTilingOffsetDynamic: Option<Vector4f>

Vector4f: (5.0.0f4 - 2022.3.2f1)

m_MaskInteraction: Option<i32>

Specifies how the Particle System Renderer interacts with SpriteMask. i32: (2017.1.0b1 - 2022.3.2f1)

m_Mesh1: Option<PPtr>

PPtr<Mesh>: (4.0.0 - 2022.3.2f1)

m_Mesh2: Option<PPtr>

PPtr<Mesh>: (4.0.0 - 2022.3.2f1)

m_Mesh3: Option<PPtr>

PPtr<Mesh>: (4.0.0 - 2022.3.2f1)

m_MeshDistribution: Option<u8>

Specifies how the system randomly assigns meshes to particles. u8: (2021.2.0b1 - 2022.3.2f1)

m_MeshWeighting: Option<f32>

f32: (2021.2.0b1 - 2022.3.2f1)

m_MeshWeighting1: Option<f32>

f32: (2021.2.0b1 - 2022.3.2f1)

m_MeshWeighting2: Option<f32>

f32: (2021.2.0b1 - 2022.3.2f1)

m_MeshWeighting3: Option<f32>

f32: (2021.2.0b1 - 2022.3.2f1)

m_MinParticleSize: Option<f32>

Clamp the minimum particle size. f32: (5.3.0f1 - 2022.3.2f1)

m_MotionVectors: Option<u8>

u8: (5.4.0f3 - 2022.3.2f1)

m_NormalDirection: Option<f32>

Specifies how to calculate lighting for the billboard. f32: (4.0.0 - 2022.3.2f1)

m_Pivot: Option<Vector3f>

Modify the pivot point used for rotating particles. Vector3f: (5.3.0f1 - 2022.3.2f1)

m_ProbeAnchor: Option<PPtr>

If set, Renderer will use this Transform’s position to find the light or reflection probe. PPtr<Transform>: (5.0.0f4 - 2022.3.2f1)

m_RayTraceProcedural: Option<u8>

u8: (2020.1.0b1 - 2022.3.2f1)

m_RayTracingMode: Option<u8>

Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)

m_ReflectionProbeUsage: Option<i32>

Should reflection probes be used for this Renderer? i32: (5.0.0f4 - 5.3.8f2); u8: (5.4.0f3 - 2022.3.2f1)

m_RenderAlignment: Option<i32>

i32: (5.3.0f1 - 2022.3.2f1)

m_RendererPriority: Option<i32>

This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)

m_RenderingLayerMask: Option<u32>

Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)

m_RotateWithStretchDirection: Option<bool>

Rotate the particles based on the direction they are stretched in. This is added on top of other particle rotation. bool: (2020.1.0b1 - 2022.3.2f1)

m_ShadowBias: Option<f32>

Apply a shadow bias to prevent self-shadowing artifacts. The specified value is the proportion of the particle size. f32: (2018.3.0f2 - 2022.3.2f1)

m_SortingLayer: Option<i16>

i16: (4.3.0 - 2022.3.2f1)

m_SortingLayerID: Option<i64>

Unique ID of the Renderer’s sorting layer. u32: (4.5.0 - 4.7.2); i32: (5.0.0f4 - 2022.3.2f1)

m_SortingOrder: Option<i16>

Renderer’s order within a sorting layer. i16: (4.3.0 - 2022.3.2f1)

m_StaticBatchInfo: Option<StaticBatchInfo>

StaticBatchInfo: (5.5.0f3 - 2022.3.2f1)

m_StaticShadowCaster: Option<u8>

Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)

m_SubsetIndices: Option<Vec<u32>>

Vec: (3.5.0 - 5.4.6f3)

m_UseCustomVertexStreams: Option<bool>

bool: (5.5.0f3 - 2022.3.2f1)

m_UseLightProbes: Option<bool>

bool: (3.5.0 - 5.3.8f2)

m_VertexStreamMask: Option<i32>

i32: (5.5.0f3 - 5.5.6f1)

m_VertexStreams: Option<Vec<u8>>

Vec: (5.6.0b1 - 2022.3.2f1)