PlayableDirector

Struct PlayableDirector 

pub struct PlayableDirector {
    pub m_DirectorUpdateMode: i32,
    pub m_Enabled: u8,
    pub m_ExposedReferences: ExposedReferenceTable,
    pub m_GameObject: PPtr,
    pub m_InitialState: i32,
    pub m_InitialTime: f64,
    pub m_PlayableAsset: PPtr,
    pub m_SceneBindings: Vec<DirectorGenericBinding>,
    pub m_WrapMode: i32,
}
PlayableDirector is a class of the Unity engine since version 2017.1.0b1. Exert from Unity’s scripting documentation: Instantiates a PlayableAsset and controls playback of Playable objects.

Fields

m_DirectorUpdateMode: i32m_Enabled: u8

Enabled Behaviours are Updated, disabled Behaviours are not.

m_ExposedReferences: ExposedReferenceTablem_GameObject: PPtr

The game object this component is attached to. A component is always attached to a game object. PPtr<GameObject>: (2017.1.0b1 - 2022.3.2f1)

m_InitialState: i32m_InitialTime: f64

The time at which the Playable should start when first played.

m_PlayableAsset: PPtr

The PlayableAsset that is used to instantiate a playable for playback. PPtr<[Object]>: (2017.1.0b1 - 2022.3.2f1)

m_SceneBindings: Vec<DirectorGenericBinding>m_WrapMode: i32