pub struct PluginImporter {Show 15 fields
pub m_AssetBundleName: String,
pub m_AssetBundleVariant: String,
pub m_ExecutionOrder: Vec<(String, i32)>,
pub m_IconMap: Vec<(String, PPtr)>,
pub m_IsPreloaded: bool,
pub m_Name: String,
pub m_Output: PluginImportOutput,
pub m_PlatformData: Vec<(Enum_String__String___String, PlatformSettingsData)>,
pub m_UserData: String,
pub m_DefineConstraints: Option<Vec<String>>,
pub m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>,
pub m_IsExplicitlyReferenced: Option<bool>,
pub m_IsOverridable: Option<bool>,
pub m_UsedFileIDs: Option<Vec<i64>>,
pub m_ValidateReferences: Option<bool>,
}Expand description
PluginImporter is a class of the Unity engine since version 5.0.0f4. Exert from Unity’s scripting documentation: Represents a plugin importer.
Fields
m_AssetBundleName: StringGet or set the AssetBundle name.
m_AssetBundleVariant: StringGet or set the AssetBundle variant.
m_ExecutionOrder: Vec<(String, i32)>m_IconMap: Vec<(String, PPtr)>Vec<(String, PPtr<Texture2D>)>: (5.0.0f4 - 2022.3.2f1)
m_IsPreloaded: boolIs a native plugin loaded during startup or on demand?
m_Name: StringThe name of the object.
m_Output: PluginImportOutputm_PlatformData: Vec<(Enum_String__String___String, PlatformSettingsData)>m_UserData: StringGet or set any user data.
m_DefineConstraints: Option<Vec<String>>Allows you to specify a list of #define directives which controls whether your plug-in should be included.
Vec
m_ExternalObjects: Option<Vec<(SourceAssetIdentifier, PPtr)>>Vec<(SourceAssetIdentifier, PPtr<[Object]>)>: (2017.2.0b2 - 2022.3.2f1)
m_IsExplicitlyReferenced: Option<bool>bool: (2018.3.0f2 - 2022.3.2f1)
m_IsOverridable: Option<bool>bool: (5.5.0f3 - 2022.3.2f1)
m_UsedFileIDs: Option<Vec<i64>>Vec
m_ValidateReferences: Option<bool>bool: (2018.3.10f1 - 2022.3.2f1)