pub struct RectTransform {
pub m_AnchorMax: Vector2f,
pub m_AnchorMin: Vector2f,
pub m_GameObject: PPtr,
pub m_Pivot: Vector2f,
pub m_SizeDelta: Vector2f,
pub m_AnchoredPosition: Option<Vector2f>,
pub m_Children: Option<Vec<PPtr>>,
pub m_Father: Option<PPtr>,
pub m_LocalPosition: Option<Vector3f>,
pub m_LocalRotation: Option<Quaternionf>,
pub m_LocalScale: Option<Vector3f>,
pub m_Position: Option<Vector2f>,
}Expand description
RectTransform is a class of the Unity engine since version 4.5.0. Exert from Unity’s scripting documentation: Position, size, anchor and pivot information for a rectangle. RectTransforms are used for GUI but can also be used for other things.
It’s used to store and manipulate the position, size, and anchoring of a rectangle and supports various forms of scaling based on a parent RectTransform.Note: The Inspector changes which properties are exposed based on which anchor preset is in use. For more information see Rect Transform and Basic Layout.
Fields
m_AnchorMax: Vector2fThe normalized position in the parent RectTransform that the upper right corner is anchored to.
m_AnchorMin: Vector2fThe normalized position in the parent RectTransform that the lower left corner is anchored to.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (4.5.0 - 2022.3.2f1)
m_Pivot: Vector2fThe normalized position in this RectTransform that it rotates around.
m_SizeDelta: Vector2fThe size of this RectTransform relative to the distances between the anchors.
m_AnchoredPosition: Option<Vector2f>The position of the pivot of this RectTransform relative to the anchor reference point. Vector2f: (4.6.0 - 2022.3.2f1)
m_Children: Option<Vec<PPtr>>Vec<PPtr<Transform>>: (4.6.0 - 2022.3.2f1)
m_Father: Option<PPtr>PPtr<Transform>: (4.6.0 - 2022.3.2f1)
m_LocalPosition: Option<Vector3f>Position of the transform relative to the parent transform. Vector3f: (4.6.0 - 2022.3.2f1)
m_LocalRotation: Option<Quaternionf>The rotation of the transform relative to the transform rotation of the parent. Quaternionf: (4.6.0 - 2022.3.2f1)
m_LocalScale: Option<Vector3f>The scale of the transform relative to the GameObjects parent. Vector3f: (4.6.0 - 2022.3.2f1)
m_Position: Option<Vector2f>The world space position of the Transform. Vector2f: (4.5.0 - 4.5.5)