pub struct SpringJoint {Show 18 fields
pub m_Anchor: Vector3f,
pub m_BreakForce: f32,
pub m_BreakTorque: f32,
pub m_ConnectedBody: PPtr,
pub m_Damper: f32,
pub m_GameObject: PPtr,
pub m_MaxDistance: f32,
pub m_MinDistance: f32,
pub m_Spring: f32,
pub m_AutoConfigureConnectedAnchor: Option<bool>,
pub m_ConnectedAnchor: Option<Vector3f>,
pub m_ConnectedArticulationBody: Option<PPtr>,
pub m_ConnectedMassScale: Option<f32>,
pub m_EnableCollision: Option<bool>,
pub m_EnablePreprocessing: Option<bool>,
pub m_Enabled: Option<bool>,
pub m_MassScale: Option<f32>,
pub m_Tolerance: Option<f32>,
}Expand description
SpringJoint is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: The spring joint ties together 2 rigid bodies, spring forces will be automatically applied to keep the object at the given distance. The Spring attempts to maintain the distance it has when it starts out.
So if your joint’s start at a rest position where the two rigidbodies are far apart, then the joint will attempt to maintain that distance.
The minDistance and maxDistance properties add on top of this implicit distance.
Fields
m_Anchor: Vector3fThe Position of the anchor around which the joints motion is constrained.
m_BreakForce: f32The force that needs to be applied for this joint to break.
m_BreakTorque: f32The torque that needs to be applied for this joint to break. To be able to break, a joint must be Locked or Limited on the axis of rotation where the torque is being applied. This means that some joints cannot break, such as an unconstrained Configurable Joint.
m_ConnectedBody: PPtrA reference to another rigidbody this joint connects to.
PPtr<Rigidbody>: (3.4.0 - 2022.3.2f1)
m_Damper: f32The damper force used to dampen the spring force.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_MaxDistance: f32The maximum distance between the bodies relative to their initial distance.
m_MinDistance: f32The minimum distance between the bodies relative to their initial distance.
m_Spring: f32The spring force used to keep the two objects together.
m_AutoConfigureConnectedAnchor: Option<bool>Should the connectedAnchor be calculated automatically? bool: (4.3.0 - 2022.3.2f1)
m_ConnectedAnchor: Option<Vector3f>Position of the anchor relative to the connected Rigidbody. Vector3f: (4.3.0 - 2022.3.2f1)
m_ConnectedArticulationBody: Option<PPtr>A reference to an articulation body this joint connects to.
PPtr<ArticulationBody>: (2020.2.0b1 - 2022.3.2f1)
m_ConnectedMassScale: Option<f32>The scale to apply to the inverse mass and inertia tensor of the connected body prior to solving the constraints. f32: (2017.1.0b2 - 2022.3.2f1)
m_EnableCollision: Option<bool>Enable collision between bodies connected with the joint. bool: (4.5.0 - 2022.3.2f1)
m_EnablePreprocessing: Option<bool>Toggle preprocessing for this joint. bool: (5.0.0f4 - 2022.3.2f1)
m_Enabled: Option<bool>bool: (2017.1.0b2 - 2017.1.0b5)
m_MassScale: Option<f32>The scale to apply to the inverse mass and inertia tensor of the body prior to solving the constraints. f32: (2017.1.0b2 - 2022.3.2f1)
m_Tolerance: Option<f32>The maximum allowed error between the current spring length and the length defined by minDistance and maxDistance. f32: (5.2.3f1 - 2022.3.2f1)