SpriteBone

Struct SpriteBone 

pub struct SpriteBone {
    pub length: f32,
    pub name: String,
    pub parentId: i32,
    pub position: Vector3f,
    pub rotation: Quaternionf,
    pub color: Option<ColorRGBA>,
    pub guid: Option<String>,
}
SpriteBone is a sub class of the Unity engine since version 2018.1.0b2. Exert from Unity’s scripting documentation: Stores a set of information that describes the bind pose of this Sprite. This struct describes the hierarchy and other spatial relationships between the bones of this Sprite.

Fields

length: f32

The length of the bone. This is important for the leaf bones to describe their length without needing another bone as the terminal bone.

name: String

The name of the bone. This is useful when recreating bone hierarchy at editor or runtime. You can also use this as a way of resolving the bone path when a Sprite is bound to a more complex or richer hierarchy.

parentId: i32

The ID of the parent of this bone.

position: Vector3f

The position in local space of this bone.

rotation: Quaternionf

The rotation of this bone in local space.

color: Option<ColorRGBA>

Shows the color set for the bone in the Editor. ColorRGBA: (2021.1.0b1 - 2022.3.2f1)

guid: Option<String>

The Unique GUID of this bone. String: (2021.1.0b1 - 2022.3.2f1)