pub struct TextMesh {Show 13 fields
pub m_Alignment: i16,
pub m_Anchor: i16,
pub m_CharacterSize: f32,
pub m_Font: PPtr,
pub m_FontSize: i32,
pub m_FontStyle: i32,
pub m_GameObject: PPtr,
pub m_LineSpacing: f32,
pub m_OffsetZ: f32,
pub m_TabSize: f32,
pub m_Text: String,
pub m_Color: Option<ColorRGBA>,
pub m_RichText: Option<bool>,
}Expand description
TextMesh is a class of the Unity engine since version 3.4.0. Exert from Unity’s scripting documentation: A script interface for the text mesh component. See Also: text mesh component.
Fields
m_Alignment: i16How lines of text are aligned (Left, Right, Center).
m_Anchor: i16Which point of the text shares the position of the Transform.
m_CharacterSize: f32The size of each character (This scales the whole text).
m_Font: PPtrThe Font used.
PPtr<Font>: (3.4.0 - 2022.3.2f1)
m_FontSize: i32The font size to use (for dynamic fonts).
m_FontStyle: i32The font style to use (for dynamic fonts).
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (3.4.0 - 2022.3.2f1)
m_LineSpacing: f32How much space will be in-between lines of text.
m_OffsetZ: f32How far should the text be offset from the transform.position.z when drawing.
m_TabSize: f32How much space will be inserted for a tab ‘\t’ character. This is a multiplum of the ‘spacebar’ character offset.
m_Text: StringThe text that is displayed.
m_Color: Option<ColorRGBA>The color used to render the text. ColorRGBA: (4.2.0 - 2022.3.2f1)
m_RichText: Option<bool>Enable HTML-style tags for Text Formatting Markup. bool: (4.0.0 - 2022.3.2f1)