pub struct TextureImporterPlatformSettings {
pub m_AllowsAlphaSplitting: bool,
pub m_AndroidETC2FallbackOverride: i32,
pub m_BuildTarget: String,
pub m_CompressionQuality: i32,
pub m_CrunchedCompression: bool,
pub m_MaxTextureSize: i32,
pub m_Overridden: bool,
pub m_ResizeAlgorithm: i32,
pub m_TextureCompression: i32,
pub m_TextureFormat: i32,
pub m_ForceMaximumCompressionQuality_BC6H_BC7: Option<bool>,
pub m_IgnorePlatformSupport: Option<bool>,
}Expand description
TextureImporterPlatformSettings is a sub class of the Unity engine since version 2017.3.0b1. Exert from Unity’s scripting documentation: Stores platform specifics settings of a TextureImporter. See Also: TextureImporter.
Fields
m_AllowsAlphaSplitting: boolAllows Alpha splitting on the imported texture when needed (for example ETC1 compression for textures with transparency).
m_AndroidETC2FallbackOverride: i32Override for ETC2 decompression fallback on Android devices that don’t support ETC2.
m_BuildTarget: Stringm_CompressionQuality: i32The quality of Crunch texture compression. The range is 0 through 100. A higher quality means larger textures and longer compression times.
m_CrunchedCompression: boolUse crunch compression when available.
m_MaxTextureSize: i32Maximum texture size.
m_Overridden: boolSet to true in order to override the Default platform parameters by those provided in the TextureImporterPlatformSettings structure.
m_ResizeAlgorithm: i32For Texture to be scaled down choose resize algorithm. ( Applyed only when Texture dimension is bigger than Max Size ).
m_TextureCompression: i32Compression of imported texture.
m_TextureFormat: i32m_ForceMaximumCompressionQuality_BC6H_BC7: Option<bool>bool: (2019.2.0b1 - 2022.3.2f1)
m_IgnorePlatformSupport: Option<bool>Ignores platform support checks for the selected texture format. bool: (2022.2.20f1 - 2022.3.2f1)