pub struct TilemapCollider2D {Show 18 fields
pub m_Density: f32,
pub m_Enabled: u8,
pub m_GameObject: PPtr,
pub m_IsTrigger: bool,
pub m_Material: PPtr,
pub m_Offset: Vector2f,
pub m_UsedByComposite: bool,
pub m_UsedByEffector: bool,
pub m_CallbackLayers: Option<BitField>,
pub m_ContactCaptureLayers: Option<BitField>,
pub m_ExcludeLayers: Option<BitField>,
pub m_ExtrusionFactor: Option<f32>,
pub m_ForceReceiveLayers: Option<BitField>,
pub m_ForceSendLayers: Option<BitField>,
pub m_IncludeLayers: Option<BitField>,
pub m_LayerOverridePriority: Option<i32>,
pub m_MaximumTileChangeCount: Option<u32>,
pub m_UseDelaunayMesh: Option<bool>,
}Expand description
TilemapCollider2D is a class of the Unity engine since version 2017.2.0b2. Exert from Unity’s scripting documentation: Collider for 2D physics representing shapes defined by the corresponding Tilemap. See Also: BoxCollider2D, CircleCollider2D, EdgeCollider2D, PolygonCollider2D.
Fields
m_Density: f32The density of the collider used to calculate its mass (when auto mass is enabled).
m_Enabled: u8Enabled Behaviours are Updated, disabled Behaviours are not.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2017.2.0b2 - 2022.3.2f1)
m_IsTrigger: boolIs this collider configured as a trigger?
m_Material: PPtrPPtr<PhysicsMaterial2D>: (2017.2.0b2 - 2022.3.2f1)
m_Offset: Vector2fThe local offset of the collider geometry.
m_UsedByComposite: boolSets whether the Collider will be used or not used by a CompositeCollider2D.
m_UsedByEffector: boolWhether the collider is used by an attached effector or not.
m_CallbackLayers: Option<BitField>The Layers that this Collider2D will report collision or trigger callbacks for during a contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ContactCaptureLayers: Option<BitField>The layers of other Collider2D involved in contacts with this Collider2D that will be captured. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ExcludeLayers: Option<BitField>The additional Layers that this Collider2D should exclude when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ExtrusionFactor: Option<f32>The amount of Collider shapes each Tile extrudes to facilitate compositing with neighboring Tiles. This eliminates fine gaps between Tiles when using a CompositeCollider2D. This is calculated in Unity units within world space. f32: (2019.1.3f1 - 2022.3.2f1)
m_ForceReceiveLayers: Option<BitField>The Layers that this Collider2D can receive forces from during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_ForceSendLayers: Option<BitField>The Layers that this Collider2D is allowed to send forces to during a Collision contact with another Collider2D. BitField: (2022.2.0b1 - 2022.3.2f1)
m_IncludeLayers: Option<BitField>The additional Layers that this Collider2D should include when deciding if a contact with another Collider2D should happen or not. BitField: (2022.2.0b1 - 2022.3.2f1)
m_LayerOverridePriority: Option<i32>A decision priority assigned to this Collider2D used when there is a conflicting decision on whether a contact between itself and another Collision2D should happen or not. i32: (2022.2.0b1 - 2022.3.2f1)
m_MaximumTileChangeCount: Option<u32>Maximum number of Tile Changes accumulated before doing a full collider rebuild instead of an incremental rebuild. u32: (2019.1.0b1 - 2022.3.2f1)
m_UseDelaunayMesh: Option<bool>When the value is true, the Collider uses an additional Delaunay triangulation step to produce the Collider mesh. When the value is false, this additional step does not occur. bool: (2022.1.0b1 - 2022.3.2f1)