pub struct TilemapRenderer {Show 33 fields
pub m_CastShadows: u8,
pub m_ChunkSize: int3_storage,
pub m_DynamicOccludee: u8,
pub m_Enabled: bool,
pub m_GameObject: PPtr,
pub m_LightProbeUsage: u8,
pub m_LightProbeVolumeOverride: PPtr,
pub m_LightmapIndex: u16,
pub m_LightmapIndexDynamic: u16,
pub m_LightmapTilingOffset: Vector4f,
pub m_LightmapTilingOffsetDynamic: Vector4f,
pub m_MaskInteraction: i32,
pub m_Materials: Vec<PPtr>,
pub m_MaxChunkCount: u32,
pub m_MaxFrameAge: u32,
pub m_MotionVectors: u8,
pub m_ProbeAnchor: PPtr,
pub m_ReceiveShadows: u8,
pub m_ReflectionProbeUsage: u8,
pub m_SortOrder: i32,
pub m_SortingLayer: i16,
pub m_SortingLayerID: i32,
pub m_SortingOrder: i16,
pub m_StaticBatchInfo: StaticBatchInfo,
pub m_StaticBatchRoot: PPtr,
pub m_ChunkCullingBounds: Option<Vector3f>,
pub m_DetectChunkCullingBounds: Option<i32>,
pub m_Mode: Option<i32>,
pub m_RayTraceProcedural: Option<u8>,
pub m_RayTracingMode: Option<u8>,
pub m_RendererPriority: Option<i32>,
pub m_RenderingLayerMask: Option<u32>,
pub m_StaticShadowCaster: Option<u8>,
}Expand description
TilemapRenderer is a class of the Unity engine since version 2017.2.0b2. Exert from Unity’s scripting documentation: The tile map renderer is used to render the tile map marked out by a tile map component and a grid component. This class is a script interface for a tile map renderer component.
Fields
m_CastShadows: u8m_ChunkSize: int3_storageSize in number of tiles of each chunk created by the TilemapRenderer.
m_DynamicOccludee: u8m_Enabled: boolMakes the rendered 3D object visible if enabled.
m_GameObject: PPtrThe game object this component is attached to. A component is always attached to a game object.
PPtr<GameObject>: (2017.2.0b2 - 2022.3.2f1)
m_LightProbeUsage: u8The light probe interpolation type.
m_LightProbeVolumeOverride: PPtrPPtr<GameObject>: (2017.2.0b2 - 2022.3.2f1)
m_LightmapIndex: u16The index of the baked lightmap applied to this renderer.
m_LightmapIndexDynamic: u16m_LightmapTilingOffset: Vector4fm_LightmapTilingOffsetDynamic: Vector4fm_MaskInteraction: i32Specifies how the Tilemap interacts with the masks.
m_Materials: Vec<PPtr>Returns all the instantiated materials of this object.
Vec<PPtr<Material>>: (2017.2.0b2 - 2022.3.2f1)
m_MaxChunkCount: u32Maximum number of chunks the TilemapRenderer caches in memory.
m_MaxFrameAge: u32Maximum number of frames the TilemapRenderer keeps unused chunks in memory.
m_MotionVectors: u8m_ProbeAnchor: PPtrIf set, Renderer will use this Transform’s position to find the light or reflection probe.
PPtr<Transform>: (2017.2.0b2 - 2022.3.2f1)
m_ReceiveShadows: u8Does this object receive shadows?
m_ReflectionProbeUsage: u8Should reflection probes be used for this Renderer?
m_SortOrder: i32Active sort order for the TilemapRenderer.
m_SortingLayer: i16m_SortingLayerID: i32Unique ID of the Renderer’s sorting layer.
m_SortingOrder: i16Renderer’s order within a sorting layer.
m_StaticBatchInfo: StaticBatchInfom_StaticBatchRoot: PPtrPPtr<Transform>: (2017.2.0b2 - 2022.3.2f1)
m_ChunkCullingBounds: Option<Vector3f>Bounds used for culling of Tilemap chunks. Vector3f: (2017.4.33f1 - 2022.3.2f1)
m_DetectChunkCullingBounds: Option<i32>Returns whether the TilemapRenderer automatically detects the bounds to extend chunk culling by. i32: (2018.1.0f2 - 2022.3.2f1)
m_Mode: Option<i32>The mode in which the TileMapRenderer batches the tiles for rendering. i32: (2018.3.0f2 - 2022.3.2f1)
m_RayTraceProcedural: Option<u8>u8: (2020.1.0b1 - 2022.3.2f1)
m_RayTracingMode: Option<u8>Describes how this renderer is updated for ray tracing. u8: (2019.3.0b1 - 2022.3.2f1)
m_RendererPriority: Option<i32>This value sorts renderers by priority. Lower values are rendered first and higher values are rendered last. i32: (2018.3.0f2 - 2022.3.2f1)
m_RenderingLayerMask: Option<u32>Determines which rendering layer this renderer lives on. u32: (2018.1.0b2 - 2022.3.2f1)
m_StaticShadowCaster: Option<u8>Is this renderer a static shadow caster? u8: (2021.1.0b1 - 2022.3.2f1)